"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[91684],{91684:function(e,u,t){t(36947),Object.defineProperty(u,"__esModule",{value:!0}),u.default=void 0;var l={lastWeek:"eeee 'lalu pukul' p",yesterday:"'Kemarin pukul' p",today:"'Hari ini pukul' p",tomorrow:"'Besok pukul' p",nextWeek:"eeee 'pukul' p",other:"P"};u.default=function(e,u,t,p){return l[e]},e.exports=u.default}}]);