#comicsPlayer{background:#fff}#comicsPlayer .slideshowSwiperContainer{height:100%}#comicsPlayer .slider-zoom-container{height:100%;text-align:center}#comicsPlayer .swiper-slide-img{height:100%;max-height:100%;max-width:100%;object-fit:contain;width:100%}#comicsPlayer .swiper-pagination{background:#fff;color:#000;left:50%;padding:2px 5px 2px 5px;text-shadow:0 0 20px #fff;-webkit-transform:translate(-50%);transform:translate(-50%);width:-webkit-max-content;width:max-content}#comicsPlayer .actionButtons{position:absolute;right:.5vh;top:.5vh;z-index:1002}#comicsPlayer .actionButtonIcon{color:#000;opacity:.7}
