.actionSheet{border:none;border-radius:.1em!important;display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center;max-height:84%;padding:0}.actionsheet-not-fullscreen{max-height:90%;max-width:90%}.actionsheet-fullscreen{border-radius:0!important;max-height:none}.actionSheetContent-centered{-webkit-align-items:center;align-items:center;text-align:center}.actionSheetContent{display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;-webkit-flex-grow:1;flex-grow:1;-webkit-justify-content:center;justify-content:center;margin:0!important;overflow:hidden;padding:.4em 0!important}.actionSheetMenuItem{border-radius:0;box-shadow:none;-webkit-flex-shrink:0;flex-shrink:0;font-weight:inherit;margin:0}.actionSheetMenuItem:focus{-webkit-transform:none!important;transform:none!important}[dir=ltr] .actionsheetListItemBody{padding:.4em 1em .4em .6em!important}[dir=rtl] .actionsheetListItemBody{padding:.4em .6em .4em 1em!important}.actionSheetItemText{display:-webkit-flex;display:flex;-webkit-flex-grow:1;flex-grow:1;-webkit-justify-content:flex-start;justify-content:flex-start;overflow:hidden;text-overflow:ellipsis;vertical-align:middle;white-space:nowrap}.actionSheetItemAsideText{display:-webkit-flex;display:flex;-webkit-flex-shrink:0;flex-shrink:0;font-size:90%;-webkit-justify-content:flex-end;justify-content:flex-end;opacity:.7}[dir=ltr] .actionSheetItemAsideText{margin-left:5em;margin-right:.5em}[dir=rtl] .actionSheetItemAsideText{margin-left:.5em;margin-right:5em}.actionSheetScroller{display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;margin-bottom:0!important;width:100%}.actionSheetScroller-tv{max-height:64%;max-width:60%;width:auto}.actionsheetDivider{-webkit-flex-shrink:0;flex-shrink:0;height:.07em;margin:.25em 0}.actionSheetTitle{margin:.6em 0 .7em!important}.actionSheetText,.actionSheetTitle{-webkit-flex-grow:0;flex-grow:0;padding:0 .75rem}.actionSheetText{margin-top:0}.actionsheetMenuItemIcon{padding:0!important}[dir=ltr] .actionsheetMenuItemIcon{margin:0 .85em 0 .45em!important}[dir=rtl] .actionsheetMenuItemIcon{margin:0 .45em 0 .85em!important}.actionsheet-xlargeFont{font-size:112%!important}.btnCloseActionSheet{position:fixed;top:.75em}[dir=ltr] .btnCloseActionSheet{left:.5em}[dir=rtl] .btnCloseActionSheet{right:.5em}
.emby-select{box-sizing:border-box;display:block;font-family:inherit;font-size:110%;font-weight:inherit;margin:0;margin-bottom:0!important;outline:none!important;-webkit-tap-highlight-color:rgba(0,0,0,0);width:100%}[dir=ltr] .emby-select{padding:.5em 1.9em .5em .5em}[dir=rtl] .emby-select{padding:.5em .5em .5em 1.9em}.emby-select[disabled]{-webkit-appearance:none;appearance:none;background:none!important;border-color:transparent!important;color:inherit!important}.emby-select::-moz-focus-inner{border:0}.selectContainer-inline>.emby-select{font-size:inherit}[dir=ltr] .selectContainer-inline>.emby-select{padding:.3em 1.9em .3em .5em}[dir=rtl] .selectContainer-inline>.emby-select{padding:.3em .5em .3em 1.9em}.selectContainer-inline>.emby-select[disabled]{padding-left:0;padding-right:0}.emby-select-focusscale{-webkit-transform-origin:center center;transform-origin:center center;transition:-webkit-transform .18s ease-out!important;transition:transform .18s ease-out!important;transition:transform .18s ease-out,-webkit-transform .18s ease-out!important}.emby-select-focusscale:focus{-webkit-transform:scale(1.04);transform:scale(1.04);z-index:1}.emby-select+.fieldDescription{margin-top:.25em}.selectContainer{margin-bottom:1.8em;position:relative}.selectContainer-inline{-webkit-align-items:center;align-items:center;display:-webkit-inline-flex;display:inline-flex;margin-bottom:0}.selectLabel{display:block;margin-bottom:.25em}.selectContainer-inline>.selectLabel{-webkit-flex-shrink:0;flex-shrink:0;margin-bottom:0;margin-right:.5em}.trackSelections>.selectContainer{margin:.4em 0}.emby-select-withcolor{-webkit-appearance:none;appearance:none;border-radius:.2em}.selectArrowContainer{color:inherit;pointer-events:none;position:absolute;top:.2em}[dir=ltr] .selectArrowContainer{right:.3em}[dir=rtl] .selectArrowContainer{left:.3em}.selectContainer-inline>.selectArrowContainer{bottom:.24em;font-size:90%;top:auto}.emby-select[disabled]+.selectArrowContainer{display:none}.selectArrow{font-size:1.7em;margin-top:1.2em}.emby-select-iconbutton{-webkit-align-self:flex-end;align-self:flex-end}
.mdl-slider{-webkit-align-self:center;align-self:center;-webkit-appearance:none;appearance:none;background:transparent;color:#00a4dc;cursor:pointer;height:150%;margin:0;outline:0;-webkit-user-select:none;-ms-user-select:none;user-select:none;width:100%;z-index:1;-webkit-tap-highlight-color:rgba(0,0,0,0);display:block;font-size:inherit}.mdl-slider::-moz-focus-outer{border:0}.mdl-slider::-ms-tooltip{display:none}.mdl-slider::-webkit-slider-runnable-track{background:transparent}.mdl-slider::-ms-track{background:none;border:none;color:transparent;height:.2em;width:100%}.mdl-slider::-ms-fill-lower,.mdl-slider::-ms-fill-upper{display:none}.slider-browser-edge{margin-left:-.16em;margin-right:-.16em;width:150%}.mdl-slider::-webkit-slider-thumb{-webkit-appearance:none;appearance:none;background:#00a4dc;border:none;border-radius:50%;box-sizing:border-box;height:1.08em;pointer-events:none;-webkit-transition:.2s;transition:.2s;width:1.08em}.mdl-slider-hoverthumb:hover::-webkit-slider-thumb,.mdl-slider.show-focus:focus::-webkit-slider-thumb{-webkit-transform:scale(1.3);transform:scale(1.3)}.mdl-slider::-moz-range-thumb{appearance:none;background:#00a4dc;background-image:none;border:none;border-radius:50%;box-sizing:border-box;height:1.08em;-moz-transition:.2s;transition:.2s;width:1.08em}.mdl-slider-hoverthumb:hover::-moz-range-thumb,.mdl-slider.show-focus:focus::-moz-range-thumb{transform:scale(1.3)}.mdl-slider::-ms-thumb{appearance:none;background:#00a4dc;border:none;border-radius:50%;box-sizing:border-box;height:1.4em;transform:scale(.771429);-ms-transition:.2s;transition:.2s;width:1.4em}.mdl-slider-hoverthumb:hover::-ms-thumb,.mdl-slider.show-focus:focus::-ms-thumb{transform:none}.mdl-slider[disabled]::-webkit-slider-thumb{display:none}.mdl-slider[disabled]::-moz-range-thumb{display:none}.mdl-slider[disabled]::-ms-thumb{display:none}.mdl-slider-container{background:none;display:-webkit-flex;display:flex;-webkit-flex-direction:row;flex-direction:row;height:1.25em;position:relative}.mdl-slider-background-flex-container{box-sizing:border-box;padding:0 .54em;position:absolute;top:50%;width:100%}[dir=ltr] .mdl-slider-background-flex-container{left:0}[dir=rtl] .mdl-slider-background-flex-container{right:0}.mdl-slider-background-flex{background:hsla(0,0%,100%,.3);border:0;display:-webkit-flex;display:flex;height:.2em;margin-top:-.1em;overflow:hidden;padding:0;top:50%;width:100%}[dir=ltr] .mdl-slider-background-flex{left:0}[dir=rtl] .mdl-slider-background-flex{right:0}.mdl-slider-background-flex-inner{position:relative;width:100%}.mdl-slider-background-lower{background-color:#00a4dc;bottom:0;position:absolute;top:0;width:0}[dir=ltr] .mdl-slider-background-lower{left:0}[dir=rtl] .mdl-slider-background-lower{right:0}.mdl-slider-background-lower-clear{background-color:transparent}.mdl-slider-background-lower-withtransform{-webkit-transform:scaleX(0);transform:scaleX(0);-webkit-transform-origin:left center;transform-origin:left center;width:100%}.mdl-slider-background-upper{background:#666;background:hsla(0,0%,100%,.4);bottom:0;left:0;position:absolute;top:0;width:0}.sliderBubbleTrack{left:0;margin:0 .54em;position:absolute;right:0}.sliderBubble{-webkit-align-items:center;align-items:center;background:#282828;color:#fff;display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center;left:0;position:absolute;top:0;-webkit-transform:translate3d(-50%,-120%,0);transform:translate3d(-50%,-120%,0);z-index:1}.sliderBubbleText{margin:0;padding:.5em .75em}.sliderContainer-settings{margin-bottom:1.8em;position:relative}.sliderContainer-settings .mdl-slider-container{height:2.83em}.sliderLabel{display:block;margin-bottom:.25em}.sliderMarkerContainer{left:0;margin:0 .54em;position:absolute;right:0}.sliderMarker{height:12px;position:absolute;-webkit-transform:translate3d(0,25%,0);transform:translate3d(0,25%,0);width:2px}.sliderMarker.unwatched{background-color:hsla(0,0%,100%,.3)}.sliderMarker.watched{background-color:#00a4dc}
.subtitleappearance-fullpreview{height:100%;left:0;pointer-events:none;position:fixed;top:0;transition:.2s;width:100%;z-index:1000}.subtitleappearance-fullpreview-hide{opacity:0}.subtitleappearance-fullpreview-window{font-size:170%;position:absolute;text-align:center;width:100%}.subtitleappearance-fullpreview-text{display:inline-block;max-width:70%}
