"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[59034],{59034:function(e,o,n){n(36947),n(95021),n(53819),n(93062),Object.defineProperty(o,"__esModule",{value:!0}),o.default=void 0;var s={xseconds_other:"sekundė_sekundžių_sekundes",xminutes_one:"minutė_minutės_minutę",xminutes_other:"minutės_minučių_minutes",xhours_one:"valanda_valandos_valandą",xhours_other:"valandos_valandų_valandas",xdays_one:"diena_dienos_dieną",xdays_other:"dienos_dienų_dienas",xweeks_one:"savaitė_savaitės_savaitę",xweeks_other:"savaitės_savaičių_savaites",xmonths_one:"mėnuo_mėnesio_mėnesį",xmonths_other:"mėnesiai_mėnesių_mėnesius",xyears_one:"metai_metų_metus",xyears_other:"metai_metų_metus",about:"apie",over:"daugiau nei",almost:"beveik",lessthan:"mažiau nei"},t=function(e,o,n,s){return o?s?"kelių sekundžių":"kelias sekundes":"kelios sekundės"},a=function(e,o,n,s){return o?s?u(n)[1]:u(n)[2]:u(n)[0]},i=function(e,o,n,s){var t=e+" ";return 1===e?t+a(0,o,n,s):o?s?t+u(n)[1]:t+(r(e)?u(n)[1]:u(n)[2]):t+(r(e)?u(n)[1]:u(n)[0])};function r(e){return e%10==0||e>10&&e<20}function u(e){return s[e].split("_")}var _={lessThanXSeconds:{one:t,other:i},xSeconds:{one:t,other:i},halfAMinute:"pusė minutės",lessThanXMinutes:{one:a,other:i},xMinutes:{one:a,other:i},aboutXHours:{one:a,other:i},xHours:{one:a,other:i},xDays:{one:a,other:i},aboutXWeeks:{one:a,other:i},xWeeks:{one:a,other:i},aboutXMonths:{one:a,other:i},xMonths:{one:a,other:i},aboutXYears:{one:a,other:i},xYears:{one:a,other:i},overXYears:{one:a,other:i},almostXYears:{one:a,other:i}};o.default=function(e,o,n){var t,a=e.match(/about|over|almost|lessthan/i),i=a?e.replace(a[0],""):e,r=void 0!==(null==n?void 0:n.comparison)&&n.comparison>0,u=_[e];if(t="string"==typeof u?u:1===o?u.one(o,!0===(null==n?void 0:n.addSuffix),i.toLowerCase()+"_one",r):u.other(o,!0===(null==n?void 0:n.addSuffix),i.toLowerCase()+"_other",r),a){var d=a[0].toLowerCase();t=s[d]+" "+t}return null!=n&&n.addSuffix?n.comparison&&n.comparison>0?"po "+t:"prieš "+t:t},e.exports=o.default}}]);