"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[31974],{31974:function(o,t,u){u(36947),u(78557),u(95021),u(73687),u(93062),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n={lessThanXSeconds:"តិចជាង {{count}} វិនាទី",xSeconds:"{{count}} វិនាទី",halfAMinute:"កន្លះនាទី",lessThanXMinutes:"តិចជាង {{count}} នាទី",xMinutes:"{{count}} នាទី",aboutXHours:"ប្រហែល {{count}} ម៉ោង",xHours:"{{count}} ម៉ោង",xDays:"{{count}} ថ្ងៃ",aboutXWeeks:"ប្រហែល {{count}} សប្តាហ៍",xWeeks:"{{count}} សប្តាហ៍",aboutXMonths:"ប្រហែល {{count}} ខែ",xMonths:"{{count}} ខែ",aboutXYears:"ប្រហែល {{count}} ឆ្នាំ",xYears:"{{count}} ឆ្នាំ",overXYears:"ជាង {{count}} ឆ្នាំ",almostXYears:"ជិត {{count}} ឆ្នាំ"};t.default=function(o,t,u){var e=n[o];return"number"==typeof t&&(e=e.replace("{{count}}",t.toString())),null!=u&&u.addSuffix?u.comparison&&u.comparison>0?"ក្នុងរយៈពេល "+e:e+"មុន":e},o.exports=t.default}}]);