"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[23163,66884,67056],{67056:function(e,t,n){n.r(t),n.d(t,{default:function(){return o}}),n(44962),n(78557),n(90076),n(83994),n(82367);var r=n(82885),i=n(24468),u=n(76542),a=n(8566);function o(e,t,o){function s(){var e=l(),t=f[e];return t||(t=f[e]={query:{SortBy:"SortName",SortOrder:"Ascending",IncludeItemTypes:"Playlist",Recursive:!0,Fields:"PrimaryImageAspectRatio,SortName,CanDelete",StartIndex:0},view:r.getSavedView(e)||"Poster"},r.loadQuerySettings(e,t.query)),t}function c(){return s().query}function l(){return"".concat(t.topParentId,"-musicplaylists")}var d,f={};this.getCurrentViewStyle=function(){return s().view},this.preRender=function(){d=function(){a.Ay.show();var e=c();return ApiClient.getItems(ApiClient.getCurrentUserId(),e)}()},this.renderTab=function(){!function(e,t){var o=c();t.then((function(t){var s;s=i.default.getCardsHtml({items:t.Items,shape:"square",showTitle:!0,coverImage:!0,centerText:!0,overlayPlayButton:!0,allowBottomPadding:!0,cardLayout:!1});var c=e.querySelector("#items");c.innerHTML=s,u.default.lazyChildren(c),r.saveQuerySettings(l(),o),a.Ay.hide(),Promise.resolve().then(n.bind(n,84069)).then((function(t){t.default.autoFocus(e)}))}))}(o,d)}}}}]);