"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[96921],{2690:function(e,a,t){t.r(a),a.default='<div id="homeScreenPreferencesPage" data-role="page" class="page libraryPage userPreferencesPage noSecondaryNavPage" data-title="${Subtitles}" data-backbutton="true"> <div class="settingsContainer padded-left padded-right padded-bottom-page"></div> </div> '}}]);