"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[23717],{23717:function(e,n,t){t.r(n),t.d(n,{download:function(){return u}}),t(86584),t(78557),t(23630);var o=t(34789);function r(e){var n=document.createElement("a");n.download="",n.href=e,n.click()}function c(e){if(!e)throw new Error("`urls` required");if(void 0===document.createElement("a").download||o.A.iOS)return function(e){var n=0;!function t(){var o=document.createElement("iframe");o.style.display="none",o.src=e[n++],document.documentElement.appendChild(o);var r=setInterval((function(){"complete"!==o.contentWindow.document.readyState&&"interactive"!==o.contentWindow.document.readyState||(clearInterval(r),setTimeout((function(){o.parentNode.removeChild(o)}),1e3),n<e.length&&t())}),100)}()}(e);var n=0;e.forEach((function(e){setTimeout(r.bind(null,e),100*++n)}))}var a=t(13615);function u(e){a.A.downloadFiles(e)||c(e.map((function(e){return e.url})))}}}]);