"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[33978],{33978:function(e,t,a){a(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r={lastWeek:"eeee 'trecută la' p",yesterday:"'ieri la' p",today:"'astăzi la' p",tomorrow:"'mâine la' p",nextWeek:"eeee 'viitoare la' p",other:"P"};t.default=function(e,t,a,l){return r[e]},e.exports=t.default}}]);