"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[22888],{29387:function(e){e.exports=JSON.parse('{"Add":"Añadir","Actor":"Actor","AccessRestrictedTryAgainLater":"El acceso está restringido actualmente. Inténtelo de nuevo más tarde.","Absolute":"Absoluto","HeaderAlbumArtists":"Artistas del álbum","HeaderContinueWatching":"Continuar Viendo","Genres":"Géneros","Folders":"Carpetas","Favorites":"Favoritos","Collections":"Colecciones","Books":"Libros","Albums":"Álbumes","Artists":"Artistas","Channels":"Canales","ButtonSyncPlay":"SyncPlay","Aired":"Emitido","AirDate":"Fecha de emisión","AddedOnValue":"Añadido {0}","AddToPlayQueue":"Añadir a la lista de reproducción","AddToCollection":"Añadir a la Colección","Default":"Predeterminado","MusicVideos":"Videos musicales","Movies":"Películas","Photos":"Fotos","Playlists":"Listas de reproducción","Shows":"Series","Songs":"Canciones","ValueSpecialEpisodeName":"Especial - {0}"}')}}]);