.videoPlayerContainer{-webkit-align-items:center;align-items:center;background:#000!important;bottom:0;display:-webkit-flex;display:flex;left:0;position:fixed!important;right:0;top:0}.videoPlayerContainer-onTop{z-index:1000}.videoPlayerContainer .libassjs-canvas-parent{-webkit-order:-1;order:-1}video[controls]::-webkit-media-controls{display:none!important}.htmlvideoplayer{height:100%;margin:0!important;padding:0!important;width:100%}.htmlvideoplayer::cue{background-color:transparent;text-shadow:.14em .14em .14em #000;-webkit-font-smoothing:antialiased;font-family:inherit;line-height:normal}.htmlvideoplayer::-webkit-media-text-track-container{font-size:170%!important;line-height:50%}.htmlvideoplayer::-webkit-media-text-track-display{margin-left:15%;max-width:70%}.videoSubtitles{-webkit-align-items:center;align-items:center;bottom:0;color:#fff;display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;font-size:170%;left:0;padding-bottom:env(safe-area-inset-bottom);padding-left:env(safe-area-inset-left);padding-right:env(safe-area-inset-right);position:fixed;right:0;text-align:center}.videoSecondarySubtitlesInner,.videoSubtitlesInner{background-color:rgba(0,0,0,.8);max-width:70%}.videoSecondarySubtitlesInner{margin-bottom:.5em!important;margin-top:.5em!important;min-height:0!important}@-webkit-keyframes htmlvideoplayer-zoomin{0%{opacity:.6;-webkit-transform:scale3d(.2,.2,.2);transform:scale3d(.2,.2,.2)}to{opacity:1;-webkit-transform:none;transform:none}}@keyframes htmlvideoplayer-zoomin{0%{opacity:.6;-webkit-transform:scale3d(.2,.2,.2);transform:scale3d(.2,.2,.2)}to{opacity:1;-webkit-transform:none;transform:none}}
