"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[58122],{32197:function(e,a,d){d.r(a),a.default='<div id="displayPreferencesPage" data-role="page" class="page libraryPage userPreferencesPage noSecondaryNavPage" data-title="${Display}" data-backbutton="true"> <div class="settingsContainer padded-left padded-right padded-bottom-page"> </div> </div> '}}]);