"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[24072],{60715:function(e){e.exports=JSON.parse('{"TabLogs":"Capt\'n\'s Logs","HeaderAdmin":"Cap\'n","WelcomeToProject":"Ahoy, matey! This be Jellyfin!","ButtonOk":"Aye","DisplayInMyMedia":"Show on the Poop Deck","HeaderCastAndCrew":"Mateys","HeaderMusicQuality":"Sea Shanty Strength","HeaderLatestMusic":"Latest Sea Shanties","HeaderAudioBooks":"Spoken Tales","Books":"Scrolls","LabelHomeNetworkQuality":"Sail strength","Home":"Poop Deck","DisplayInOtherHomeScreenSections":"Show on Poop Deck such as latest booty and continue plundering","Add":"Upend","Actor":"Privateer","AccessRestrictedTryAgainLater":"Ye ain\'t allowed to be here, matey.","ButtonSyncPlay":"SyncPlay","AddedOnValue":"Upended {0}","AddToCollection":"Add t\' ye collection","AdditionalNotificationServices":"Browse th\' plugin scroll t\' invoke additional bell-ringing.","AddToPlaylist":"Upend t\' ye playlist","AddToPlayQueue":"Upend t\' ye play queue","StopPlayback":"Belay That","ClearQueue":"Swab the Decks","Alerts":"Avast Ye","AirDate":"Maiden Voyage","SearchResults":"X Marks The Spot","Songs":"Shantees","SelectAdminUsername":"Capt\'n\'s Title.","OnWakeFromSleep":"Show A Leg","TabDashboard":"The Helm","TabContainers":"Chests","ValueOneSong":"1 shanty","ValueSongCount":"{0} shanties","Yes":"Ay","PathNotFound":"That Be Uncharted Waters Friend.","LastSeen":"Ship Last Sighted {0}","Aired":"Sailed","Descending":"Headin\' Down","ButtonAddScheduledTaskTrigger":"Add Fuse","ButtonActivate":"Light the Fuse","BoxSet":"Chest Set","BoxRear":"Chest (stern)","Box":"Chest","Blacklist":"Black Charter","BirthDateValue":"Birthed: {0}","Banner":"Sail","Auto":"Without Doin\' Nothin\'","Audio":"Sound","Ascending":"Headin\' Up","Artists":"Artistas","Artist":"Crewmate","Anytime":"Whenever ye want","AllowRemoteAccessHelp":"If ye don\'t check the box, ye friends ain\'t gonna be joinin\' the fun.","AllowRemoteAccess":"Let ye friends from outside join the fun","Albums":"Tomes","AlbumArtist":"Ship Captain","Album":"Ship","Photos":"Paintings","HeaderContinueWatching":"Continue Yer Journey","Folders":"Chests","Collections":"Barrels","LabelUser":"","HeaderPleaseSignIn":"Mewngofnodwch os gwelwch yn dda","ButtonArrowRight":"Starboard","ButtonArrowLeft":"Port","AllowFfmpegThrottlingHelp":"When a transcode or remux gets far enough ahead from the current playback position, pause the process so \'twill consume less resources. This here be most useful when watchin\' without seekin\' often. Turn this off if ye experience playback issues.","AddToFavorites":"Upend t\' ye finest pickin\'s","AskAdminToCreateLibrary":"Request yer captain to build a library.","AspectRatio":"Proportion o\' the sides","AuthProviderHelp":"Pick a middleman to gander at yer friends secret handshake.","ButtonAudioTracks":"Listenin\' Choices","ButtonForgotPassword":"Forgot Secret Code","ButtonCancel":"Change yer Mind","AllowMediaConversion":"Let yer media convert","AllowMediaConversionHelp":"Give\'er take th\' media convertin\' feature.","AnyLanguage":"All Tongues","AsManyAsPossible":"All that\'ll fit","Browse":"Gander","ButtonManualLogin":"Loggin\' in by Hand","ButtonAddServer":"Find a Ship","ButtonGotIt":"Aye-Aye","ButtonChangeServer":"Board another Ship","BookLibraryHelp":"Noise n\' reading scrolls are workin\'. Look at the {0} scrolls namin\' instructions {1}.","ButtonParentalControl":"Keepin\' Yer Younguns Safe","ButtonBack":"Retreat","ButtonEditOtherUserPreferences":"Change this matey\'s name, looks, and allowances.","BirthLocation":"Place o\' Birth","ButtonAddUser":"Find a Matey","Default":"Normal-like","ButtonBackspace":"Mistake Erasing Button","ButtonClose":"Shut","Favorites":"Finest Loot","Genres":"types o\' booty","HeaderAlbumArtists":"Buccaneers o\' the musical arts","AllLibraries":"All Tomes","AllowedRemoteAddressesHelp":"List o\' IP ports or IP/netmask regions fer ships that be allowed to dock remotely. If ye leave it empty, all remote vessels be welcome.","AllLanguages":"All Tongues","AllEpisodes":"All tales","AllComplexFormats":"All Fancy Codecs (ARR, SSA, BootySub, Pirate GoldS, Swabby, Charts, …)","AllowFfmpegThrottling":"Rein in Code Scurvy","Channels":"Channels","AllowCollectionManagement":"Permit this scallywag to handle treasures","Absolute":"Abs\'lute","AgeValue":"({0} summers gone by)","AirPlay":"Spyglass","MusicVideos":"Shanty films","Movies":"Moving pictures","Shows":"Sagas","Playlists":"Lists o’ plunder","ValueSpecialEpisodeName":"Special Tale – {0}"}')}}]);