"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[19842],{19842:function(e,t,n){n.r(t),n(29305),n(32733),n(84701),n(81678),n(44962),n(4754),n(94),n(36947),n(78557),n(83994),n(82367);var r=n(36300),i=n(44797);function o(e){return o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},o(e)}function a(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,u(r.key),r)}}function u(e){var t=function(e){if("object"!=o(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=o(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==o(t)?t:t+""}function l(e){return e.changedTouches||e.targetTouches||e.touches}var s=function(){return e=function e(t,n){var o,a,u,s,c,v;!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e);var h=this,f=(n=n||{}).swipeXThreshold||50,p=n.swipeYThreshold||50,y=n.ignoreTagNames||[],d=function(e){var t=l(e)[0];if(o=null,a=0,u=0,s=null,c=null,v=!1,t){var n=t.target;if(r.Ay.parentWithTag(n,y))return;o=n,a=t.clientX,u=t.clientY}},m=function(e){var t="touchmove"===e.type;if(o){var r,y,d,m,b=l(e)[0];b?(d=b.clientX||0,m=b.clientY||0,r=d-(a||0),y=m-(u||0)):(r=0,y=0);var g=null==s?r:r-s,w=null==c?y:y-c;s=r,c=y,r>f&&Math.abs(y)<30?i.A.trigger(h,"swiperight",[o]):r<0-f&&Math.abs(y)<30?i.A.trigger(h,"swipeleft",[o]):(y<0-p||v)&&Math.abs(r)<30?(v=!0,i.A.trigger(h,"swipeup",[o,{deltaY:y,deltaX:r,clientX:d,clientY:m,currentDeltaX:g,currentDeltaY:w}])):(y>p||v)&&Math.abs(r)<30&&(v=!0,i.A.trigger(h,"swipedown",[o,{deltaY:y,deltaX:r,clientX:d,clientY:m,currentDeltaX:g,currentDeltaY:w}])),t&&n.preventDefaultOnMove&&e.preventDefault()}t||(o=null,a=0,u=0,s=null,c=null,v=!1)};this.touchStart=d,this.touchEnd=m,r.Ay.addEventListener(t,"touchstart",d,{passive:!0}),n.triggerOnMove&&r.Ay.addEventListener(t,"touchmove",m,{passive:!n.preventDefaultOnMove}),r.Ay.addEventListener(t,"touchend",m,{passive:!0}),r.Ay.addEventListener(t,"touchcancel",m,{passive:!0})},(t=[{key:"destroy",value:function(){var e=this.elem;if(e){var t=this.touchStart,n=this.touchEnd;r.Ay.removeEventListener(e,"touchstart",t,{passive:!0}),r.Ay.removeEventListener(e,"touchmove",n,{passive:!0}),r.Ay.removeEventListener(e,"touchend",n,{passive:!0}),r.Ay.removeEventListener(e,"touchcancel",n,{passive:!0})}this.touchStart=null,this.touchEnd=null,this.elem=null}}])&&a(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e;var e,t}();t.default=s}}]);