.itemSelectionPanel{background-color:rgba(0,0,0,.3);bottom:0;left:0;position:absolute;right:0;top:0;z-index:99998}.selectionCommandsPanel{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;left:0;padding-bottom:1em;padding-left:.5em;position:fixed;right:0;top:0;z-index:99999}@supports(width:max(1px,1px)){.selectionCommandsPanel{padding-left:max(env(safe-area-inset-left),.5em)}}.selectionCommandsPanel{padding-right:.5em}@supports(width:max(1px,1px)){.selectionCommandsPanel{padding-right:max(env(safe-area-inset-right),.5em)}}.selectionCommandsPanel{padding-top:1em}@supports(width:max(1px,1px)){.selectionCommandsPanel{padding-top:max(env(safe-area-inset-top),1em)}}.itemSelectionCount{color:#fff!important;margin:0;vertical-align:middle}.multiSelectCheckboxOutline{border-radius:0!important;top:0!important}.withMultiSelect{position:relative}.btnSelectionPanelOptions{margin-left:auto}
