"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[14050],{86497:function(e){e.exports=JSON.parse('{"Favorites":"পছন্দসমূহ","Albums":"অ্যালবামসমূহ","Artists":"শিল্পীগণ","Books":"পুস্তকসমূহ","Channels":"চ্যানেলসমূহ","Collections":"সংগ্রহশালা","Folders":"ফোল্ডারসমূহ","Genres":"ধরণ","HeaderAlbumArtists":"অ্যালবাম শিল্পীবৃন্দ","HeaderContinueWatching":"দেখতে থাকুন","Movies":"চলচ্চিত্রসমূহ","MusicVideos":"সঙ্গীত ভিডিয়ো সমূহ","Photos":"ছবিসমূহ","Playlists":"প্লে লিস্ট সমূহ","Songs":"সঙ্গীত সমূহ","Sync":"সমলয় স্থাপন","ValueSpecialEpisodeName":"বিশেষ পর্ব - {0}","Default":"ডিফল্ট","Shows":"শো সমূহ","Actor":"অভিনেতা","Add":"যোগ করো","AddToFavorites":"পছন্দের তালিকায় যোগ করো","AccessRestrictedTryAgainLater":"এখন অ্যাক্সেস সীমিত করা হয়েছে। অনুগ্রহ করে পরে আবার চেষ্টা করুন।","AddToCollection":"সংগ্রহে যোগ করো","AddedOnValue":"{0} যোগ করা হয়েছে","Absolute":"চূড়ান্ত","AddToPlaylist":"প্লেলিস্টে যোগ করো","AllChannels":"সব চ্যানেল","AllowFfmpegThrottlingHelp":"যখন একটি ট্রান্সকোড বা রিমাক্স বর্তমান প্লেব্যাক অবস্থান থেকে যথেষ্ট এগিয়ে চলে যায়, সেই সময় প্রক্রিয়াটি বিরতি দিন যাতে এটি কম সম্পদ ব্যবহার করে। এটি বার-বার অনুসন্ধান না করে দেখার সময় সবচেয়ে বেশি উপকারী। যদি আপনি প্লেব্যাক সমস্যার সম্মুখীন হন তবে এটি বন্ধ করুন।","AllComplexFormats":"সব কমপ্লেক্স ফরম্যাট (ASS, SSA, VobSub, PGS, SUB, IDX, …)","AllowContentWithTagsHelp":"কমপক্ষে একটি নির্দিষ্ট ট্যাগযুক্ত মিডিয়া দেখান।","AllowCollectionManagement":"এই ব্যবহারকারীকে সংগ্রহ পরিচালনা করার অনুমতি দিন","AllowFmp4TranscodingContainerHelp":"এই টিউনারের জন্য fMP4 অন্তর্নিহিত যন্ত্রকে HEVC এবং HDR বিষয়বস্তু সমর্থন করার জন্য সম্মতি দিন। সব টিউনার এই অন্তর্নিহিত যন্ত্রের সাথে সামঞ্জস্যপূর্ণ নয়। যদি আপনি প্লেব্যাক সমস্যা অনুভব করেন তবে এটি অক্ষম করুন।","AllowSegmentDeletionHelp":"গ্রাহকের দ্বারা ডাউনলোড করার পর পুরনো সেগমেন্টগুলি মুছে দিন। এটি সম্পূর্ণ পরিবর্তিত ফাইলটি ডিস্কে সংরক্ষণ করা থেকে বিরত রাখে। যদি আপনি প্লে ব্যাকের সমস্যার সম্মুখীন হন, তবে এটি বন্ধ করে দিন।","AllowStreamSharingHelp":"জেলিফিনকে টিউনার থেকে MPEG-TS স্ট্রিমটি নকল করার অনুমতি দিন এবং এই নকল স্ট্রিমটিকে এর ক্লায়েন্টদের সাথে শেয়ার করুন। যখন টিউনারের মোট স্ট্রিম সংখ্যা সীমা রয়েছে তখন এটি উপকারী, তবে এটি প্লেব্যাক সমস্যা সৃষ্টি করতে পারে।","AirPlay":"এয়ারপ্লে","Alerts":"সতর্কবার্তা","All":"সব","AllEpisodes":"সব এপিসোড","AddToPlayQueue":"প্লে কিউতে যোগ করুন","AgeValue":"({0} বছর বয়স)","Album":"অ্যালবাম","AirDate":"প্রচার তারিখ","Aired":"প্রচারিত","AlbumArtist":"অ্যালবাম শিল্পী","AllLanguages":"সব ভাষা","AllLibraries":"সব লাইব্রেরি","AllowedRemoteAddressesHelp":"দূরবর্তীভাবে সংযোগ করার জন্য অনুমোদিত নেটওয়ার্কের জন্য কমা দ্বারা আলাদা IP ঠিকানা বা IP/নেটমাস্কের তালিকা। ফাঁকা থাকলে, সব দূরবর্তী ঠিকানা অনুমোদিত হবে।","Alternate":"বিকল্প","AllowFfmpegThrottling":"থ্রটল ট্রান্সকোড","AllowSubtitleManagement":"এই ব্যবহারকারীকে সাবটাইটেল সম্পাদনার অনুমতি দিন","AllowSegmentDeletion":"সেগমেন্ট মুছে ফেলুন"}')}}]);