"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[39373],{39373:function(e,t,u){u(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"'上個'eeee p",yesterday:"'昨天' p",today:"'今天' p",tomorrow:"'明天' p",nextWeek:"'下個'eeee p",other:"P"};t.default=function(e,t,u,r){return o[e]},e.exports=t.default}}]);