"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[15402],{93929:function(t){t.exports=JSON.parse('{"Books":"Liv","AllLanguages":"Tout lang yo","AllLibraries":"Tout libreri","ButtonClose":"Fèmen","ButtonStop":"Kanpe","Absolute":"Absolu","AddToCollection":"Ajoute nan koleksyon","AddToFavorites":"Renmen","AirDate":"Dat emisyon","Album":"Albòm","AlbumArtist":"Atis Albòm","Alerts":"Alèt","Albums":"Albòm yo","All":"Tout","AllChannels":"Tout chanèl","AllEpisodes":"Tout episòd","AddedOnValue":"Ajoute {0}","Actor":"Aktè","Add":"Ajoute","AddToPlaylist":"Ajoute nan lis","AddToPlayQueue":"Ajoute nan lis keu","AgeValue":"({0} lane)","HeaderError":"Erè","Shows":"Emisyon yo","Channels":"Kanal yo","HeaderAlbumArtists":"Albòm Atis","ValueSpecialEpisodeName":"Spesyal - {0}","ButtonExitApp":"Soti nan Aplikasyon","ChannelNameOnly":"Kanal {0} sèlman","HeaderMyMedia":"Medya Pa\'m","AlwaysPlaySubtitles":"Toujou Jwe","Anime":"Anime","AnyLanguage":"Nimpòt Lang","Anytime":"Nimpot Lè","Artist":"Atis","Artists":"Atis yo","Author":"Otè","Authorize":"Otorize","BirthDateValue":"Fet: {0}","BirthLocation":"Kote li Fet","Box":"Bwat","ButtonActivate":"Aktive","ButtonAddImage":"Ajoute Imaj","ButtonAddServer":"Ajoute Sèvè","ButtonBackspace":"Retrè","ButtonEditUser":"Modifye Itilizatè","ButtonLibraryAccess":"Aksè Libreri","ButtonInfo":"Enfo","ButtonPause":"Poz","ButtonRemove":"Retire","ButtonRename":"Chanje non","ButtonShutdown":"Etèn","ButtonSend":"Voye","ButtonSpace":"Espas","ButtonStart":"Kòmanse","ChannelResolutionSDPAL":"SD (PAL)","ChannelResolutionFullHD":"Full HD","ChannelResolutionUHD4K":"UHD (4K)","Collections":"Koleksyon yo","Default":"Defo","Favorites":"Pi Renmen","Favorite":"Renmen","HeaderForKids":"Pou Timoun","HeaderMedia":"Medya","EveryXMinutes":"Chak {0} minit","HeaderContinueWatching":"Kontinye Kade","HeaderDVR":"DVR","Movies":"Fim","EveryHour":"Chak èdtan","Photos":"Foto","Songs":"Mizik yo","HeaderStartNow":"Komanse kouneya","ButtonLearnMore":"Aprann Plis","ButtonMore":"Plus","ButtonResume":"Kontinye","ButtonRevoke":"Revoke","ButtonUninstall":"Dezenstale","ButtonWebsite":"Sit Entènèt","ChannelResolutionHD":"HD","ChannelResolutionSD":"SD","ChannelNumber":"Nimewo Kanal","Folders":"Dosye","Genres":"Jan yo","BoxRear":"Bwat (dèyè)","ButtonAddMediaLibrary":"Ajoute Medya Libreri","ButtonAddScheduledTaskTrigger":"Ajoute Gachèt","ButtonAddUser":"Ajoute Itilizatè","ButtonArrowLeft":"Gòch","ButtonArrowRight":"Dwat","ButtonBack":"Tounen","ButtonCancel":"Anile","ButtonChangeServer":"Change Sèvè","ButtonOk":"OK","EveryNDays":"Chak {0} jou","MusicVideos":"Videyo Mizik","EveryXHours":"Chak {0} èdtan","ButtonQuickStartGuide":"Gid Konfigirasyon","ButtonParentalControl":"Kontwòl paran","ButtonPlayer":"Pleyè","ButtonPreviousTrack":"Trak anvan"}')}}]);