.tmla-mask,.touch-menu-la{bottom:0;box-sizing:border-box;contain:strict;padding-left:env(safe-area-inset-left);position:fixed;top:0}.touch-menu-la{background-color:#fff;display:-webkit-flex;display:flex;transition:left .26s ease-out,-webkit-transform 40ms ease-out;transition:transform 40ms ease-out,left .26s ease-out;transition:transform 40ms ease-out,left .26s ease-out,-webkit-transform 40ms ease-out;will-change:transform;z-index:1099}[div=rtl] .touch-menu-la{transition:right .26s ease-out,-webkit-transform 40ms ease-out;transition:transform 40ms ease-out,right .26s ease-out;transition:transform 40ms ease-out,right .26s ease-out,-webkit-transform 40ms ease-out}.touch-menu-la.transition{transition:left .26s ease-out,-webkit-transform .24s ease-out;transition:transform .24s ease-out,left .26s ease-out;transition:transform .24s ease-out,left .26s ease-out,-webkit-transform .24s ease-out}[div=rtl] .touch-menu-la.transition{transition:right .26s ease-out,-webkit-transform .24s ease-out;transition:transform .24s ease-out,right .26s ease-out;transition:transform .24s ease-out,right .26s ease-out,-webkit-transform .24s ease-out}.drawer-open{box-shadow:2px 0 12px rgba(0,0,0,.4)}.scrollContainer{-webkit-flex-grow:1;flex-grow:1}.tmla-mask{background-color:rgba(0,0,0,.3);left:0;opacity:0;right:0;transition:opacity .38s ease-in-out,visibility .38s ease-in-out;will-change:opacity;z-index:1098}.tmla-mask.backdrop{opacity:1}
