"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[72521],{72521:function(e,t,n){n.r(t),n.d(t,{default:function(){return s}}),n(29305),n(32733),n(78557),n(90076);var i=n(79754),o=n(46782),r=n(10838),l=n(5898),a=n(36300),s=(n(10353),n(15453),n(98959),function(e){return"string"==typeof e&&(e={title:"",text:e}),function(e){var t={removeOnClose:!0,scrollY:!1};o.A.tv&&(t.size="fullscreen");var n,s=i.default.createDialog(t);return s.classList.add("formDialog"),s.innerHTML=l.Ay.translateHtml('<div class="formDialogHeader"> <button is="paper-icon-button-light" class="btnCancel autoSize" tabindex="-1" title="${ButtonBack}"> <span class="material-icons arrow_back" aria-hidden="true"></span> </button> <h3 class="formDialogHeaderTitle"></h3> </div> <div class="formDialogContent smoothScrollY"> <div class="dialogContentInner dialog-content-centered" style="padding-top:2em"> <form> <div class="inputContainer"> <input is="emby-input" type="text" id="txtInput" label=""/> <div class="fieldDescription"></div> </div> <div class="formDialogFooter"> <button is="emby-button" type="submit" class="raised btnSubmit block formDialogFooterItem button-submit"> <span class="submitText"></span> </button> </div> </form> </div> </div> ',"core"),o.A.tv?r.default.centerFocus.on(s.querySelector(".formDialogContent"),!1):(s.querySelector(".dialogContentInner").classList.add("dialogContentInner-mini"),s.classList.add("dialog-fullscreen-lowres")),s.querySelector(".btnCancel").addEventListener("click",(function(){i.default.close(s)})),s.querySelector(".formDialogHeaderTitle").innerText=e.title||"",e.description?s.querySelector(".fieldDescription").innerText=e.description:s.querySelector(".fieldDescription").classList.add("hide"),function(e,t){var n=e.querySelector("#txtInput");n.label?n.label(t.label||""):n.setAttribute("label",t.label||""),n.value=t.value||""}(s,e),s.querySelector("form").addEventListener("submit",(function(e){return n=s.querySelector("#txtInput").value,e.preventDefault(),e.stopPropagation(),setTimeout((function(){i.default.close(s)}),300),!1})),s.querySelector(".submitText").innerText=e.confirmText||l.Ay.translate("ButtonOk"),s.style.minWidth="".concat(Math.min(400,a.Ay.getWindowSize().innerWidth-50),"px"),i.default.open(s).then((function(){return o.A.tv&&r.default.centerFocus.off(s.querySelector(".formDialogContent"),!1),n||Promise.reject()}))}(e)})}}]);