(self.webpackChunk=self.webpackChunk||[]).push([[17486,21933,37658,39867,44314,62248,95105],{37658:function(e,t,u){"use strict";u(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e){return function(){var t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{},u=t.width?String(t.width):e.defaultWidth;return e.formats[u]||e.formats[e.defaultWidth]}},e.exports=t.default},96784:function(e){e.exports=function(e){return e&&e.__esModule?e:{default:e}},e.exports.__esModule=!0,e.exports.default=e.exports}}]);