"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[97073],{97073:function(e,t,u){u(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"'গত' eeee 'সময়' p",yesterday:"'গতকাল' 'সময়' p",today:"'আজ' 'সময়' p",tomorrow:"'আগামীকাল' 'সময়' p",nextWeek:"eeee 'সময়' p",other:"P"};t.default=function(e,t,u,r){return o[e]},e.exports=t.default}}]);