#bookPlayer{background:#fff;display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;height:100%;overflow:auto;position:relative;width:100%;z-index:100}#bookPlayer .topButtons{color:#000;opacity:.7;width:100%;z-index:1002}#bookPlayer .bookPlayerContainer{-webkit-flex-grow:1;flex-grow:1}#bookPlayer #btnBookplayerToc{float:left;margin:.5vh .5vh .5vh 2vw}#bookPlayer #btnBookplayerExit{float:right;margin:.5vh 2vw .5vh .5vh}#bookPlayer .bookplayerErrorMsg{text-align:center}#bookPlayer #btnBookplayerNext,#bookPlayer #btnBookplayerPrev{margin:.5vh .5vh}#dialogToc{background-color:#fff;height:-webkit-fit-content;height:fit-content;max-height:80%;max-width:60%;width:-webkit-fit-content;width:fit-content}#dialogToc .bookplayerButtonIcon{color:#000}#dialogToc .bookplayerButton{margin:.5vh}#dialogToc .toc{margin:0;padding:30px}#dialogToc .toc li{font-size:1.2rem;font-weight:700;list-style-type:none;margin-bottom:5px}#dialogToc .toc li ul{padding-left:1.5rem}#dialogToc .toc li ul li{font-weight:400}#dialogToc .toc li a:link{color:#000;-webkit-text-decoration:none;text-decoration:none}#dialogToc .toc li a:active,#dialogToc .toc li a:hover{color:#00a4dc;-webkit-text-decoration:none;text-decoration:none}@media(max-width:60em){#dialogToc{max-height:100%;max-width:100%}}
