"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[61470],{61470:function(e,r,t){t.r(r),t.d(r,{default:function(){return s}});var n=t(24468),i=t(76542),a=t(8566);t(15453),t(10353);var o={SortBy:"SortName",SortOrder:"Ascending"};function s(e,r,t){var s;this.preRender=function(){s=ApiClient.getLiveTvSeriesTimers(o)},this.renderTab=function(){var e,r;e=t,r=s,a.Ay.show(),r.then((function(r){!function(e,r){var t=n.default.getCardsHtml({items:r,shape:"auto",defaultShape:"portrait",showTitle:!0,cardLayout:!1,preferThumb:"auto",coverImage:!0,overlayText:!1,showSeriesTimerTime:!0,showSeriesTimerChannel:!0,centerText:!0,overlayMoreButton:!0,lines:3}),o=e.querySelector("#items");o.innerHTML=t,i.default.lazyChildren(o),a.Ay.hide()}(e,r.Items)}))}}}}]);