"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[46629],{46629:function(e,a,t){t(36947),Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var r={lastWeek:"eeee 'la semaine dernière à' p",yesterday:"'hier à' p",today:"'aujourd’hui à' p",tomorrow:"'demain à' p'",nextWeek:"eeee 'la semaine prochaine à' p",other:"P"};a.default=function(e,a,t,u){return r[e]},e.exports=a.default}}]);