.emby-tab-button{background:transparent;border-radius:0;box-shadow:none;box-sizing:border-box;cursor:pointer;display:inline-block;-webkit-flex-shrink:0;flex-shrink:0;font-family:inherit;font-size:inherit;font-weight:600;height:auto;line-height:1.25;margin:0;min-width:0;min-width:auto;outline:none;overflow:hidden;padding:1.5em 1.5em;position:relative;vertical-align:middle;width:auto}.emby-tab-button.show-focus:focus{background:0!important;-webkit-transform:scale(1.3)!important;transform:scale(1.3)!important}.emby-tabs-slider{position:relative}.tabContent:not(.is-active){display:none}
.emby-scroller-container{position:relative}.emby-scroller{padding-left:3.3%}@supports(width:max(1px,1px)){.emby-scroller{padding-left:max(env(safe-area-inset-left),3.3%)}}.emby-scroller{padding-right:3.3%}@supports(width:max(1px,1px)){.emby-scroller{padding-right:max(env(safe-area-inset-right),3.3%)}}.servers>.card>.cardBox{margin-left:.6em;margin-right:.6em}[dir=ltr] .itemsContainer>.card>.cardBox{margin-left:0;margin-right:1.2em}[dir=rtl] .itemsContainer>.card>.cardBox{margin-left:1.2em;margin-right:0}[dir=ltr] .no-padding{padding-left:0}[dir=rtl] .no-padding{padding-right:0}
