"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[84347],{69080:function(l){l.exports=JSON.parse('{"Absolute":"Assolut","AddToPlaylist":"Żid fil-playlist","AddToPlayQueue":"Żid fil-play queue","Album":"Album","AllEpisodes":"L-episodji kollha","AllLanguages":"Il-lingwi kollha","AllLibraries":"Il-libreriji kollha","AccessRestrictedTryAgainLater":"L-aċċess bħalissa huwa ristrett. Jekk jogħgbok erġa\' pprova aktar tard.","Actor":"Attur","Add":"Żid","AddedOnValue":"{0} miżjud","AddToCollection":"Żid fil-kollezzjoni","AddToFavorites":"Żid fil-lista tal-favoriti","AgeValue":"({0} snin)","AirDate":"Data tax-xandir","Aired":"Imxandar","Albums":"Albums","All":"Kollha","AllChannels":"L-istazzjonijiet kollha","AllComplexFormats":"Il-formats kumplessi kollha (ASS, SSA, VobSub, PGS, SUB, IDX, …)","AirPlay":"AirPlay","Alerts":"Twissijiet","AlbumArtist":"Artist tal-Album","AllowedRemoteAddressesHelp":"Lista separata b\'virgola ta\' indirizzi IP jew entrati ta\' IP/netmask għal netwerks li se jitħallew jikkonnettjaw remotament. Jekk titħalla vojta, l-indirizzi remoti kollha jkunu permessi.","AllowCollectionManagement":"Ħalli lil dan l-utent jimmaniġġja l-kollezzjonijiet","AllowContentWithTagsHelp":"Uri biss midja b\'mill-inqas waħda mit-tags speċifikati.","AllowSubtitleManagement":"Ħalli lil dan l-utent jeditja s-sottotitli","Artists":"Artisti","Collections":"Kollezzjonijiet","Genres":"Ġeneri","HeaderContinueWatching":"Kompli Ara","Favorites":"Favoriti","Books":"Kotba","Channels":"Stazzjonijiet","HeaderAlbumArtists":"Artisti tal-album","AllowSegmentDeletionHelp":"Ħassar segmenti qodma wara li jkunu ġew imniżżla mill-klijent. Dan jipprevjeni li jkollu jaħżen il-fajl kollu transkodifikat fuq disk. Itfi din jekk ikollok problemi ta\' daqq.","AllowSegmentDeletion":"Ħassar segmenti","LabelSegmentKeepSeconds":"Żmien li żżomm is-segmenti","Shows":"Serje","Default":"Standard","Playlists":"Playlists","Folders":"Folders","Photos":"Ritratti","Songs":"Kanzunetti","Movies":"Films","MusicVideos":"Music Videos","ValueSpecialEpisodeName":"Speċjali - {0}"}')}}]);