"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[75209],{75209:function(e,t,u){u(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"'પાછલા' eeee p",yesterday:"'ગઈકાલે' p",today:"'આજે' p",tomorrow:"'આવતીકાલે' p",nextWeek:"eeee p",other:"P"};t.default=function(e,t,u,r){return o[e]},e.exports=t.default}}]);