.alphaPicker{-webkit-align-self:center;align-self:center;display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;text-align:center}.alphaPicker-vertical{line-height:1}.alphaPicker-fixed{bottom:5.5em;position:fixed}@supports(width:max(1px,1px)){.alphaPicker-fixed{bottom:max(env(safe-area-inset-bottom),5.5em)}}.alphaPickerRow{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;-webkit-flex-direction:row;flex-direction:row;-webkit-justify-content:center;justify-content:center}.alphaPickerRow-vertical{-webkit-flex-direction:column;flex-direction:column}.alphaPickerButton{border:0!important;border-radius:.1em;cursor:pointer;-webkit-flex-grow:1;flex-grow:1;-webkit-flex-shrink:0;flex-shrink:0;font-family:inherit;font-size:inherit;font-weight:400;margin:0;min-width:0;min-width:auto;outline:none!important;padding:.1em .4em;vertical-align:middle;width:auto}@media (max-height:50em){.alphaPicker-fixed{bottom:5em}@supports(width:max(1px,1px)){.alphaPicker-fixed{bottom:max(env(safe-area-inset-bottom),5em)}}.alphaPickerButton-vertical{padding-bottom:1px!important;padding-top:1px!important}}@media (max-height:49em){.alphaPicker-vertical{font-size:94%}}@media (max-height:44em){.alphaPicker-vertical{font-size:90%}.alphaPickerButton-vertical{padding-bottom:0!important;padding-top:0!important}}@media (max-height:37em){.alphaPicker-vertical{font-size:82%}}@media (max-height:32em){.alphaPicker-vertical{font-size:74%}}.alphaPicker-vertical.alphaPicker-tv{font-size:86%}.alphaPickerButton-tv.alphaPickerButton-vertical{padding:0}.alphaPickerButton-vertical{display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center;text-align:center;width:1.5em}.alphaPickerButtonIcon{font-size:100%!important}.alphaPicker-fixed.alphaPicker-tv{bottom:1%}@supports(width:max(1px,1px)){.alphaPicker-fixed.alphaPicker-tv{bottom:max(env(safe-area-inset-bottom),1%)}}[dir=ltr] .alphaPicker-fixed-right{right:.4em}@supports(width:max(1px,1px)){[dir=ltr] .alphaPicker-fixed-right{right:max(env(safe-area-inset-right),.4em)}}[dir=rtl] .alphaPicker-fixed-right{left:.4em}@supports(width:max(1px,1px)){[dir=rtl] .alphaPicker-fixed-right{left:max(env(safe-area-inset-left),.4em)}}@media (min-width:62.5em){[dir=ltr] .alphaPicker-fixed-right{right:1em}@supports(width:max(1px,1px)){[dir=ltr] .alphaPicker-fixed-right{right:max(env(safe-area-inset-right),1em)}}[dir=rtl] .alphaPicker-fixed-right{left:1em}@supports(width:max(1px,1px)){[dir=rtl] .alphaPicker-fixed-right{left:max(env(safe-area-inset-left),1em)}}}@media (max-height:31.25em){.alphaPicker-fixed{display:none!important}}
.mediaInfoItem{padding:0}[dir=ltr] .mediaInfoItem{margin:0 1em 0 0}[dir=rtl] .mediaInfoItem{margin:0 0 0 1em}.mediaInfoText{-webkit-align-items:center;align-items:center;border-radius:.25em;display:-webkit-flex;display:flex;font-size:92%;margin:0 .5em 0 0;padding:.22em .5em;white-space:nowrap}.mediaInfoText-upper{text-transform:uppercase}.mediaInfoIconItem{font-size:1.6em;height:auto;margin-right:.6em;width:auto}[dir=ltr] .mediaInfoItem:last-child{margin-right:0}[dir=rtl] .mediaInfoItem:last-child{margin-left:0}.starRatingContainer{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center;vertical-align:middle}.starIcon{color:#f2b01e;font-size:1.4em;height:auto!important;margin-right:.125em;width:auto!important}.mediaInfoCriticRating{-webkit-align-items:center;align-items:center;background-repeat:no-repeat;background-size:auto 1.2em;display:-webkit-flex;display:flex;min-height:1.2em}[dir=ltr] .mediaInfoCriticRating{background-position:0;padding-left:1.5em}[dir=rtl] .mediaInfoCriticRating{background-position:100%;padding-right:1.5em}.mediaInfoCriticRatingFresh{background-image:url(assets/img/fresh.svg)}.mediaInfoCriticRatingRotten{background-image:url(assets/img/rotten.svg)}.mediaInfoProgramAttribute{border-radius:.15em;font-size:80%;padding:.16em .6em;text-transform:uppercase}.closedCaptionMediaInfoText{font-weight:700}
