"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[94167],{48420:function(e){e.exports=JSON.parse('{"Sync":"Vumelanisa","Songs":"Amaculo","Shows":"Izinhlelo","Playlists":"Izinhla Zokudlalayo","Photos":"Izithombe","Movies":"Amamuvi","HeaderStatus":"Usimo","HeaderSeasons":"Amasizini","HeaderScenes":"Izigcawu","HeaderPaths":"Imigudu","HeaderPassword":"Iphasiwedi","HeaderNavigation":"Ukuhlwaya","HeaderMedia":"Imidiya","HeaderLibraries":"Imitapo","HeaderInstall":"Ukufaka","HeaderIdentification":"Ukuhlonza","HeaderError":"Iphutha","HeaderDevices":"Amadivayisi","HeaderBranding":"Ukwenza uphawu","HeaderApp":"I-app","HeaderAlert":"Isexwayiso","HeaderAdmin":"Ukulawulwa","HeaderActivity":"Umsebenzi","GuideProviderLogin":"Ukungena","Guide":"Umhlahlandlela","Genres":"Izinhlobo","Genre":"Uhlobo","General":"Ngokuvamile","Friday":"ULwesihlanu","Framerate":"Ukukalwa kwe fulemu","Folders":"Izikhwama","Filters":"Izisefo","Filter":"Isihlungi","File":"Ifayela","Features":"Izici","Favorites":"Izintandokazi","Favorite":"Intandokazi","FastForward":"Shesha phambili","Extras":"Okwengeziwe","Episode":"Isiqephu","Ended":"Kuphelile","Edit":"Hlela","Download":"Yehlisa","Down":"Phansi","Display":"Bonisa","Disconnect":"Nqamula","Disc":"Idiski","DisablePlugin":"Vimbela","EnablePlugin":"Vumela","Directors":"Abaqondisi","Director":"Umqondisi","Desktop":"Ideskithophu","Descending":"Ukwehla","Depressed":"Cindezelekile","Delete":"Susa","Default":"Okumisiwe","Data":"Imininingo","Continuing":"Ukuqhubeka","Connect":"Xhuma","Composer":"Umqambi","Collections":"Amaqoqo","Channels":"Amashaneli","Categories":"Izigaba","Bwdif":"BWDIF","ButtonWebsite":"Iwebhusayithi","ButtonUninstall":"Khipha","ButtonTrailer":"Ithreyila","ButtonTogglePlaylist":"Uhlu lokudlalwayo","ButtonSyncPlay":"SyncPlay","ButtonSubmit":"Hambisa","ButtonStop":"Misa","ButtonStart":"Qalisa","ButtonSplit":"Hlukanisa","ButtonShutdown":"Ivaliwe","ButtonSend":"Thumela","ButtonRevoke":"Hoxisa","ButtonResume":"Qala futhi","ButtonRename":"Qamba kabusha","ButtonRemove":"Khipha","ButtonPlayer":"Isidlali","ButtonPause":"Phumuza isikhashana","ButtonOpen":"Vula","ButtonOk":"Kulungile","ButtonNetwork":"Inethiwekhi","ButtonMore":"Okwengeziwe","ButtonInfo":"Ulwazi","ButtonFullscreen":"Isikrini esigcwele","ButtonCast":"Thumela imidiya","ButtonCancel":"Khansela","ButtonBack":"Emuva","ButtonArrowRight":"Okwesokudla","ButtonArrowLeft":"Okwesokunxele","ButtonActivate":"Yenza isebenze","Browse":"Phequlula","Box":"Ibhokisi","Books":"Izincwadi","Blacklist":"Uhlu oluvinjelwe","Banner":"Ibhena","Backdrops":"Okungemuva","Backdrop":"Ingemuva","Auto":"Zenzekelayo","Authorize":"Gunyaza","Audio":"Okulalelwayo","Ascending":"Ukwenyuka","Artists":"Abadlali","Artist":"Umculi","Anytime":"Noma nini","All":"Konke","Alerts":"Izixwayiso","Albums":"Ama-albhamu","Album":"I-albhamu","Aired":"Kusakazwa","Add":"Yengeza","Actor":"Umlingisi","Absolute":"Impela","HeaderAlbumArtists":"Abasethi wenkulumo","HeaderContinueWatching":"Buyela Ukubona"}')}}]);