"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[71454],{71454:function(s,e,n){n.r(e);var i,t,r,a,o,c,d=n(39738),h=n(36300),l=n(34789),u=n(44797);function f(){this.classList.add("hide")}function g(){c&&(clearTimeout(c),c=null)}function m(){g();var s=t;s&&(o?(s.offsetWidth,requestAnimationFrame((function(){s.classList.add("iconOsd-hidden"),h.Ay.addEventListener(s,h.Ay.whichTransitionEvent(),f,{once:!0})}))):f.call(s))}function v(){var s,e,n,i;(s=t)||(o=l.A.supportsCssAnimation(),(s=document.createElement("div")).classList.add("hide"),s.classList.add("iconOsd"),s.classList.add("iconOsd-hidden"),s.classList.add("brightnessOsd"),s.innerHTML='<span class="material-icons iconOsdIcon brightness_high" aria-hidden="true"></span><div class="iconOsdProgressOuter"><div class="iconOsdProgressInner brightnessOsdProgressInner"></div></div>',r=s.querySelector(".material-icons"),a=s.querySelector(".iconOsdProgressInner"),document.body.appendChild(s),t=s),e=d.f.getBrightness(this),r&&(i=e>=80?"brightness_high":e>=20?"brightness_medium":"brightness_low",(n=r).classList.remove("brightness_high","brightness_medium","brightness_low"),n.classList.add(i)),a&&(a.style.width=(e||0)+"%"),function(){g();var s=t;h.Ay.removeEventListener(s,h.Ay.whichTransitionEvent(),f,{once:!0}),s.classList.remove("hide"),s.offsetWidth,requestAnimationFrame((function(){s.classList.remove("iconOsd-hidden"),c=setTimeout(m,3e3)}))}()}function b(s){s!==i&&(function(){var s=i;s&&(u.A.off(s,"brightnesschange",v),u.A.off(s,"playbackstop",m),i=null)}(),i=s,s&&(m(),u.A.on(s,"brightnesschange",v),u.A.on(s,"playbackstop",m)))}u.A.on(d.f,"playerchange",(function(){b(d.f.getCurrentPlayer())})),b(d.f.getCurrentPlayer())}}]);