"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[97689],{97689:function(e,t,a){a(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"'pasinta' eeee 'je' p",yesterday:"'hieraŭ je' p",today:"'hodiaŭ je' p",tomorrow:"'morgaŭ je' p",nextWeek:"eeee 'je' p",other:"P"};t.default=function(e,t,a,r){return o[e]},e.exports=t.default}}]);