.iconOsd{-webkit-backdrop-filter:blur(5px);backdrop-filter:blur(5px);background:#222;background:rgba(0,0,0,.8);border-radius:.25em;color:#fff;padding:1em;position:fixed;right:3%;top:7%;transition:opacity .2s ease-out;z-index:100000}.iconOsd-hidden{opacity:0}.iconOsdIcon{display:block;font-size:320%;margin:.25em .7em}.iconOsdProgressOuter{background:#222;border-radius:.25em;height:.35em;margin:1.5em .25em 1em}.iconOsdProgressInner{background:#00a4dc;border-radius:.25em;height:100%}.brightnessOsdProgressInner{background:#ff9800}
