@-webkit-keyframes fadein{0%{opacity:0}to{opacity:1}}@keyframes fadein{0%{opacity:0}to{opacity:1}}.lazy-image-fadein{-webkit-animation:fadein .5s;animation:fadein .5s;opacity:1}.lazy-image-fadein-fast{-webkit-animation:fadein .1s;animation:fadein .1s;opacity:1}.lazy-hidden,.lazy-hidden-children *{opacity:0}.blurhash-canvas{bottom:0;height:100%;left:0;pointer-events:none;position:absolute;right:0;top:0;width:100%}
.itemProgressBar{background:#333;background:rgba(51,51,51,.8);height:.28em;position:relative}.itemLinearProgress{border-radius:100px;bottom:0;left:0;position:absolute!important;width:100%}.itemProgressBarForeground{bottom:0;position:absolute;top:0}[dir=ltr] .itemProgressBarForeground{left:0}[dir=rtl] .itemProgressBarForeground{right:0}.indicator{-webkit-align-items:center;align-items:center;border-radius:100em;display:-webkit-flex;display:flex;font-weight:500;height:2em;-webkit-justify-content:center;justify-content:center;width:2em}.timerIndicator{color:#cb272a}.timerIndicator-inactive{color:#888}[dir=ltr] .indicator+.indicator{margin-left:.25em}[dir=rtl] .indicator+.indicator{margin-right:.25em}.indicatorIcon{font-size:1.6em;height:auto;width:auto}.countIndicator{font-size:88%;font-weight:500}.countIndicator,.playedIndicator{-webkit-align-items:center;align-items:center;border-radius:100em;box-shadow:0 2px 2px 0 rgba(0,0,0,.14),0 1px 5px 0 rgba(0,0,0,.12),0 3px 1px -2px rgba(0,0,0,.2);color:#fff;display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center}.playedIndicator{font-size:80%}.videoIndicator{-webkit-align-items:center;align-items:center;background:#444;box-shadow:0 2px 2px 0 rgba(0,0,0,.14),0 1px 5px 0 rgba(0,0,0,.12),0 3px 1px -2px rgba(0,0,0,.2);color:#fff;display:-webkit-flex;display:flex;font-size:88%;-webkit-justify-content:center;justify-content:center}.syncIndicator,.videoIndicator{border-radius:100em}.emptySyncIndicator{background:#ccc;color:#333}.missingIndicator,.unairedIndicator{background:#c33;border-radius:100em;color:#fff;font-size:84%;font-weight:500;margin:0 .25em;padding:.25em .5em}
.newTvProgram{background:#38c;color:#fff}.liveTvProgram{background:#c33;color:#fff}.premiereTvProgram{background:#ef6c00;color:#fff}.repeatTvProgram{background:#009688;color:#fff}
.emby-scroller-container{position:relative}.emby-scroller{padding-left:3.3%}@supports(width:max(1px,1px)){.emby-scroller{padding-left:max(env(safe-area-inset-left),3.3%)}}.emby-scroller{padding-right:3.3%}@supports(width:max(1px,1px)){.emby-scroller{padding-right:max(env(safe-area-inset-right),3.3%)}}.servers>.card>.cardBox{margin-left:.6em;margin-right:.6em}[dir=ltr] .itemsContainer>.card>.cardBox{margin-left:0;margin-right:1.2em}[dir=rtl] .itemsContainer>.card>.cardBox{margin-left:1.2em;margin-right:0}[dir=ltr] .no-padding{padding-left:0}[dir=rtl] .no-padding{padding-right:0}
.homeLibraryButton{margin:.5em!important;min-width:18%}@media (max-width:50em){.homeLibraryButton{width:46%!important}}.homeLibraryIcon{-webkit-flex-shrink:0;flex-shrink:0;margin-left:.5em;margin-right:.5em}.homeLibraryText{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}
