"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[7006],{7006:function(e,u,t){t(36947),Object.defineProperty(u,"__esModule",{value:!0}),u.default=void 0;var r={lastWeek:function(e){switch(e.getUTCDay()){case 0:return"'prošle nedjelje u' p";case 3:return"'prošle srijede u' p";case 6:return"'prošle subote u' p";default:return"'prošli' EEEE 'u' p"}},yesterday:"'juče u' p",today:"'danas u' p",tomorrow:"'sutra u' p",nextWeek:function(e){switch(e.getUTCDay()){case 0:return"'sljedeće nedjelje u' p";case 3:return"'sljedeću srijedu u' p";case 6:return"'sljedeću subotu u' p";default:return"'sljedeći' EEEE 'u' p"}},other:"P"};u.default=function(e,u,t,s){var n=r[e];return"function"==typeof n?n(u):n},e.exports=u.default}}]);