html{font-size:93%;-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;text-size-adjust:100%;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility}h1{font-size:1.8em}h1,h2{font-weight:400}h2{font-size:1.5em}h3{font-size:1.17em;font-weight:400}.textarea-mono{font-family:ui-monospace,Menlo,Monaco,Cascadia Mono,Segoe UI Mono,Roboto Mono,Oxygen Mono,Ubuntu Mono,Source Code Pro,Fira Mono,Droid Sans Mono,Consolas,Courier New,monospace!important}.layout-tv{font-size:125%}.layout-mobile{font-size:90%}
