(self.webpackChunk=self.webpackChunk||[]).push([[9387,19863,31768,42244,75101,94160,97482],{94160:function(t,e,u){"use strict";u(44962),u(36947),u(78557),u(82367),Object.defineProperty(e,"__esModule",{value:!0}),e.default=function(t){return function(e,u){var n;if("formatting"===(null!=u&&u.context?String(u.context):"standalone")&&t.formattingValues){var a=t.defaultFormattingWidth||t.defaultWidth,l=null!=u&&u.width?String(u.width):a;n=t.formattingValues[l]||t.formattingValues[a]}else{var r=t.defaultWidth,i=null!=u&&u.width?String(u.width):t.defaultWidth;n=t.values[i]||t.values[r]}return n[t.argumentCallback?t.argumentCallback(e):e]}},t.exports=e.default},96784:function(t){t.exports=function(t){return t&&t.__esModule?t:{default:t}},t.exports.__esModule=!0,t.exports.default=t.exports}}]);