.slideshowDialog,.slideshowSwiperContainer,.swiper-slide,.swiper-wrapper{background:#000}.slideshowImage,.slideshowSwiperContainer{background-position:50%;background-repeat:no-repeat;background-size:contain;bottom:0;color:#fff;left:0;line-height:normal;margin:0!important;position:fixed;right:0;top:0}.slideshowImage-cover{background-size:cover}.slideshowImageText{bottom:.25em;color:#fff;font-weight:400;position:fixed;right:.5em;text-shadow:3px 3px 0 #000,-1px -1px 0 #000,1px -1px 0 #000,-1px 1px 0 #000,1px 1px 0 #000;z-index:1002}.slideshowButtonIcon{color:#fff;opacity:.7}.btnSlideshowPrevious{left:.5vh;position:absolute;top:45vh;z-index:1002}.btnSlideshowNext{top:45vh}.btnSlideshowNext,.topActionButtons{position:absolute;right:.5vh;z-index:1002}.topActionButtons{top:.5vh}.slideshowBottomBar{bottom:0;-webkit-justify-content:center;justify-content:center}.slideshowBottomBar,.slideshowTopBar{-webkit-align-items:center;align-items:center;background-color:rgba(0,0,0,.7);color:#fff;display:-webkit-flex;display:flex;-webkit-flex-direction:row;flex-direction:row;left:0;padding:.5%;position:fixed;right:0}.slideshowTopBar{-webkit-justify-content:flex-end;justify-content:flex-end;text-align:right;top:0}.slideshowExtraButtons{margin-left:auto;text-align:right}.slideText{bottom:10vh;left:0;position:absolute;right:0;text-align:center}.slideTextInner{background:rgba(0,0,0,.8);border-radius:.25em;display:inline-block;margin:0 auto;max-width:60%;padding:.5em 1em}.slideTitle{margin:0 0 .25em}.slideSubtitle{color:#ccc}.swiper-zoom-fakeimg{background-position:50% 50%;background-repeat:no-repeat;background-size:contain;left:50%;pointer-events:none;position:absolute;top:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%);z-index:1}.swiper-zoom-fakeimg-hidden{display:none}
