"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[69806],{14189:function(l){l.exports=JSON.parse('{"AlbumArtist":"Albomoù arzourien","All":"An holl","AllChannels":"An holl chadennoù","Actor":"Komedian","Add":"Ouzhpennañ","AllLanguages":"An holl yezhoù","AddedOnValue":"Ouzhpennet {0}","AgeValue":"({0} bloaz \'zo)","Album":"Albom","AllEpisodes":"An holl rannoù","AddToFavorites":"Ouzhpennañ d\'ar re vuiañ karet","Albums":"Albomoù","AddToPlaylist":"Ouzhpennañ d\'ar roll-videoioù","Alerts":"Kemennoù-diwall","AirPlay":"AirPlay","AllLibraries":"An holl levraouegoù"}')}}]);