"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[53408],{53408:function(e,t,u){u(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n={lastWeek:function(e){return 6===e.getUTCDay()?"'το προηγούμενο' eeee 'στις' p":"'την προηγούμενη' eeee 'στις' p"},yesterday:"'χθες στις' p",today:"'σήμερα στις' p",tomorrow:"'αύριο στις' p",nextWeek:"eeee 'στις' p",other:"P"};t.default=function(e,t){var u=n[e];return"function"==typeof u?u(t):u},e.exports=t.default}}]);