"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[22252],{17242:function(e,t,n){n(86584),n(36947),n(78557),n(95021),n(53819),n(93062);var l=n(96784).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,n){var l,D,O,S,b,y,C,E,P,W,R,Y,z,L,T,j,A,$;(0,v.default)(2,arguments);var _=String(t),I=(0,c.getDefaultOptions)(),M=null!==(l=null!==(D=null==n?void 0:n.locale)&&void 0!==D?D:I.locale)&&void 0!==l?l:w.default,q=(0,f.default)(null!==(O=null!==(S=null!==(b=null!==(y=null==n?void 0:n.firstWeekContainsDate)&&void 0!==y?y:null==n||null===(C=n.locale)||void 0===C||null===(E=C.options)||void 0===E?void 0:E.firstWeekContainsDate)&&void 0!==b?b:I.firstWeekContainsDate)&&void 0!==S?S:null===(P=I.locale)||void 0===P||null===(W=P.options)||void 0===W?void 0:W.firstWeekContainsDate)&&void 0!==O?O:1);if(!(q>=1&&q<=7))throw new RangeError("firstWeekContainsDate must be between 1 and 7 inclusively");var x=(0,f.default)(null!==(R=null!==(Y=null!==(z=null!==(L=null==n?void 0:n.weekStartsOn)&&void 0!==L?L:null==n||null===(T=n.locale)||void 0===T||null===(j=T.options)||void 0===j?void 0:j.weekStartsOn)&&void 0!==z?z:I.weekStartsOn)&&void 0!==Y?Y:null===(A=I.locale)||void 0===A||null===($=A.options)||void 0===$?void 0:$.weekStartsOn)&&void 0!==R?R:0);if(!(x>=0&&x<=6))throw new RangeError("weekStartsOn must be between 0 and 6 inclusively");if(!M.localize)throw new RangeError("locale must contain localize property");if(!M.formatLong)throw new RangeError("locale must contain formatLong property");var F=(0,r.default)(e);if(!(0,o.default)(F))throw new RangeError("Invalid time value");var H=(0,d.default)(F),K=(0,a.default)(F,H),Q={firstWeekContainsDate:q,weekStartsOn:x,locale:M,_originalDate:F};return _.match(p).map((function(e){var t=e[0];return"p"===t||"P"===t?(0,u.default[t])(e,M.formatLong):e})).join("").match(k).map((function(l){if("''"===l)return"'";var o,a,r=l[0];if("'"===r)return(a=(o=l).match(g))?a[1].replace(h,"'"):o;var u=i.default[r];if(u)return null!=n&&n.useAdditionalWeekYearTokens||!(0,s.isProtectedWeekYearToken)(l)||(0,s.throwProtectedError)(l,t,String(e)),null!=n&&n.useAdditionalDayOfYearTokens||!(0,s.isProtectedDayOfYearToken)(l)||(0,s.throwProtectedError)(l,t,String(e)),u(K,l,M.localize,Q);if(r.match(m))throw new RangeError("Format string contains an unescaped latin alphabet character `"+r+"`");return l})).join("")};var o=l(n(5877)),a=l(n(14819)),r=l(n(33188)),i=l(n(79541)),u=l(n(57655)),d=l(n(54583)),s=n(54486),f=l(n(30867)),v=l(n(23058)),c=n(35119),w=l(n(80345)),k=/[yYQqMLwIdDecihHKkms]o|(\w)\1*|''|'(''|[^'])+('|$)|./g,p=/P+p+|P+|p+|''|'(''|[^'])+('|$)|./g,g=/^'([^]*?)'?$/,h=/''/g,m=/[a-zA-Z]/;e.exports=t.default}}]);