"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[36154],{38193:function(e,n,u){u.r(n),u.d(n,{default:function(){return t}});var r=u(36934);function t(e,n,u){var t,i=this;i.renderTab=function(){t||(t=new r.A({element:u,serverId:ApiClient.serverId()}))},i.onShow=function(){t&&t.resume()},i.onHide=function(){t&&t.pause()}}}}]);