"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[38619],{38619:function(e,a,t){t(36947),Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var s={lastWeek:"'geçen hafta' eeee 'saat' p",yesterday:"'dün saat' p",today:"'bugün saat' p",tomorrow:"'yarın saat' p",nextWeek:"eeee 'saat' p",other:"P"};a.default=function(e,a,t,n){return s[e]},e.exports=a.default}}]);