"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[16504],{16504:function(e,t,o){o(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var u={lastWeek:"eeee 'tuần trước vào lúc' p",yesterday:"'hôm qua vào lúc' p",today:"'hôm nay vào lúc' p",tomorrow:"'ngày mai vào lúc' p",nextWeek:"eeee 'tới vào lúc' p",other:"P"};t.default=function(e,t,o,a){return u[e]},e.exports=t.default}}]);