"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[7184],{7184:function(t,e,a){a(89336),a(36947),a(95021),a(53819),Object.defineProperty(e,"__esModule",{value:!0}),e.default=function(t){return function(e){var a=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},r=a.width,n=r&&t.matchPatterns[r]||t.matchPatterns[t.defaultMatchWidth],l=e.match(n);if(!l)return null;var u,s=l[0],c=r&&t.parsePatterns[r]||t.parsePatterns[t.defaultParseWidth],f=Array.isArray(c)?function(t){for(var e=0;e<t.length;e++)if(t[e].test(s))return e}(c):function(t){for(var e in t)if(t.hasOwnProperty(e)&&t[e].test(s))return e}(c);return u=t.valueCallback?t.valueCallback(f):f,{value:u=a.valueCallback?a.valueCallback(u):u,rest:e.slice(s.length)}}},t.exports=e.default}}]);