"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[13231],{13231:function(u,e,t){t(36947),Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0;var r={lastWeek:function(u){switch(u.getUTCDay()){case 0:return"'prošlu nedjelju u' p";case 3:return"'prošlu srijedu u' p";case 6:return"'prošlu subotu u' p";default:return"'prošli' EEEE 'u' p"}},yesterday:"'jučer u' p",today:"'danas u' p",tomorrow:"'sutra u' p",nextWeek:function(u){switch(u.getUTCDay()){case 0:return"'iduću nedjelju u' p";case 3:return"'iduću srijedu u' p";case 6:return"'iduću subotu u' p";default:return"'prošli' EEEE 'u' p"}},other:"P"};e.default=function(u,e,t,n){var a=r[u];return"function"==typeof a?a(e):a},u.exports=e.default}}]);