"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[80625],{80625:function(e,a,t){t(36947),Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var l={lastWeek:"'el' eeee 'passat a la' LT",yesterday:"'ahir a la' p",today:"'avui a la' p",tomorrow:"'demà a la' p",nextWeek:"eeee 'a la' p",other:"P"},s={lastWeek:"'el' eeee 'passat a les' p",yesterday:"'ahir a les' p",today:"'avui a les' p",tomorrow:"'demà a les' p",nextWeek:"eeee 'a les' p",other:"P"};a.default=function(e,a,t,r){return 1!==a.getUTCHours()?s[e]:l[e]},e.exports=a.default}}]);