.loginDisclaimerContainer{display:-webkit-flex;display:flex;margin-top:2em}.loginDisclaimer{margin:0 auto}.loginDisclaimer h1,.loginDisclaimer h2,.loginDisclaimer h3,.loginDisclaimer h4,.loginDisclaimer h5,.loginDisclaimer h6,.loginDisclaimer p{text-align:center}.loginDisclaimer ol,.loginDisclaimer ul{margin-left:auto;margin-right:auto;max-width:40em;width:-webkit-fit-content;width:fit-content}
