"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[48834],{69665:function(e){e.exports=JSON.parse('{"Add":"එක් කරන්න","AllLanguages":"සියලුම භාෂා","AccessRestrictedTryAgainLater":"ප්‍රවේශය දැනට සීමා කර ඇත. කරුණාකර පසුව නැවත උත්සාහ කරන්න.","Actor":"නළුවා","AddToCollection":"එකතුවට එකතු කරන්න","AddToFavorites":"ප්‍රියතමයන් වෙත එක් කරන්න","AllLibraries":"සියලුම පුස්තකාල","AddedOnValue":"එකතු කරන ලදී {0}","AddToPlaylist":"ධාවන ලැයිස්තුවට එක් කරන්න","AllowFfmpegThrottling":"පරිවර්තනය අඩුකරන්න","AllowFfmpegThrottlingHelp":"පරිවර්තනය කිරීමක් හෝ රීමක්ස්කිරීමක් වත්මන් ධාවන ස්ථානයෙන් ප්‍රමාණවත් තරම් ඉදිරියෙන් සිටින විට ක්‍රියාවලිය නවතන්න, එවිට එය අඩු සම්පත් ප්‍රමානයක් පරිභෝජනය කරයි. නිතර මගහරිමින් නොබලන විට මෙය වඩාත් ප්‍රයෝජනවත් වේ. ඔබ ධාවන ගැටළු අත්විඳින්නේ නම් මෙය අක්‍රිය කරන්න.","AllowCollectionManagement":"එකතු කළමනාකරණය කිරීමට මෙම පරිශීලකයාට ඉඩ දෙන්න","AddToPlayQueue":"වාදන පෝලිමට එකතු කරන්න","AgeValue":"(වයස {0})","AirDate":"විකාශන දිනය","Aired":"විකාශනය කරන ලදී","Album":"ඇල්බමය","AlbumArtist":"ඇල්බම කලාකරු","Albums":"ඇල්බම","Alerts":"ඇඟවීම්","All":"සියලුම","AllChannels":"සියලුම නාලිකා","AllComplexFormats":"සියලුම සංකීර්ණ ආකෘති (ASS, SSA, VobSub, PGS, SUB, IDX, …)","AllEpisodes":"සියලුම කථාංග","AllowedRemoteAddressesHelp":"දුරස්ථව සම්බන්ධ වීමට ඉඩ දෙන ජාල සඳහා කොමාවෙන් වෙන් කළ IP ලිපින ලැයිස්තුව හෝ IP/netmask ඇතුළත් කිරීම්. හිස්ව තැබුවහොත්, සියලු දුරස්ථ ලිපිනවලට ඉඩ දෙනු ලැබේ.","AllowSegmentDeletion":"මේ කොටස මකන්න","AllowSegmentDeletionHelp":"client වෙත යැවීමෙන් පසු පැරණි කොටස් මකන්න. මෙය සම්පූර්ණ ට්‍රාන්ස්කෝඩ් ගොනුව තැටියේ ගබඩා කිරීම වළක්වයි. ක්‍රියා කරන්නේ තෙරපුම සක්‍රීය කර පමණි. ඔබ පසුධාවන ගැටළු අත්විඳින්නේ නම් මෙය අක්‍රිය කරන්න."}')}}]);