"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[38155],{97652:function(t,e,a){a.r(e),e.default='<div data-role="page" class="page standalonePage forgotPasswordPinPage"> <div class="padded-left padded-right padded-bottom-page"> <form class="forgotPasswordPinForm" style="text-align:center;margin:0 auto"> <div style="text-align:left"> <h2>${HeaderPasswordReset}</h2> <div class="inputContainer"> <input is="emby-input" type="text" id="txtPin" label="${LabelPasswordRecoveryPinCode}" autocomplete="off" required="required"/> </div> <div> <button is="emby-button" type="submit" class="raised submit block"> <span>${ButtonSubmit}</span> </button> <button is="emby-button" type="button" class="raised cancel block btnCancel" onclick="history.back()"> <span>${ButtonCancel}</span> </button> </div> </div> </form> </div> </div> '}}]);