"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[22424],{22424:function(n,o,i){i.r(o);var e,r=i(39738),t=i(46782),c=i(44797);function a(){e=!0}function l(n){e=!1,console.error("error locking orientation: "+n)}c.A.on(r.f,"playbackstart",(function(n,o){if(o.isLocalPlayer&&!o.isExternalPlayer&&r.f.isPlayingVideo(o)&&t.A.mobile){var i,c=window.screen.lockOrientation||window.screen.mozLockOrientation||window.screen.msLockOrientation||(null===(i=window.screen.orientation)||void 0===i?void 0:i.lock);if(c)try{var s=c("landscape");s.then?s.then(a,l):e=s}catch(n){l(n)}}})),c.A.on(r.f,"playbackstop",(function(n,o){if(e&&!o.nextMediaType){var i,r=window.screen.unlockOrientation||window.screen.mozUnlockOrientation||window.screen.msUnlockOrientation||(null===(i=window.screen.orientation)||void 0===i?void 0:i.unlock);if(r){try{r()}catch(n){console.error("error unlocking orientation: "+n)}e=!1}}}))}}]);