"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[70884],{86086:function(e,t,r){r.r(t),r.d(t,{default:function(){return i}});var s=r(5898),a=r(89100);function n(e){if(e.Success){var t=s.Ay.translate("MessagePasswordResetForUsers");return t+="<br/>",t+="<br/>",t+=e.UsersReset.join("<br/>"),void a.default.alert({message:t,title:s.Ay.translate("HeaderPasswordReset"),callback:function(){window.location.href=""}})}a.default.alert({message:s.Ay.translate("MessageInvalidForgotPasswordPin"),title:s.Ay.translate("HeaderPasswordReset")})}function i(e){e.querySelector("form").addEventListener("submit",(function(t){return ApiClient.ajax({type:"POST",url:ApiClient.getUrl("Users/ForgotPassword/Pin"),dataType:"json",data:JSON.stringify({Pin:e.querySelector("#txtPin").value}),contentType:"application/json"}).then(n),t.preventDefault(),!1})),e.querySelector("#txtPin").focus()}}}]);