(self.webpackChunk=self.webpackChunk||[]).push([[10807,33188,65202],{10564:function(e){function t(r){return e.exports=t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},e.exports.__esModule=!0,e.exports.default=e.exports,t(r)}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports},33188:function(e,t,r){"use strict";r(36947),r(78557),r(73687);var o=r(96784).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e){(0,a.default)(1,arguments);var t=Object.prototype.toString.call(e);return e instanceof Date||"object"===(0,n.default)(e)&&"[object Date]"===t?new Date(e.getTime()):"number"==typeof e||"[object Number]"===t?new Date(e):("string"!=typeof e&&"[object String]"!==t||"undefined"==typeof console||(console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#string-arguments"),console.warn((new Error).stack)),new Date(NaN))};var n=o(r(10564)),a=o(r(23058));e.exports=t.default},65202:function(e,t,r){"use strict";r(36947);var o=r(96784).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n=o(r(33188)),a=o(r(56974)),s=["неделя","понеделник","вторник","сряда","четвъртък","петък","събота"];function u(e){var t=s[e];return 2===e?"'във "+t+" в' p":"'в "+t+" в' p"}var c={lastWeek:function(e,t,r){var o=(0,n.default)(e),c=o.getUTCDay();return(0,a.default)(o,t,r)?u(c):function(e){var t=s[e];switch(e){case 0:case 3:case 6:return"'миналата "+t+" в' p";case 1:case 2:case 4:case 5:return"'миналия "+t+" в' p"}}(c)},yesterday:"'вчера в' p",today:"'днес в' p",tomorrow:"'утре в' p",nextWeek:function(e,t,r){var o=(0,n.default)(e),c=o.getUTCDay();return(0,a.default)(o,t,r)?u(c):function(e){var t=s[e];switch(e){case 0:case 3:case 6:return"'следващата "+t+" в' p";case 1:case 2:case 4:case 5:return"'следващия "+t+" в' p"}}(c)},other:"P"};t.default=function(e,t,r,o){var n=c[e];return"function"==typeof n?n(t,r,o):n},e.exports=t.default},96784:function(e){e.exports=function(e){return e&&e.__esModule?e:{default:e}},e.exports.__esModule=!0,e.exports.default=e.exports}}]);