#pdfPlayer{background:#fff;height:100%;overflow:none;position:relative;width:100%;z-index:100}#pdfPlayer #canvas{display:block;margin:auto}#pdfPlayer .actionButtons{position:absolute;right:.5vh;top:.5vh;z-index:1002}#pdfPlayer .actionButtonIcon{color:#000;opacity:.7}
