.emby-scrollbuttons{-webkit-align-items:center;align-items:center;color:#fff;display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center;min-height:24px;min-width:104px;padding-top:.85em;position:absolute;top:0;z-index:1}[dir=ltr] .emby-scrollbuttons{right:0}[dir=rtl] .emby-scrollbuttons{left:0}.emby-scrollbuttons-button>.material-icons{display:block;min-height:24px;min-width:24px}
