"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[7389],{7389:function(e,t,u){u(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"'ўтган' eeee p 'да'",yesterday:"'кеча' p 'да'",today:"'бугун' p 'да'",tomorrow:"'эртага' p 'да'",nextWeek:"eeee p 'да'",other:"P"};t.default=function(e,t,u,r){return o[e]},e.exports=t.default}}]);