"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[68672],{68104:function(t,o,e){e.r(o),o.default='<div class="topButtons"> <button is="paper-icon-button-light" id="btnBookplayerToc" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon toc" aria-hidden="true"></span> </button> <button is="paper-icon-button-light" id="btnBookplayerPrev" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon navigate_before" aria-hidden="true"></span> </button> <button is="paper-icon-button-light" id="btnBookplayerNext" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon navigate_next" aria-hidden="true"></span> </button> <button is="paper-icon-button-light" id="btnBookplayerExit" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon close" aria-hidden="true"></span> </button> <button is="paper-icon-button-light" id="btnBookplayerRotateTheme" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon remove_red_eye" aria-hidden="true"></span> </button> <button is="paper-icon-button-light" id="btnBookplayerDecreaseFontSize" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon text_decrease" aria-hidden="true"></span> </button> <button is="paper-icon-button-light" id="btnBookplayerIncreaseFontSize" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon text_increase" aria-hidden="true"></span> </button> <button is="paper-icon-button-light" id="btnBookplayerFullscreen" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon fullscreen" aria-hidden="true"></span> </button> </div> <div id="bookPlayerContainer" class="bookPlayerContainer"></div> '}}]);