"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[77236],{77236:function(e,t,u){u(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"先週のeeeeのp",yesterday:"昨日のp",today:"今日のp",tomorrow:"明日のp",nextWeek:"翌週のeeeeのp",other:"P"};t.default=function(e,t,u,r){return o[e]},e.exports=t.default}}]);