"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[80106],{80106:function(e,t,u){u(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var d={lastWeek:"'sonuncu' eeee p -'də'",yesterday:"'dünən' p -'də'",today:"'bugün' p -'də'",tomorrow:"'sabah' p -'də'",nextWeek:"eeee p -'də'",other:"P"};t.default=function(e,t,u,n){return d[e]},e.exports=t.default}}]);