"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[98216],{98216:function(e,l,t){t(36947),Object.defineProperty(l,"__esModule",{value:!0}),l.default=void 0;var n={lastWeek:"'eelmine' eeee 'kell' p",yesterday:"'eile kell' p",today:"'täna kell' p",tomorrow:"'homme kell' p",nextWeek:"'järgmine' eeee 'kell' p",other:"P"};l.default=function(e,l,t,o){return n[e]},e.exports=l.default}}]);