.subtitleEditor-dropZone{-webkit-align-items:center;align-items:center;border:.2em dashed currentcolor;border-radius:.25em;display:-webkit-flex;display:flex;height:12em;-webkit-justify-content:center;justify-content:center;position:relative;text-align:center}.raised.raised-mini.btnBrowse{margin-left:1.5em}
