"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[2917],{2917:function(e,t,r){r(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var l={lastWeek:"'førre' eeee 'kl.' p",yesterday:"'i går kl.' p",today:"'i dag kl.' p",tomorrow:"'i morgon kl.' p",nextWeek:"EEEE 'kl.' p",other:"P"};t.default=function(e,t,r,o){return l[e]},e.exports=t.default}}]);