.playerStats{background:rgba(28,28,28,.8);border-radius:.3em;color:#fff;position:absolute;top:5em}[dir=ltr] .playerStats{left:1.5em}[dir=rtl] .playerStats{right:1.5em}.playerStats-tv{top:4em}.playerStats-content{font-size:84%;position:relative}.playerStats-content-tv{font-size:60%}.playerStats-closeButton{color:#ccc;position:absolute;right:.25em;top:.25em;z-index:1}.playerStats-stats{display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;max-width:50em;overflow:hidden}[dir=ltr] .playerStats-stats{padding:0 3em 1em 1em}[dir=rtl] .playerStats-stats{padding:0 1em 1em 3em}.playerStats-stat{display:-webkit-flex;display:flex}[dir=ltr] .playerStats-stat{margin-left:1em}[dir=rtl] .playerStats-stat{margin-right:1em}.playerStats-stat-label{font-weight:500}[dir=ltr] .playerStats-stat-label{margin:0 .5em 0 0}[dir=rtl] .playerStats-stat-label{margin:0 0 0 .5em}[dir=ltr] .playerStats-stat-header{margin:1em 1em 0 0}[dir=rtl] .playerStats-stat-header{margin:1em 0 0 1em}.playerStats-stat-value{color:#ddd}
