@media (min-width:900px){.dashboardDocument .mainAnimatedPage:not(.metadataEditorPage){left:240px}}.dashboardDocument .skinBody{position:static!important}.dashboardDocument .content-primary{padding-top:3.25rem}.dashboardDocument .withTabs .content-primary{padding-top:6.5rem}@media (min-width:1200px){.dashboardDocument .withTabs .content-primary{padding-top:3.25rem}}.dashboardDocument .metadataEditorPage{padding-top:3.25rem!important}
