"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[16566],{16566:function(e,t,l){l(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r={lastWeek:"'sidste' eeee 'kl.' p",yesterday:"'i går kl.' p",today:"'i dag kl.' p",tomorrow:"'i morgen kl.' p",nextWeek:"'på' eeee 'kl.' p",other:"P"};t.default=function(e,t,l,o){return r[e]},e.exports=t.default}}]);