.youtubePlayerContainer{-webkit-align-items:center;align-items:center;background:#000!important;bottom:0;display:-webkit-flex;display:flex;left:0;position:fixed!important;right:0;top:0}.youtubePlayerContainer.onTop{z-index:1000}.youtubePlayerContainer video{height:100%;margin:0!important;padding:0!important;width:100%}
