(self.webpackChunk=self.webpackChunk||[]).push([[4665,7184,15126,15141,27046,37522,49427,71808,83518],{7184:function(i,a,t){"use strict";t(89336),t(36947),t(95021),t(53819),Object.defineProperty(a,"__esModule",{value:!0}),a.default=function(i){return function(a){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},e=t.width,r=e&&i.matchPatterns[e]||i.matchPatterns[i.defaultMatchWidth],n=a.match(r);if(!n)return null;var l,u=n[0],d=e&&i.parsePatterns[e]||i.parsePatterns[i.defaultParseWidth],s=Array.isArray(d)?function(i){for(var a=0;a<i.length;a++)if(i[a].test(u))return a}(d):function(i){for(var a in i)if(i.hasOwnProperty(a)&&i[a].test(u))return a}(d);return l=i.valueCallback?i.valueCallback(s):s,{value:l=t.valueCallback?t.valueCallback(l):l,rest:a.slice(u.length)}}},i.exports=a.default},15126:function(i,a,t){"use strict";t(36947),t(96054);var e=t(96784).default;Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var r=e(t(7184)),n={ordinalNumber:(0,e(t(83518)).default)({matchPattern:/\d+/i,parsePattern:/\d+/i,valueCallback:function(i){return parseInt(i,10)}}),era:(0,r.default)({matchPatterns:{narrow:/^(нтө|нт)/i,abbreviated:/^(нтө|нт)/i,wide:/^(нийтийн тооллын өмнө|нийтийн тооллын)/i},defaultMatchWidth:"wide",parsePatterns:{any:[/^(нтө|нийтийн тооллын өмнө)/i,/^(нт|нийтийн тооллын)/i]},defaultParseWidth:"any"}),quarter:(0,r.default)({matchPatterns:{narrow:/^(iv|iii|ii|i)/i,abbreviated:/^(iv|iii|ii|i) улирал/i,wide:/^[1-4]-р улирал/i},defaultMatchWidth:"wide",parsePatterns:{any:[/^(i(\s|$)|1)/i,/^(ii(\s|$)|2)/i,/^(iii(\s|$)|3)/i,/^(iv(\s|$)|4)/i]},defaultParseWidth:"any",valueCallback:function(i){return i+1}}),month:(0,r.default)({matchPatterns:{narrow:/^(xii|xi|x|ix|viii|vii|vi|v|iv|iii|ii|i)/i,abbreviated:/^(1-р сар|2-р сар|3-р сар|4-р сар|5-р сар|6-р сар|7-р сар|8-р сар|9-р сар|10-р сар|11-р сар|12-р сар)/i,wide:/^(нэгдүгээр сар|хоёрдугаар сар|гуравдугаар сар|дөрөвдүгээр сар|тавдугаар сар|зургаадугаар сар|долоодугаар сар|наймдугаар сар|есдүгээр сар|аравдугаар сар|арван нэгдүгээр сар|арван хоёрдугаар сар)/i},defaultMatchWidth:"wide",parsePatterns:{narrow:[/^i$/i,/^ii$/i,/^iii$/i,/^iv$/i,/^v$/i,/^vi$/i,/^vii$/i,/^viii$/i,/^ix$/i,/^x$/i,/^xi$/i,/^xii$/i],any:[/^(1|нэгдүгээр)/i,/^(2|хоёрдугаар)/i,/^(3|гуравдугаар)/i,/^(4|дөрөвдүгээр)/i,/^(5|тавдугаар)/i,/^(6|зургаадугаар)/i,/^(7|долоодугаар)/i,/^(8|наймдугаар)/i,/^(9|есдүгээр)/i,/^(10|аравдугаар)/i,/^(11|арван нэгдүгээр)/i,/^(12|арван хоёрдугаар)/i]},defaultParseWidth:"any"}),day:(0,r.default)({matchPatterns:{narrow:/^[ндмлпбб]/i,short:/^(ня|да|мя|лх|пү|ба|бя)/i,abbreviated:/^(ням|дав|мяг|лха|пүр|баа|бям)/i,wide:/^(ням|даваа|мягмар|лхагва|пүрэв|баасан|бямба)/i},defaultMatchWidth:"wide",parsePatterns:{narrow:[/^н/i,/^д/i,/^м/i,/^л/i,/^п/i,/^б/i,/^б/i],any:[/^ня/i,/^да/i,/^мя/i,/^лх/i,/^пү/i,/^ба/i,/^бя/i]},defaultParseWidth:"any"}),dayPeriod:(0,r.default)({matchPatterns:{narrow:/^(ү\.ө\.|ү\.х\.|шөнө дунд|үд дунд|өглөө|өдөр|орой|шөнө)/i,any:/^(ү\.ө\.|ү\.х\.|шөнө дунд|үд дунд|өглөө|өдөр|орой|шөнө)/i},defaultMatchWidth:"any",parsePatterns:{any:{am:/^ү\.ө\./i,pm:/^ү\.х\./i,midnight:/^шөнө дунд/i,noon:/^үд дунд/i,morning:/өглөө/i,afternoon:/өдөр/i,evening:/орой/i,night:/шөнө/i}},defaultParseWidth:"any"})};a.default=n,i.exports=a.default},83518:function(i,a,t){"use strict";t(89336),t(36947),t(95021),t(53819),Object.defineProperty(a,"__esModule",{value:!0}),a.default=function(i){return function(a){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},e=a.match(i.matchPattern);if(!e)return null;var r=e[0],n=a.match(i.parsePattern);if(!n)return null;var l=i.valueCallback?i.valueCallback(n[0]):n[0];return{value:l=t.valueCallback?t.valueCallback(l):l,rest:a.slice(r.length)}}},i.exports=a.default},96784:function(i){i.exports=function(i){return i&&i.__esModule?i:{default:i}},i.exports.__esModule=!0,i.exports.default=i.exports}}]);