"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[86040],{53286:function(e,t,r){r.r(t),r(29305),r(32733),r(84701),r(81678),r(44962),r(4754),r(94),r(36947),r(78557),r(90076),r(83994),r(82367);var n=r(67430),o=r(82885),i=r(38783);function s(e){return s="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},s(e)}function a(e,t){for(var r=0;r<t.length;r++){var n=t[r];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,u(n.key),n)}}function u(e){var t=function(e){if("object"!=s(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var r=t.call(e,"string");if("object"!=s(r))return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==s(t)?t:t+""}var c=function(){return e=function e(){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e),this.name="BackdropScreensaver",this.type=i.Q.Screensaver,this.id="backdropscreensaver",this.supportsAnonymous=!1},(t=[{key:"show",value:function(){var e=this,t=n.tF.currentApiClient();t.getItems(t.getCurrentUserId(),{ImageTypes:"Backdrop",EnableImageTypes:"Backdrop",IncludeItemTypes:"Movie,Series,MusicArtist",SortBy:"Random",Recursive:!0,Fields:"Taglines",ImageTypeLimit:10,StartIndex:0,Limit:200}).then((function(t){t.Items.length&&r.e(27884).then(r.bind(r,27884)).then((function(r){var n=new(0,r.default)({showTitle:!0,cover:!0,items:t.Items,autoplay:{delay:1e3*o.backdropScreensaverInterval()}});n.show(),e.currentSlideshow=n})).catch(console.error)}))}},{key:"hide",value:function(){return this.currentSlideshow&&(this.currentSlideshow.hide(),this.currentSlideshow=null),Promise.resolve()}}])&&a(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e;var e,t}();t.default=c}}]);