"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[18119,66884],{66242:function(e,t,n){n.r(t),n(29305),n(32733),n(84701),n(81678),n(44962),n(4754),n(94),n(36947),n(78557),n(90076),n(45309),n(83994),n(82367);var i=n(82885),o=n(8566),r=n(9164),s=n(56213),u=n(67430);function c(e){return c="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},c(e)}function a(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,l(i.key),i)}}function l(e){var t=function(e){if("object"!=c(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=c(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==c(t)?t:t+""}n(1177);var f=function(){return e=function e(t,n){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e),this.view=t,this.params=n,this.apiClient=u.tF.currentApiClient(),this.sectionsContainer=t.querySelector(".sections"),t.querySelector(".sections").addEventListener("settingschange",y.bind(this))},(t=[{key:"onResume",value:function(e){if(this.sectionsRendered){var t=this.sectionsContainer;return t?s.Ay.resume(t,e):Promise.resolve()}o.Ay.show();var n=this.view,u=this.apiClient;return this.destroyHomeSections(),this.sectionsRendered=!0,u.getCurrentUser().then((function(e){return s.Ay.loadSections(n.querySelector(".sections"),u,e,i)})).then((function(){e.autoFocus&&r.A.autoFocus(n)})).catch((function(e){console.error(e)})).finally((function(){o.Ay.hide()}))}},{key:"onPause",value:function(){var e=this.sectionsContainer;e&&s.Ay.pause(e)}},{key:"destroy",value:function(){this.view=null,this.params=null,this.apiClient=null,this.destroyHomeSections(),this.sectionsContainer=null}},{key:"destroyHomeSections",value:function(){var e=this.sectionsContainer;e&&s.Ay.destroySections(e)}}])&&a(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e;var e,t}();function y(){this.sectionsRendered=!1,this.paused||this.onResume({refresh:!0})}t.default=f}}]);