@-webkit-keyframes fadein{0%{opacity:0}to{opacity:1}}@keyframes fadein{0%{opacity:0}to{opacity:1}}.lazy-image-fadein{-webkit-animation:fadein .5s;animation:fadein .5s;opacity:1}.lazy-image-fadein-fast{-webkit-animation:fadein .1s;animation:fadein .1s;opacity:1}.lazy-hidden,.lazy-hidden-children *{opacity:0}.blurhash-canvas{bottom:0;height:100%;left:0;pointer-events:none;position:absolute;right:0;top:0;width:100%}
.imageEditor-buttons{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;margin:1em 0 1em}.first-imageEditor-buttons{margin-top:2em}[dir=ltr] .btnBrowseAllImages{margin-left:1em}[dir=rtl] .btnBrowseAllImages{margin-right:1em}[dir=ltr] .btnOpenUploadMenu{margin-left:.5em}[dir=rtl] .btnOpenUploadMenu{margin-right:.5em}
