"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[21721],{21721:function(e,t,a){a(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r={lastWeek:"'Praėjusį' eeee p",yesterday:"'Vakar' p",today:"'Šiandien' p",tomorrow:"'Rytoj' p",nextWeek:"eeee p",other:"P"};t.default=function(e,t,a,u){return r[e]},e.exports=t.default}}]);