"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[85960],{82379:function(e){e.exports=JSON.parse('{"Add":"Keworra","AddToPlaylist":"Keworra dhe rol-gwari","AirPlay":"GwariAyr","AlbumArtist":"Artydh Albom","AllEpisodes":"Towlennow oll","AllLanguages":"Yethow oll","Ascending":"Yskynnus","Authorize":"Gasa","Banner":"Baner","BirthDateValue":"Genys: {0}","Books":"Lyvrow","Box":"Kist","BoxSet":"Kist Rol","ButtonAddScheduledTaskTrigger":"Keworra Skila","ButtonAddUser":"Keworra Devnydhyer","ButtonArrowRight":"Dyghow","Absolute":"Purra","AgeValue":"({0} bloodh)","Actor":"Gwarier","AddedOnValue":"Keworras {0}","AddToCollection":"Keworra dhe guntel","AllChannels":"Kanolyow oll","AddToFavorites":"Keworra dhe guntel drudh","AddToPlayQueue":"Keworra dhe lost gwari","AllLibraries":"Lyvervaow oll","AirDate":"Dydh gwari","Aired":"Gwarys","Album":"Albom","Albums":"Albomow","Alerts":"Gwarnyansow","All":"Oll","AllComplexFormats":"Furvasow komplek oll (ASS, SSA, VobSub, PGS, SUB, IDX, …)","Photos":"Skeusennow","Playlists":"Rolyow-gwari","ValueSpecialEpisodeName":"Arbennik - {0}","Artists":"Artyhdyon","ButtonArrowLeft":"Kledh","AsManyAsPossible":"Mar lies avel galadow","Audio":"Klewans","Author":"Awtour","Auto":"Awto","Backdrop":"Keynlen","BirthLocation":"Genesigva","Blacklist":"Rol-dhu","ButtonAddImage":"Keworra Imach","Backdrops":"Keynlennow","BackdropScreensaver":"Gwitherskrin Keynlen","BirthPlaceValue":"Genesigva: {0}","BoxRear":"Kist (a-dryv)","Browse":"Peuri","ButtonActivate":"Bywhe","ButtonAddMediaLibrary":"Keworra Lyverva Media","ButtonAddServer":"Keworra Servell","ButtonAudioTracks":"Hynsow Klewans","Channels":"Kanolyow","Default":"Defowt","General":"Ollgemmyn","Genre":"Eghen","Guide":"Gid","GuideProviderLogin":"Omgelmi","HeaderAdmin":"Menystrans","HeaderAlert":"Gwarnyans","HeaderError":"Kamm","HeaderFrequentlyPlayed":"Gwarys Yn Fenowgh","TypeOptionPluralMusicVideo":"Gwydhyow Ilow","Folders":"Plegellow","Collections":"Kuntellow","Genres":"Eghennow","MediaInfoDefault":"Defowt","Favorites":"Moyha Kerys","Songs":"Kanow","HeaderAlbumArtists":"Albom artydhyon","LabelAlbumArtists":"Albom artydhyon","Movies":"Fylmow","HeaderContinueWatching":"Pesya Ow Kweles","ContinueWatching":"Pesya Ow Kweles","HeaderForKids":"Rag Fleghes","TypeOptionPluralMovie":"Fylmow","MusicVideos":"Gwydhyow Ilow","HeaderActivity":"Gwrians","Shows":"Diskwedhyansow","Friday":"Dy\'Gwener","HeaderDevices":"Devisyow","HeaderApp":"App","HeaderBranding":"Merkyans","LogLevel.Error":"Kamm","HeaderDVR":"DVR","HeaderLibraries":"Lyvervaow","HeaderInstall":"Ynstallya","HeaderMedia":"Media","HeaderNextItem":"Nessa {0}","LabelMetadata":"Metamanylyon","Metadata":"Metamanylyon","AllowCollectionManagement":"Gasa an devnydhyer ma dhe venystra kuntellow","AccessRestrictedTryAgainLater":"Strothys yw hedhas y\'n eur na. Assay arta diwettha, mar pleg."}')}}]);