"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[94726],{837:function(a){a.exports=JSON.parse('{"Add":"Ampio","AddToPlaylist":"Ampiana ao amin\'ny playlist","AddToPlayQueue":"Ampiana ao amin\'ny filaharana","AirDate":"Daty nivoahana","Aired":"Nivoaka","AlbumArtist":"Mpanakanto tompon\'ny Album","Alerts":"Fanairana","AllChannels":"Fahitalavitra rehetra","AllowMediaConversion":"Avela hiasa hanao famadiahana format","AllowEmbeddedSubtitlesAllowNoneOption":"Tsy asiana mihitsy","AllowEmbeddedSubtitlesAllowTextOption":"Asiana soratra","Absolute":"Feno","AccessRestrictedTryAgainLater":"Voafetra ny fidirana amin\'izao fotoana izao. Andramo indray afaka fotoana fohy.","Actor":"Mpilalao","AddedOnValue":"Nampiana {0}","AdditionalNotificationServices":"Tsidiho ny katalaogin\'ny plugin raha hanampy serivisy fampahafantarana fanampiny.","AddToCollection":"Ampiana ao amin\'ny tambatra","AddToFavorites":"Ampiana ao amin\'ireo ankafizina","AgeValue":"({0} taona)","Album":"Album","Albums":"Albums","All":"Rehetra","AllComplexFormats":"Ireo endrika sarotra rehetra (ASS, SSA, VobSub, PGS, SUB, IDX, …)","AllEpisodes":"Fizaràna rehetra","AllLanguages":"Teny rehetra","AllLibraries":"Tahiry rehetra","AllowedRemoteAddressesHelp":"Lisitry ny adiresy IP na IP/netmask nosarahan\'ny faingo ho an\'ny tambajotra izay faka hifandray lavitra. Raha banga dia avela miditra avokoa ny IP rehetra.","AllowEmbeddedSubtitles":"Atsahatra ny karazana dikanteny ao anatiny","AllowEmbeddedSubtitlesAllowAllOption":"Avela malalaka","AllowEmbeddedSubtitlesAllowImageOption":"Asiana sary","AllowEmbeddedSubtitlesHelp":"Atsahatra ny dikanteny raikitra ao anaty media. Mila fanavaozana ny tahiry rehetra.","AllowFfmpegThrottling":"Ahena ny asa famadihana format","AllowFfmpegThrottlingHelp":"Rehefa lasa lavitra mihoatra ny playback ny asa famadihana endrika dia atsahatra kely ny fampiasana CPU. Tena ilaina izany rehefa mijery fotsiny fa tsy mandingana na mamerina matetika. Aza atao raha mahita olana amin\'ny playback.","AllowHevcEncoding":"Avela hamadika format HEVC","AllowHWTranscodingHelp":"Avela ny tuner hiasa sady mamadika format. Mety hanampy amin\'ny fampihenana ny asa takian\'ny serveur izany.","AllowMediaConversionHelp":"Avela na lavina ny fidirana amin\'ny asa famadihana format.","AllowOnTheFlySubtitleExtraction":"Avela hamaky dikanteny eny ampandehanana","AllowOnTheFlySubtitleExtractionHelp":"Azo alaina avy amin\'ilay video ny dikanteny ao anatiny ary aseho amin\'ny soratra tsotra, mba hisorohana ny famadihana video. Mety haharitra ela izany ka hampiato ny famakiana horonan-tsary mandritra ny dingan\'ny fitrandrahana. Atsaharo raha avela ho dikanteny miaraka amin\'ny famadihana horonan-tsary.","AllowRemoteAccess":"Avela hifandray amin\'ny hafa ity serveur ity","AllowRemoteAccessHelp":"Raha tsy marihina dia ho voasakana ny fifandraisana lavitra rehetra.","AllowCollectionManagement":"Afaka manamboatra ny fitambarana ity mpampiasa ity","AllowSegmentDeletion":"Vonoy ny sombiny","AllowSegmentDeletionHelp":"Vonoy ny sombiny efa lany andro rehefa lasa any amin\'ny mpanjifa. Manampy ity satria tsy mameno ny vata ny sombiny feno. Tsy misy fiantraikany ity rehefa tsy manao throttling. Aza atao ity raha misy olana ny fisosan\'ny jery.","LabelThrottleDelaySeconds":"Amboary ny hafainganan\'ny sosa rehefa feno"}')}}]);