"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[6157],{6157:function(e,t,r){r.r(t),r.d(t,{default:function(){return d}}),r(77575);var n=r(24468),a=r(76542),i=r(8566),o=r(76942),l=r(89100);function s(e,t,r,i){if(e){t.length?e.classList.remove("hide"):e.classList.add("hide");var l=e.querySelector(".recordingItems");i?(l.classList.add("scrollX"),l.classList.add("hiddenScrollX"),l.classList.remove("vertical-wrap")):(l.classList.remove("scrollX"),l.classList.remove("hiddenScrollX"),l.classList.add("vertical-wrap")),l.innerHTML=n.default.getCardsHtml(Object.assign({items:t,shape:i?"autooverflow":"auto",defaultShape:(0,o.UI)(i),showTitle:!0,showParentTitle:!0,coverImage:!0,cardLayout:!1,centerText:!0,allowBottomPadding:!i,preferThumb:"auto",overlayText:!1},r||{})),a.default.lazyChildren(l)}}function c(){"latest"===this.getAttribute("data-type")&&l.default.navigate("list?type=Recordings&serverId="+ApiClient.serverId())}function d(e,t,r){function n(){return(new Date).getTime()-d>3e5}for(var a,o,d=0,u=r.querySelectorAll(".more"),f=0,h=u.length;f<h;f++)u[f].addEventListener("click",c);this.preRender=function(){n()&&(o=ApiClient.getLiveTvRecordings({UserId:l.default.getCurrentUserId(),Limit:12,Fields:"CanDelete,PrimaryImageAspectRatio",EnableTotalRecordCount:!1,EnableImageTypes:"Primary,Thumb,Backdrop"}),a=ApiClient.getRecordingFolders(l.default.getCurrentUserId()))},this.renderTab=function(){var e;n()&&(i.Ay.show(),e=r,o.then((function(t){s(e.querySelector("#latestRecordings"),t.Items,{showYear:!0,lines:2},!1),i.Ay.hide()})),function(e,t){t.then((function(t){s(e.querySelector("#recordingFolders"),t.Items,{showYear:!1,showParentTitle:!1},!1)}))}(r,a),d=(new Date).getTime())}}r(22777),r(1177)},22777:function(e,t,r){r.d(t,{i:function(){return c}}),r(29305),r(32733),r(84701),r(69892),r(44962),r(86584),r(89336),r(78557),r(90076),r(95021),r(73687),r(83994),r(82367);var n=r(24468),a=r(46782),i=r(76942),o=r(98320);function l(e,t){(null==t||t>e.length)&&(t=e.length);for(var r=0,n=Array(t);r<t;r++)n[r]=e[r];return n}function s(){return!a.A.desktop}function c(e,t){t=t||{};var r,c=[],d="",u=[],f=function(e,t){var r="undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(!r){if(Array.isArray(e)||(r=function(e,t){if(e){if("string"==typeof e)return l(e,t);var r={}.toString.call(e).slice(8,-1);return"Object"===r&&e.constructor&&(r=e.constructor.name),"Map"===r||"Set"===r?Array.from(e):"Arguments"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?l(e,t):void 0}}(e))||t&&e&&"number"==typeof e.length){r&&(e=r);var n=0,a=function(){};return{s:a,n:function(){return n>=e.length?{done:!0}:{done:!1,value:e[n++]}},e:function(e){throw e},f:a}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var i,o=!0,s=!1;return{s:function(){r=r.call(e)},n:function(){var e=r.next();return o=e.done,e},e:function(e){s=!0,i=e},f:function(){try{o||null==r.return||r.return()}finally{if(s)throw i}}}}(e.map((function(e){return e.Type="Timer",e})));try{for(f.s();!(r=f.n()).done;){var h=r.value,m="";if(!1!==t.indexByDate&&h.StartDate)try{var v=o.Ay.parseISO8601Date(h.StartDate,!0);m=o.Ay.toLocaleDateString(v,{weekday:"long",month:"short",day:"numeric"})}catch(e){console.error("error parsing premiereDate:"+h.StartDate+"; error: "+e)}m!=d?(u.length&&c.push({name:d,items:u}),d=m,u=[h]):u.push(h)}}catch(e){f.e(e)}finally{f.f()}u.length&&c.push({name:d,items:u});for(var p="",y=0,g=c;y<g.length;y++){var w=g[y];if(w.name&&(p+='<div class="verticalSection">',p+='<h2 class="sectionTitle sectionTitle-cards padded-left">'+w.name+"</h2>"),s()){var T="scrollX hiddenScrollX";a.A.tv&&(T+=" smoothScrollX"),p+='<div is="emby-itemscontainer" class="itemsContainer '+T+' padded-left padded-right">'}else p+='<div is="emby-itemscontainer" class="itemsContainer vertical-wrap padded-left padded-right">';p+=n.default.getCardsHtml({items:w.items,shape:(0,i.UI)(s()),showTitle:!0,showParentTitleOrTitle:!0,showAirTime:!0,showAirEndTime:!0,showChannelName:!1,cardLayout:!0,centerText:!1,action:"edit",cardFooterAside:"none",preferThumb:!0,defaultShape:null,coverImage:!0,allowBottomPadding:!1,overlayText:!1,showChannelLogo:!0}),p+="</div>",w.name&&(p+="</div>")}return Promise.resolve(p)}}}]);