"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[7046],{7046:function(e,t,n){n(24776),n(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r=["vasárnap","hétfőn","kedden","szerdán","csütörtökön","pénteken","szombaton"];function o(e){return function(t){var n=r[t.getUTCDay()];return"".concat(e?"":"'múlt' ","'").concat(n,"' p'-kor'")}}var a={lastWeek:o(!1),yesterday:"'tegnap' p'-kor'",today:"'ma' p'-kor'",tomorrow:"'holnap' p'-kor'",nextWeek:o(!0),other:"P"};t.default=function(e,t){var n=a[e];return"function"==typeof n?n(t):n},e.exports=t.default}}]);