(self.webpackChunk=self.webpackChunk||[]).push([[28110],{3234:function(e,t,n){var r={"./schedulesdirect.template.html":[44717,44717],"./xmltv.template.html":[99049,99049]};function o(e){if(!n.o(r,e))return Promise.resolve().then((function(){var t=new Error("Cannot find module '"+e+"'");throw t.code="MODULE_NOT_FOUND",t}));var t=r[e],o=t[0];return n.e(t[1]).then((function(){return n(o)}))}o.keys=function(){return Object.keys(r)},o.id=3234,e.exports=o},45043:function(e,t,n){"use strict";n.r(t),n(44962),n(78557),n(90076),n(83994),n(82367);var r=n(8566),o=n(5898),i=n(89100),u=n(83375),c=n(44797);function s(){i.default.navigate("dashboard/livetv")}(0,i.pageIdOn)("pageshow","liveTvGuideProviderPage",(function(){r.Ay.show();var e=(0,u.E)("id");!function(e,t,r){n(3234)("./".concat(t,".template.html")).then((function(i){var u=i.default;e.querySelector(".providerTemplate").innerHTML=o.Ay.translateHtml(u),function(e,t,r){n(73547)("./".concat(t)).then((function(t){var n=new(0,t.default)(e,r,{});c.A.on(n,"submitted",s),n.init()}))}(e,t,r)}))}(this,(0,u.E)("type"),e)}))},73547:function(e,t,n){var r={"./schedulesdirect":[1451,1451],"./schedulesdirect.js":[1451,1451],"./schedulesdirect.template.html":[44717,44717],"./style.scss":[12394,12394],"./xmltv":[28463,28463],"./xmltv.js":[28463,28463],"./xmltv.template.html":[99049,99049]};function o(e){if(!n.o(r,e))return Promise.resolve().then((function(){var t=new Error("Cannot find module '"+e+"'");throw t.code="MODULE_NOT_FOUND",t}));var t=r[e],o=t[0];return n.e(t[1]).then((function(){return n(o)}))}o.keys=function(){return Object.keys(r)},o.id=73547,e.exports=o}}]);