.emby-collapse{margin:.5em 0}.collapseContent{border-width:0;height:0;overflow:hidden;padding:1.25em 1.25em;transition-duration:.3s;transition-property:height}.emby-collapsible-button{-webkit-align-items:center;align-items:center;background:transparent;border-style:solid;border-width:0 0 .1em 0;box-shadow:none;display:-webkit-flex;display:flex;margin:0;padding-left:.1em;text-transform:none;width:100%}[dir=ltr] .emby-collapsible-button{padding-left:.1em;text-align:left}[dir=rtl] .emby-collapsible-button{padding-right:.1em;text-align:right}.emby-collapse-expandIcon{font-size:1.5em;position:absolute;-webkit-transform-origin:50% 50%;transform-origin:50% 50%;transition:-webkit-transform .18s ease-out;transition:transform .18s ease-out;transition:transform .18s ease-out,-webkit-transform .18s ease-out}[dir=ltr] .emby-collapse-expandIcon{right:.5em}[dir=rtl] .emby-collapse-expandIcon{left:.5em}.emby-collapse-expandIconExpanded{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.emby-collapsible-title{margin:0;padding:0}
.dynamicFilterDialog{border-radius:0!important;bottom:5%!important;margin-bottom:0!important;margin-right:0!important;margin-top:0!important;max-height:none!important;max-width:none!important;position:fixed!important;top:5%!important}@media (min-height:600px){.dynamicFilterDialog{bottom:25%!important;top:10%!important}}@media (max-width:400px){.dynamicFilterDialog{left:10vw!important;margin-left:0!important;right:10vw!important;width:auto}}@media (min-width:400px){.dynamicFilterDialog{left:50%!important;margin-left:-10.08em!important;width:20.16em}}
.itemSelectionPanel{background-color:rgba(0,0,0,.3);bottom:0;left:0;position:absolute;right:0;top:0;z-index:99998}.selectionCommandsPanel{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;left:0;padding-bottom:1em;padding-left:.5em;position:fixed;right:0;top:0;z-index:99999}@supports(width:max(1px,1px)){.selectionCommandsPanel{padding-left:max(env(safe-area-inset-left),.5em)}}.selectionCommandsPanel{padding-right:.5em}@supports(width:max(1px,1px)){.selectionCommandsPanel{padding-right:max(env(safe-area-inset-right),.5em)}}.selectionCommandsPanel{padding-top:1em}@supports(width:max(1px,1px)){.selectionCommandsPanel{padding-top:max(env(safe-area-inset-top),1em)}}.itemSelectionCount{color:#fff!important;margin:0;vertical-align:middle}.multiSelectCheckboxOutline{border-radius:0!important;top:0!important}.withMultiSelect{position:relative}.btnSelectionPanelOptions{margin-left:auto}
