(self.webpackChunk=self.webpackChunk||[]).push([[82798],{16764:function(n,e,t){t(78557),t(90076),self.addEventListener("notificationclick",(function(n){var e=n.notification;e.close();var t=e.data,i=t.serverId,r=n.action;if(!r)return clients.openWindow("/"),void n.waitUntil(Promise.resolve());n.waitUntil(function(n,e,t){return function(n){return Promise.resolve(window.connectionManager.getApiClient(n))}(t).then((function(t){switch(n){case"cancel-install":return t.cancelPackageInstallation(e.id);case"restart":return t.restartServer();default:return clients.openWindow("/"),Promise.resolve()}}))}(r,t,i))}),!1),self.addEventListener("activate",(function(){return self.clients.claim()}))}},function(n){n.O(0,[59928],(function(){return n(n.s=16764)})),n.O()}]);