[dir=rtl] .arrow_back,[dir=rtl] .arrow_forward,[dir=rtl] .chevron_left,[dir=rtl] .chevron_right,[dir=rtl] .clear_all,[dir=rtl] .dvr,[dir=rtl] .input,[dir=rtl] .message,[dir=rtl] .playlist_add,[dir=rtl] .shopping_cart,[dir=rtl] .shuffle,[dir=rtl] .volume_off,[dir=rtl] .volume_up,[dir=rtl] .vpn_key{-webkit-transform:scaleX(-1);transform:scaleX(-1)}
