"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[68085],{68085:function(e,a,t){t(36947),Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var p={lastWeek:"eeee 'lepas pada jam' p",yesterday:"'Semalam pada jam' p",today:"'Hari ini pada jam' p",tomorrow:"'Esok pada jam' p",nextWeek:"eeee 'pada jam' p",other:"P"};a.default=function(e,a,t,d){return p[e]},e.exports=a.default}}]);