"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[35090],{35090:function(e,a,t){t(36947),Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var u={lastWeek:"'mu dheireadh' eeee 'aig' p",yesterday:"'an-dè aig' p",today:"'an-diugh aig' p",tomorrow:"'a-màireach aig' p",nextWeek:"eeee 'aig' p",other:"P"};a.default=function(e,a,t,i){return u[e]},e.exports=a.default}}]);