"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[81613],{81613:function(e,t,s){s.r(t);var i=s(46782),c=s(34789),a=(s(69177),Object.create(HTMLInputElement.prototype));function d(e){if(13===e.keyCode||32===e.keyCode&&c.A.tizen)return e.preventDefault(),this.checked||(this.checked=!0,this.dispatchEvent(new CustomEvent("change",{bubbles:!0}))),!1}a.attachedCallback=function(){var e=!i.A.mobile;if("true"!==this.getAttribute("data-radio")){this.setAttribute("data-radio","true"),this.classList.add("mdl-radio__button");var t=this.parentNode;t.classList.add("mdl-radio"),t.classList.add("mdl-js-radio"),t.classList.add("mdl-js-ripple-effect"),e&&t.classList.add("show-focus");var s=t.querySelector("span");s.classList.add("radioButtonLabel"),s.classList.add("mdl-radio__label");var c="";c+='<div class="mdl-radio__circles">',c+="<svg>",c+="<defs>",c+='<clipPath id="cutoff">',c+='<circle cx="50%" cy="50%" r="50%" />',c+="</clipPath>",c+="</defs>",c+='<circle class="mdl-radio__outer-circle" cx="50%" cy="50%" r="50%" fill="none" stroke="currentcolor" stroke-width="0.26em" clip-path="url(#cutoff)" />',c+='<circle class="mdl-radio__inner-circle" cx="50%" cy="50%" r="25%" fill="currentcolor" />',c+="</svg>",e&&(c+='<div class="mdl-radio__focus-circle"></div>'),c+="</div>",this.insertAdjacentHTML("afterend",c),this.addEventListener("keydown",d)}},document.registerElement("emby-radio",{prototype:a,extends:"input"})}}]);