"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[52011],{39387:function(e,t,r){r.r(t),r(29305),r(32733),r(84701),r(81678),r(44962),r(4754),r(94),r(36947),r(78557),r(90076),r(45309),r(83994),r(82367);var n=r(22622),o=r(97339);function i(e){return i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},i(e)}function u(e,t){for(var r=0;r<t.length;r++){var n=t[r];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,a(n.key),n)}}function a(e){var t=function(e){if("object"!=i(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var r=t.call(e,"string");if("object"!=i(r))return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==i(t)?t:t+""}var c=function(){return e=function e(){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e)},(t=[{key:"check",value:function(){if(n.g.supports(o.Y.HtmlAudioAutoplay))return Promise.resolve(!0);var e,t=((e=document.createElement("audio")).classList.add("testMediaPlayerAudio"),e.classList.add("hide"),document.body.appendChild(e),e.volume=1,e.src="assets/audio/silence.mp3",e);return t.play().finally((function(){!function(e){e.pause(),e.remove()}(t)}))}}])&&u(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e;var e,t}();t.default=new c}}]);