"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[70118],{7780:function(t,e,n){n.r(e),n.d(e,{default:function(){return f}}),n(29305),n(32733),n(84701),n(81678),n(44962),n(4754),n(94),n(36947),n(78557),n(90076),n(83994),n(82367);var r=n(67430),o=n(38783);function i(t){return i="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},i(t)}function u(t,e){for(var n=0;n<e.length;n++){var r=e[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(t,a(r.key),r)}}function a(t){var e=function(t){if("object"!=i(t)||!t)return t;var e=t[Symbol.toPrimitive];if(void 0!==e){var n=e.call(t,"string");if("object"!=i(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(t)}(t);return"symbol"==i(e)?e:e+""}var f=function(){return t=function t(){!function(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}(this,t),this.name="Photo Player",this.type=o.Q.MediaPlayer,this.id="photoplayer",this.priority=1},(e=[{key:"play",value:function(t){return new Promise((function(e){n.e(27884).then(n.bind(n,27884)).then((function(n){var o=n.default,i=t.startIndex||0;r.tF.currentApiClient().getCurrentUser().then((function(n){new o({showTitle:!1,cover:!1,items:t.items,startIndex:i,interval:11e3,interactive:!0,autoplay:t.autoplay||t.shuffle,user:n}).show(),e()}))}))}))}},{key:"canPlayMediaType",value:function(t){return"photo"===(t||"").toLowerCase()}}])&&u(t.prototype,e),Object.defineProperty(t,"prototype",{writable:!1}),t;var t,e}()}}]);