@-webkit-keyframes fadein{0%{opacity:0}to{opacity:1}}@keyframes fadein{0%{opacity:0}to{opacity:1}}.lazy-image-fadein{-webkit-animation:fadein .5s;animation:fadein .5s;opacity:1}.lazy-image-fadein-fast{-webkit-animation:fadein .1s;animation:fadein .1s;opacity:1}.lazy-hidden,.lazy-hidden-children *{opacity:0}.blurhash-canvas{bottom:0;height:100%;left:0;pointer-events:none;position:absolute;right:0;top:0;width:100%}
.itemProgressBar{background:#333;background:rgba(51,51,51,.8);height:.28em;position:relative}.itemLinearProgress{border-radius:100px;bottom:0;left:0;position:absolute!important;width:100%}.itemProgressBarForeground{bottom:0;position:absolute;top:0}[dir=ltr] .itemProgressBarForeground{left:0}[dir=rtl] .itemProgressBarForeground{right:0}.indicator{-webkit-align-items:center;align-items:center;border-radius:100em;display:-webkit-flex;display:flex;font-weight:500;height:2em;-webkit-justify-content:center;justify-content:center;width:2em}.timerIndicator{color:#cb272a}.timerIndicator-inactive{color:#888}[dir=ltr] .indicator+.indicator{margin-left:.25em}[dir=rtl] .indicator+.indicator{margin-right:.25em}.indicatorIcon{font-size:1.6em;height:auto;width:auto}.countIndicator{font-size:88%;font-weight:500}.countIndicator,.playedIndicator{-webkit-align-items:center;align-items:center;border-radius:100em;box-shadow:0 2px 2px 0 rgba(0,0,0,.14),0 1px 5px 0 rgba(0,0,0,.12),0 3px 1px -2px rgba(0,0,0,.2);color:#fff;display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center}.playedIndicator{font-size:80%}.videoIndicator{-webkit-align-items:center;align-items:center;background:#444;box-shadow:0 2px 2px 0 rgba(0,0,0,.14),0 1px 5px 0 rgba(0,0,0,.12),0 3px 1px -2px rgba(0,0,0,.2);color:#fff;display:-webkit-flex;display:flex;font-size:88%;-webkit-justify-content:center;justify-content:center}.syncIndicator,.videoIndicator{border-radius:100em}.emptySyncIndicator{background:#ccc;color:#333}.missingIndicator,.unairedIndicator{background:#c33;border-radius:100em;color:#fff;font-size:84%;font-weight:500;margin:0 .25em;padding:.25em .5em}
.mediaInfoItem{padding:0}[dir=ltr] .mediaInfoItem{margin:0 1em 0 0}[dir=rtl] .mediaInfoItem{margin:0 0 0 1em}.mediaInfoText{-webkit-align-items:center;align-items:center;border-radius:.25em;display:-webkit-flex;display:flex;font-size:92%;margin:0 .5em 0 0;padding:.22em .5em;white-space:nowrap}.mediaInfoText-upper{text-transform:uppercase}.mediaInfoIconItem{font-size:1.6em;height:auto;margin-right:.6em;width:auto}[dir=ltr] .mediaInfoItem:last-child{margin-right:0}[dir=rtl] .mediaInfoItem:last-child{margin-left:0}.starRatingContainer{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center;vertical-align:middle}.starIcon{color:#f2b01e;font-size:1.4em;height:auto!important;margin-right:.125em;width:auto!important}.mediaInfoCriticRating{-webkit-align-items:center;align-items:center;background-repeat:no-repeat;background-size:auto 1.2em;display:-webkit-flex;display:flex;min-height:1.2em}[dir=ltr] .mediaInfoCriticRating{background-position:0;padding-left:1.5em}[dir=rtl] .mediaInfoCriticRating{background-position:100%;padding-right:1.5em}.mediaInfoCriticRatingFresh{background-image:url(assets/img/fresh.svg)}.mediaInfoCriticRatingRotten{background-image:url(assets/img/rotten.svg)}.mediaInfoProgramAttribute{border-radius:.15em;font-size:80%;padding:.16em .6em;text-transform:uppercase}.closedCaptionMediaInfoText{font-weight:700}
.newTvProgram{background:#38c;color:#fff}.liveTvProgram{background:#c33;color:#fff}.premiereTvProgram{background:#ef6c00;color:#fff}.repeatTvProgram{background:#009688;color:#fff}
.alphaPicker{-webkit-align-self:center;align-self:center;display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;text-align:center}.alphaPicker-vertical{line-height:1}.alphaPicker-fixed{bottom:5.5em;position:fixed}@supports(width:max(1px,1px)){.alphaPicker-fixed{bottom:max(env(safe-area-inset-bottom),5.5em)}}.alphaPickerRow{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;-webkit-flex-direction:row;flex-direction:row;-webkit-justify-content:center;justify-content:center}.alphaPickerRow-vertical{-webkit-flex-direction:column;flex-direction:column}.alphaPickerButton{border:0!important;border-radius:.1em;cursor:pointer;-webkit-flex-grow:1;flex-grow:1;-webkit-flex-shrink:0;flex-shrink:0;font-family:inherit;font-size:inherit;font-weight:400;margin:0;min-width:0;min-width:auto;outline:none!important;padding:.1em .4em;vertical-align:middle;width:auto}@media (max-height:50em){.alphaPicker-fixed{bottom:5em}@supports(width:max(1px,1px)){.alphaPicker-fixed{bottom:max(env(safe-area-inset-bottom),5em)}}.alphaPickerButton-vertical{padding-bottom:1px!important;padding-top:1px!important}}@media (max-height:49em){.alphaPicker-vertical{font-size:94%}}@media (max-height:44em){.alphaPicker-vertical{font-size:90%}.alphaPickerButton-vertical{padding-bottom:0!important;padding-top:0!important}}@media (max-height:37em){.alphaPicker-vertical{font-size:82%}}@media (max-height:32em){.alphaPicker-vertical{font-size:74%}}.alphaPicker-vertical.alphaPicker-tv{font-size:86%}.alphaPickerButton-tv.alphaPickerButton-vertical{padding:0}.alphaPickerButton-vertical{display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center;text-align:center;width:1.5em}.alphaPickerButtonIcon{font-size:100%!important}.alphaPicker-fixed.alphaPicker-tv{bottom:1%}@supports(width:max(1px,1px)){.alphaPicker-fixed.alphaPicker-tv{bottom:max(env(safe-area-inset-bottom),1%)}}[dir=ltr] .alphaPicker-fixed-right{right:.4em}@supports(width:max(1px,1px)){[dir=ltr] .alphaPicker-fixed-right{right:max(env(safe-area-inset-right),.4em)}}[dir=rtl] .alphaPicker-fixed-right{left:.4em}@supports(width:max(1px,1px)){[dir=rtl] .alphaPicker-fixed-right{left:max(env(safe-area-inset-left),.4em)}}@media (min-width:62.5em){[dir=ltr] .alphaPicker-fixed-right{right:1em}@supports(width:max(1px,1px)){[dir=ltr] .alphaPicker-fixed-right{right:max(env(safe-area-inset-right),1em)}}[dir=rtl] .alphaPicker-fixed-right{left:1em}@supports(width:max(1px,1px)){[dir=rtl] .alphaPicker-fixed-right{left:max(env(safe-area-inset-left),1em)}}}@media (max-height:31.25em){.alphaPicker-fixed{display:none!important}}
.btnFilterWithIndicator{position:relative}.filterIndicator{-webkit-align-items:center;align-items:center;background:#03a9f4;border-radius:100em;box-shadow:0 4px 5px 0 rgba(0,0,0,.14),0 1px 10px 0 rgba(0,0,0,.12),0 2px 4px -1px rgba(0,0,0,.2);color:#fff;display:-webkit-flex;display:flex;font-size:60%;font-weight:700;height:1.8em;-webkit-justify-content:center;justify-content:center;position:absolute;right:2px;top:2px;width:1.8em;z-index:1}
