"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[30121],{30121:function(e,t,a){a(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var d={lastWeek:"eeee 'diwethaf am' p",yesterday:"'ddoe am' p",today:"'heddiw am' p",tomorrow:"'yfory am' p",nextWeek:"eeee 'am' p",other:"P"};t.default=function(e,t,a,o){return d[e]},e.exports=t.default}}]);