"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[17420,33796,66884],{85775:function(e,i,o){o.r(i);var t=o(62540),a=o(11444),l=(o(63696),o(37632)),s=o(65242),n=o(99883),c=o(46850),p=o(65369),v=o(4672),r={viewType:c.D.Movies,collectionType:p.X.Movies,isBtnPlayAllEnabled:!0,isBtnShuffleEnabled:!0,itemType:[a.D.Movie]},T={viewType:c.D.Collections,collectionType:p.X.Movies,isBtnFilterEnabled:!1,isBtnNewCollectionEnabled:!0,itemType:[a.D.BoxSet],noItemsMessage:"MessageNoCollectionsAvailable"},y={viewType:c.D.Favorites,collectionType:p.X.Movies,itemType:[a.D.Movie]},b={0:r,1:{viewType:c.D.Suggestions,collectionType:p.X.Movies,sectionsView:v.Nc},2:y,3:T,4:{viewType:c.D.Genres,collectionType:p.X.Movies,itemType:[a.D.Movie]}};i.default=function(){var e=(0,l.A)(),i=e.libraryId,o=e.activeTab,a=b[o];return(0,t.jsx)(s.A,{id:"moviesPage",className:"mainAnimatedPage libraryPage backdropPage collectionEditorPage pageWithAbsoluteTabs withTabs",backDropType:"movie",children:(0,t.jsx)(n.A,{currentTab:a,parentId:i},"".concat(a.viewType," - ").concat(i))})}}}]);