"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[47206],{62885:function(e){e.exports=JSON.parse('{"Actor":"অভিনেতা","Absolute":"নিৰংকুশ","HeaderAlbumArtists":"অ্যালবাম শিল্পী","Albums":"এলবাম","Books":"পুস্তক","Channels":"চেনেলস","Movies":"চলচ্চিত্ৰ","Artists":"শিল্পী","Collections":"সংগ্রহ","Default":"ডিফল্ট","Favorites":"পছন্দসই","Folders":"ফোল্ডাৰ","Genres":"শ্রেণী","HeaderContinueWatching":"দেখা চালিয়ে যান"}')}}]);