"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[15889],{15889:function(e,o,t){t(36947),Object.defineProperty(o,"__esModule",{value:!0}),o.default=void 0;var r={lastWeek:"'vorige' eeee 'om' p",yesterday:"'gisteren om' p",today:"'vandaag om' p",tomorrow:"'morgen om' p",nextWeek:"eeee 'om' p",other:"P"};o.default=function(e,o,t,a){return r[e]},e.exports=o.default}}]);