"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[93969],{93969:function(e,t,n){n(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r={lastWeek:"'të' eeee 'e shkuar në' p",yesterday:"'dje në' p",today:"'sot në' p",tomorrow:"'nesër në' p",nextWeek:"eeee 'at' p",other:"P"};t.default=function(e,t,n,u){return r[e]},e.exports=t.default}}]);