"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[10350],{45581:function(e){e.exports=JSON.parse('{"Album":"البم","Actor":"ئاكتيور","Absolute":"مۇتلەق","ButtonCast":"ئۈسكۈنىگە يوللاش","Channels":"قانال","Books":"كىتاب","Artists":"سەنئەتكار","Albums":"پىلاستىنكا","Collections":"توپلام","Default":"سۈكۈتتىكى","Folders":"ھۆججەت خالتىسى","Favorites":"ساقلىغۇچ","AddedOnValue":"{0} ى قوشۇلدى","Add":"قوشۇش","AccessRestrictedTryAgainLater":"نۆۋەتتە زىيارىتىڭىز چەكلىمىگە ئۇچرىدى. سەل تۇرۇپ قايتا سىناڭ.","ValueSpecialEpisodeName":"خاسلىق - {0}","Sync":"ماس قەدەمدەش","Songs":"ناخشىلار","Shows":"پروگراممىلار","Playlists":"قويۇش تىزىملىكى","Photos":"رەسىملەر","MusicVideos":"سىنلىق مۇزىكا","Movies":"فىلىملەر","HeaderContinueWatching":"داۋاملىق كۆرۈش","HeaderAlbumArtists":"پىلاستىنكا سەنئەتكارلىرى","Genres":"ئۇسلۇبلار","Small":"كىچىك"}')}}]);