"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[68603,96084],{32203:function(e,r,s){s.d(r,{Bq:function(){return o},Jd:function(){return c},yq:function(){return n}});var a=s(65369),i=s(11444),t="assets/img/devices/";function n(e){var r;switch(e.AppName||e.Client){case"Samsung Smart TV":return t+"samsungtv.svg";case"Xbox One":return t+"xbox.svg";case"Sony PS4":return t+"playstation.svg";case"Kodi":case"Kodi JellyCon":return t+"kodi.svg";case"Jellyfin Android":case"AndroidTV":case"Android TV":return t+"android.svg";case"Jellyfin Mobile (iOS)":case"Jellyfin Mobile (iPadOS)":case"Jellyfin iOS":case"Jellyfin iPadOS":case"Jellyfin tvOS":case"Swiftfin iPadOS":case"Swiftfin iOS":case"Swiftfin tvOS":case"Infuse":case"Infuse-Direct":case"Infuse-Library":return t+"apple.svg";case"Home Assistant":return t+"home-assistant.svg";case"Jellyfin for WebOS":case"LG Smart TV":return t+"webos.svg";case"Jellyfin Roku":return t+"roku.svg";case"Finamp":return t+"finamp.svg";case"Jellyfin Web":return function(e){switch(e){case"Opera":case"Opera TV":case"Opera Android":return t+"opera.svg";case"Chrome":case"Chrome Android":return t+"chrome.svg";case"Firefox":case"Firefox Android":return t+"firefox.svg";case"Safari":case"Safari iPad":case"Safari iPhone":return t+"safari.svg";case"Edge Chromium":case"Edge Chromium Android":case"Edge Chromium iPad":case"Edge Chromium iPhone":return t+"edgechromium.svg";case"Edge":return t+"edge.svg";case"Internet Explorer":return t+"msie.svg";case"Titan OS":return t+"titanos.svg";case"Vega OS":return t+"firetv.svg";default:return t+"html5.svg"}}(e.Name||e.DeviceName);default:if(null===(r=e.Capabilities)||void 0===r?void 0:r.IconUrl)try{return new URL(e.Capabilities.IconUrl).toString()}catch(r){console.error("[getDeviceIcon] device capabilities has invalid IconUrl",e,r)}return t+"other.svg"}}function c(e){switch(e){case a.X.Movies:return"movie";case a.X.Music:return"music_note";case a.X.Homevideos:case a.X.Photos:return"photo";case a.X.Livetv:return"live_tv";case a.X.Tvshows:return"tv";case a.X.Trailers:return"theaters";case a.X.Musicvideos:return"music_video";case a.X.Books:return"book";case a.X.Boxsets:return"video_library";case a.X.Playlists:return"queue";case"channels":return"videocam";case void 0:return"quiz";default:return"folder"}}function o(e,r){switch(e){case i.D.MusicAlbum:return"album";case i.D.MusicArtist:case i.D.Person:return"person";case i.D.Audio:return"audiotrack";case i.D.Movie:return"movie";case i.D.Episode:case i.D.Series:return"tv";case i.D.Program:return"live_tv";case i.D.Book:return"book";case i.D.Folder:return"folder";case i.D.BoxSet:return"video_library";case i.D.Playlist:return"queue";case i.D.Photo:return"photo";case i.D.PhotoAlbum:return"photo_album";default:return r}}r.Ay={getDeviceIcon:n,getLibraryIcon:c,getItemTypeIcon:o}}}]);