"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[31421],{31421:function(e,n,t){t(36947),Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var a={lastWeek:"eeee 'pase nan lè' p",yesterday:"'yè nan lè' p",today:"'jodi a' p",tomorrow:"'demen nan lè' p'",nextWeek:"eeee 'pwochen nan lè' p",other:"P"};n.default=function(e,n,t,o){return a[e]},e.exports=n.default}}]);