"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[62654],{62654:function(e,t,o){o(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r={lastWeek:"'verlede' eeee 'om' p",yesterday:"'gister om' p",today:"'vandag om' p",tomorrow:"'môre om' p",nextWeek:"eeee 'om' p",other:"P"};t.default=function(e,t,o,a){return r[e]},e.exports=t.default}}]);