"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[33796,37470,66884],{46365:function(e,i,o){o.r(i);var l=o(62540),a=o(11444),t=(o(63696),o(37632)),n=o(65242),s=o(99883),c=o(46850),d=o(65369),b={0:{viewType:c.D.Photos,collectionType:d.X.Homevideos,isBtnPlayAllEnabled:!0,isBtnShuffleEnabled:!0,itemType:[a.D.Photo]},1:{viewType:c.D.PhotoAlbums,collectionType:d.X.Homevideos,isBtnPlayAllEnabled:!0,isBtnShuffleEnabled:!0,itemType:[a.D.PhotoAlbum]},2:{viewType:c.D.Videos,collectionType:d.X.Homevideos,isBtnPlayAllEnabled:!0,isBtnShuffleEnabled:!0,itemType:[a.D.Video]}};i.default=function(){var e=(0,t.A)(),i=e.libraryId,o=e.activeTab,a=b[o];return(0,l.jsx)(n.A,{id:"homevideos",className:"mainAnimatedPage libraryPage backdropPage collectionEditorPage pageWithAbsoluteTabs withTabs",backDropType:"video, photo",children:(0,l.jsx)(s.A,{currentTab:a,parentId:i},"".concat(a.viewType," - ").concat(i))})}}}]);