"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[85126],{38077:function(t,e,n){n.r(e),n.d(e,{default:function(){return c}});var r=n(8566),u=n(67430);function i(){r.Ay.show();var t=u.tF.currentApiClient();t.ajax({url:t.getUrl("Startup/Complete"),type:"POST"}).then((function(){r.Ay.hide(),window.location.href=""}))}function c(t){t.querySelector(".btnWizardNext").addEventListener("click",i)}}}]);