.emby-collapse{margin:.5em 0}.collapseContent{border-width:0;height:0;overflow:hidden;padding:1.25em 1.25em;transition-duration:.3s;transition-property:height}.emby-collapsible-button{-webkit-align-items:center;align-items:center;background:transparent;border-style:solid;border-width:0 0 .1em 0;box-shadow:none;display:-webkit-flex;display:flex;margin:0;padding-left:.1em;text-transform:none;width:100%}[dir=ltr] .emby-collapsible-button{padding-left:.1em;text-align:left}[dir=rtl] .emby-collapsible-button{padding-right:.1em;text-align:right}.emby-collapse-expandIcon{font-size:1.5em;position:absolute;-webkit-transform-origin:50% 50%;transform-origin:50% 50%;transition:-webkit-transform .18s ease-out;transition:transform .18s ease-out;transition:transform .18s ease-out,-webkit-transform .18s ease-out}[dir=ltr] .emby-collapse-expandIcon{right:.5em}[dir=rtl] .emby-collapse-expandIcon{left:.5em}.emby-collapse-expandIconExpanded{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.emby-collapsible-title{margin:0;padding:0}
.recordingDialog-imageContainer{-webkit-flex-shrink:0;flex-shrink:0;padding:1em 1em 1em 0;width:25%}.recordingDialog-img{width:100%}.recordingDialog-itemName{margin-top:.7em}.recordingDetailsContainer{display:-webkit-flex;display:flex}.recordingDetails{-webkit-flex-grow:1;flex-grow:1}.recordingDetailText{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;-webkit-flex-wrap:wrap;flex-wrap:wrap}
