.upNextContainer{background-color:rgba(0,0,0,.7);bottom:0;color:#fff;display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column;padding:1em;position:fixed;right:0;transition:opacity .3s ease-out;-webkit-user-select:none;-ms-user-select:none;user-select:none;width:30em;will-change:transform,opacity;-webkit-touch-callout:none}[dir=ltr] .upNextContainer{margin:0 2em 2em 0}[dir=rtl] .upNextContainer{margin:0 0 2em 2em}.upNextDialog-hidden{opacity:0}.upNextDialog-countdownText{font-weight:500;white-space:nowrap}.upNextDialog-title{overflow:hidden;text-overflow:ellipsis;white-space:nowrap;width:25.5em}.upNextDialog-buttons{-webkit-align-content:flex-end;align-content:flex-end;-webkit-justify-content:end;justify-content:end;width:29.75em}.upNextDialog-button{background:#404040;color:#fff}@media (orientation:landscape){.upNextDialog{-webkit-flex-direction:row;flex-direction:row}}
