"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[70042],{90905:function(e){e.exports=JSON.parse('{"Sync":"Amtawi","Photos":"Tiwlafin","Movies":"Isura","Folders":"Ikaramen","Favorites":"Ismenyifen","Default":"Lexṣas","Collections":"Tigrummiwin","Channels":"Ibuda","Albums":"Iseɣraz"}')}}]);