"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[63549],{73053:function(e,t,n){n.r(t),n.d(t,{default:function(){return s}}),n(44962),n(78557),n(90076),n(83994),n(82367);var a=n(46782),l=n(71866),o=n(5898),r=n(90381),c=n(44797),u=n(74550);function s(e){function t(t){return r.A.enableGamepad(e.querySelector(".chkEnableGamepad").checked),r.A.enableSmoothScroll(e.querySelector(".chkSmoothScroll").checked),(0,l.A)(o.Ay.translate("SettingsSaved")),c.A.trigger(e,"saved"),null==t||t.preventDefault(),!1}e.addEventListener("viewshow",(function(){e.querySelector(".enableGamepadContainer").classList.toggle("hide",!u.Ay.canEnableGamepad()),e.querySelector(".smoothScrollContainer").classList.toggle("hide",!a.A.tv),e.querySelector(".chkEnableGamepad").checked=r.A.enableGamepad(),e.querySelector(".chkSmoothScroll").checked=r.A.enableSmoothScroll(),e.querySelector("form").addEventListener("submit",t),e.querySelector(".btnSave").classList.remove("hide"),Promise.resolve().then(n.bind(n,84069)).then((function(t){t.default.autoFocus(e)}))}))}}}]);