"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[11305],{54122:function(t){t.exports=JSON.parse('{"Artist":"ਕਲਾਕਾਰ","Albums":"ਐਲਬਮਾਂ","ValueSpecialEpisodeName":"ਖਾਸ - {0}","Sync":"ਸਿੰਕ","Songs":"ਗਾਣੇ","Shows":"ਸ਼ੋਅ","Playlists":"ਪਲੇਸੂਚੀਆਂ","Photos":"ਫੋਟੋਆਂ","Movies":"ਫਿਲਮਾਂ","HeaderContinueWatching":"ਵੇਖਣਾ ਜਾਰੀ ਰੱਖੋ","Genres":"ਸ਼ੈਲੀਆਂ","Folders":"ਫੋਲਡਰ","Favorites":"ਮਨਪਸੰਦ","Default":"ਡਿਫੌਲਟ","Collections":"ਸੰਗ੍ਰਹਿਣ","Channels":"ਚੈਨਲ","Books":"ਕਿਤਾਬਾਂ","Artists":"ਕਲਾਕਾਰ","MusicVideos":"ਸੰਗੀਤ ਵੀਡੀਓ","HeaderAlbumArtists":"ਐਲਬਮ ਕਲਾਕਾਰ","Extras":"ਵਾਧੂ","Episode":"TV ਦੀ ਕਿਸ਼ਤ","Ended":"ਖਤਮ ਹੋਈ","Edit":"ਸੰਪਾਦਨ ਕਰੋ","Download":"ਡਾਉਨਲੋਡ","Down":"ਥੱਲੇ","Display":"ਪ੍ਰਦਰਸ਼ਨ","Disconnect":"ਡਿਸਕਨੈਕਟ ਕਰੋ","Disc":"ਡਿਸਕ","DisablePlugin":"ਅਸਮਰੱਥ ਕਰੋ","EnablePlugin":"ਸਮਰੱਥ ਬਣਾਓ","Directors":"ਡਾਈਰੈਕਟਰਸ","Director":"ਨਿਰਦੇਸ਼ਕ","Desktop":"ਡੈਸਕਟੌਪ","Depressed":"ਘਟਾਇਆ ਹੋਇਆ","Delete":"ਮਿਟਾਓ","Data":"ਡਾਟਾ","Continuing":"ਜਾਰੀ ਕਰ ਰਿਹਾ ਹੈ","Console":"ਕਨਸੋਲ","Connect":"ਕਨੈਕਟ ਕਰੋ","Conductor":"ਕੰਡਕਟਰ","Composer":"ਰਚਨਾਕਾਰ","Categories":"ਸ਼੍ਰੇਣੀਆਂ","Casual":"ਕੈਜੁਅਲ","Bwdif":"BWDIF","ButtonWebsite":"ਵੈਬਸਾਈਟ","ButtonUninstall":"ਅਣ-ਇੰਸਟਾਲ ਕਰੋ","ButtonTrailer":"ਟ੍ਰੇਲਰ","ButtonTogglePlaylist":"ਪਲੇਸੂਚੀ","ButtonSyncPlay":"SyncPlay","ButtonSubmit":"ਸਬਮਿਟ ਕਰੋ","ButtonStop":"ਰੋਕੋ","ButtonStart":"ਸ਼ੁਰੂ","ButtonSplit":"ਵੰਡੋ","ButtonShutdown":"ਸ਼ਟ ਡਾਊਨ ਕਰੋ","ButtonSend":"ਭੇਜੋ","ButtonRevoke":"ਕੁੰਜੀ ਰੱਦ ਕਰੋ","ButtonResume":"ਮੁੜ ਜਾਰੀ ਕਰੋ","ButtonRename":"ਨਾਂ ਬਦਲੋ","ButtonRemove":"ਹਟਾਓ","ButtonPlayer":"ਪਲੇਅਰ","ButtonPause":"ਰੋਕੋ","ButtonOpen":"ਖੋਲ੍ਹੋ","ButtonOk":"ਠੀਕ ਹੈ","ButtonNetwork":"ਨੈਟਵਰਕ","ButtonMore":"ਹੋਰ","ButtonInfo":"ਜਾਣਕਾਰੀ","ButtonFullscreen":"ਪੂਰੀ ਸਕਰੀਨ","ButtonCast":"ਕਾਸਟ ਕਰੋ","ButtonCancel":"ਰੱਦ ਕਰੋ","ButtonBack":"ਪਿੱਛੇ ਵੱਲ","ButtonArrowRight":"ਸੱਜੇ","ButtonArrowLeft":"ਖੱਬੇ","ButtonActivate":"ਐਕਟੀਵੇਟ","Browse":"ਝਲਕ","Box":"ਬਾਕਸ","Banner":"ਬੈਨਰ","Auto":"ਆਪੇ","Authorize":"ਪਰਮਾਣਿਤ","Audio":"ਆਡੀਓ","Descending":"ਅਵਰੋਹੀ","Ascending":"ਵੱਧਦਾ ਕ੍ਰਮ","Anytime":"ਕਿਸੇ ਵੀ ਸਮੇਂ","All":"ਸਾਰੇ","Alerts":"ਚੇਤਾਵਨੀਆਂ","Album":"ਐਲਬਮ","Aired":"ਪ੍ਰਸਾਰਿਤ","Add":"ਜੋਡ਼ੋ","Actor":"ਐਕਟਰ","Absolute":"ਅਸਲ","SpecialFeatures":"ਵਿਸ਼ੇਸ਼ ਫੀਚਰਜ਼","OptionSpecialEpisode":"ਵਿਸ਼ੇਸ਼","TypeOptionPluralMovie":"ਫਿਲਮਾਂ","MediaInfoDefault":"ਡਿਫੌਲਟ","LabelSelectAudioChannels":"ਚੈਨਲ","MediaInfoChannels":"ਚੈਨਲ","TypeOptionPluralBook":"ਕਿਤਾਬਾਂ","AddToFavorites":"ਪਸੰਦ ਵਿੱਚ ਜੋੜੋ","ButtonUseQuickConnect":"ਫ਼ੌਰਨ ਕਨੈਕਟ ਨੂੰ ਵਰਤੋ","Copied":"ਕਾਪੀ ਕੀਤਾ","Copy":"ਕਾਪੀ ਕਰੋ","DatePlayed":"ਚਲਾਉਣ ਦੀ ਤਾਰੀਖ","AddToCollection":"ਭੰਡਾਰ ਵਿੱਚ ਜੋੜੋ","AllLibraries":"ਸਾਰੀਆਂ ਲਾਇਬਰੇਰੀਆਂ","ButtonAddImage":"ਚਿੱਤਰ ਜੋੜੋ","ButtonAddMediaLibrary":"ਮੀਡੀਆ ਭੰਡਾਰ ਜੋੜੋ","ButtonAddServer":"ਸਰਵਰ ਜੋੜੋ","ButtonAddUser":"ਵਰਤੋਂਕਾਰ ਜੋੜੋ","ButtonSelectDirectory":"ਡਾਇਰੈਕਟਰੀ ਚੁਣੋ","ButtonSignIn":"ਸਾਈਨ ਇਨ","ButtonScanAllLibraries":"ਸਾਰੇ ਭੰਡਾਰ ਸਕੈਨ ਕਰੋ","ButtonSignOut":"ਸਾਈਨ ਆਉਟ","DeleteMedia":"ਮੀਡੀਆ ਹਟਾਓ","DeleteUser":"ਵਰਤੋਂਕਾਰ ਨੂੰ ਹਟਾਓ","DeleteUserConfirmation":"ਕੀ ਤੁਸੀਂ ਇਹ ਵਰਤੋਂਕਾਰ ਨੂੰ ਹਟਾਉਣਾ ਚਾਹੁੰਦੇ ਹੋ?","ButtonExitApp":"ਐਪਲੀਕੇਸ਼ਨ ਵਿੱਚੋਂ ਬਾਹਰ ਜਾਓ","ButtonSpace":"ਥਾਂ","DateAdded":"ਜੋੜਨ ਦੀ ਤਾਰੀਖ","CopyFailed":"ਕਾਪੀ ਨਹੀਂ ਕੀਤਾ ਜਾ ਸਕਿਆ","AllowedRemoteAddressesHelp":"ਆਈਪੀ ਐਡਰੈੱਸਾਂ ਜਾਂ ਨੈਟਵਰਕਾਂ ਲਈ ਆਈਪੀ/ਨੈੱਟਮਾਸਕ ਐਨਟ੍ਰੀਆਂ ਦੀ ਕਾਮਾ-ਵੱਖਰੀ ਸੂਚੀ, ਜਿਹਨਾਂ ਨੂੰ ਦੂਰੋਂ ਕਨੈਕਟ ਕਰਨ ਦੀ ਆਗਿਆ ਹੋਵੇਗੀ। ਜੇ ਖਾਲੀ ਛੱਡ ਦਿੱਤਾ ਗਿਆ, ਤਾਂ ਸਾਰੇ ਰਿਮੋਟ ਐਡਰੈੱਸਾਂ ਨੂੰ ਆਗਿਆ ਹੋਵੇਗੀ।","AirPlay":"ਏਅਰਪਲੇ","AllowContentWithTagsHelp":"ਕੇਵਲ ਉਹ ਮੀਡੀਆ ਦਿਖਾਓ ਜਿਸ ਵਿੱਚ ਘੱਟੋ-ਘੱਟ ਇੱਕ ਨਿਰਧਾਰਤ ਟੈਗ ਹੋਵੇ।","AccessRestrictedTryAgainLater":"ਪਹੁੰਚ ਇਸ ਸਮੇਂ ਸੀਮਿਤ ਹੈ। ਕਿਰਪਾ ਕਰਕੇ ਬਾਅਦ ਵਿੱਚ ਕੋਸ਼ਿਸ਼ ਕਰੋ।","AddedOnValue":"ਜੋੜਿਆ ਗਿਆ {0}","AddToPlaylist":"ਪਲੇਲਿਸਟ ਵਿੱਚ ਸ਼ਾਮਲ ਕਰੋ","AddToPlayQueue":"ਚਲ ਰਹੀ ਕਤਾਰ ਵਿੱਚ ਸ਼ਾਮਲ ਕਰੋ","AgeValue":"({0} ਸਾਲ ਪੁਰਾਣਾ)","AlbumArtist":"ਅਲਬਮ ਕਲਾਕਾਰ","AllComplexFormats":"ਸਾਰੇ ਜਟਿਲ ਫਾਰਮੈਟ (ASS, SSA, VobSub, PGS, SUB, IDX, …)","AllChannels":"ਸਾਰੇ ਚੈਨਲ","AllEpisodes":"ਸਾਰੇ ਐਪਿਸੋਡ","AllLanguages":"ਸਭ ਭਾਸ਼ਾਵਾਂ","AirDate":"ਪ੍ਰਸਾਰਣ ਦੀ ਮਿਤੀ","AllowCollectionManagement":"ਇਸ ਉਪਭੋਗਤਾ ਨੂੰ ਕਲੈਕਸ਼ਨ ਪ੍ਰਬੰਧਿਤ ਕਰਨ ਦੀ ਆਗਿਆ ਦਿਓ"}')}}]);