"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[54847],{54847:function(e,t,o){o(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r=["neděli","pondělí","úterý","středu","čtvrtek","pátek","sobotu"],n={lastWeek:"'poslední' eeee 've' p",yesterday:"'včera v' p",today:"'dnes v' p",tomorrow:"'zítra v' p",nextWeek:function(e){var t=e.getUTCDay();return"'v "+r[t]+" o' p"},other:"P"};t.default=function(e,t){var o=n[e];return"function"==typeof o?o(t):o},e.exports=t.default}}]);