.progressring{box-sizing:border-box;float:left;height:2.6em;position:relative;-webkit-user-select:none;-ms-user-select:none;user-select:none;width:2.6em}.progressring-bg{-webkit-align-items:center;align-items:center;background:rgba(0,0,0,.9);border:.25em solid #000;border-radius:50%;box-sizing:border-box;display:-webkit-flex;display:flex;height:100%;-webkit-justify-content:center;justify-content:center;width:100%}.progressring-text{color:#ddd;font-size:90%;text-align:center}.spiner-holder-one{height:51%;width:51%}.spiner-holder-one,.spiner-holder-two{background:transparent;box-sizing:border-box;left:0;overflow:hidden;position:absolute;top:0}.spiner-holder-two{height:100%;width:100%}.progressring-spiner{border-radius:50%;border-style:solid;border-width:.25em;box-sizing:border-box;height:200%;width:200%}.animate-0-25-a{-webkit-transform:rotate(90deg);transform:rotate(90deg);-webkit-transform-origin:100% 100%;transform-origin:100% 100%}.animate-0-25-a,.animate-0-25-b{transition:-webkit-transform .18s ease-out;transition:transform .18s ease-out;transition:transform .18s ease-out,-webkit-transform .18s ease-out}.animate-0-25-b{-webkit-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:100% 100%;transform-origin:100% 100%}.animate-25-50-a{-webkit-transform:rotate(180deg);transform:rotate(180deg);-webkit-transform-origin:100% 100%;transform-origin:100% 100%}.animate-25-50-a,.animate-25-50-b{transition:-webkit-transform .18s ease-out;transition:transform .18s ease-out;transition:transform .18s ease-out,-webkit-transform .18s ease-out}.animate-25-50-b{-webkit-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:100% 100%;transform-origin:100% 100%}.animate-50-75-a{-webkit-transform:rotate(270deg);transform:rotate(270deg);-webkit-transform-origin:100% 100%;transform-origin:100% 100%}.animate-50-75-a,.animate-50-75-b{transition:-webkit-transform .18s ease-out;transition:transform .18s ease-out;transition:transform .18s ease-out,-webkit-transform .18s ease-out}.animate-50-75-b{-webkit-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:100% 100%;transform-origin:100% 100%}.animate-75-100-a{-webkit-transform:rotate(0deg);transform:rotate(0deg);-webkit-transform-origin:100% 100%;transform-origin:100% 100%}.animate-75-100-a,.animate-75-100-b{transition:-webkit-transform .18s ease-out;transition:transform .18s ease-out;transition:transform .18s ease-out,-webkit-transform .18s ease-out}.animate-75-100-b{-webkit-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:100% 100%;transform-origin:100% 100%}
