"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[94734],{94734:function(e,a,t){t(36947),Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var d={lastWeek:"'oldingi' eeee p 'da'",yesterday:"'kecha' p 'da'",today:"'bugun' p 'da'",tomorrow:"'ertaga' p 'da'",nextWeek:"eeee p 'da'",other:"P"};a.default=function(e,a,t,u){return d[e]},e.exports=a.default}}]);