"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[82509],{82509:function(e,s,r){r.r(s),r.d(s,{buildPeopleCards:function(){return n}}),r(77575);var a=r(24468);function n(e,s){s=Object.assign(s||{},{cardLayout:!1,centerText:!0,showTitle:!0,cardFooterAside:"none",showPersonRoleOrType:!0,cardCssClass:"personCard",defaultCardImageIcon:"person"}),a.default.buildCards(e,s)}s.default={buildPeopleCards:n}}}]);