"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[30419],{50672:function(e){e.exports=JSON.parse('{"Albums":"एल्बमहरू","Songs":"गीतहरू","Shows":"शोहरू","Playlists":"प्लेलिस्टहरू","Photos":"तस्बिरहरु","Movies":"चलचित्रहरू","HeaderContinueWatching":"हेर्न जारी राख्नुहोस्","Genres":"विधाहरू","Folders":"फोल्डरहरू","Favorites":"मनपर्ने","Collections":"संग्रह","Channels":"च्यानलहरू","Books":"पुस्तकहरु","Artists":"कलाकारहरू","MusicVideos":"सांगीतिक भिडियोहरू","HeaderAlbumArtists":"एल्बमका कलाकारहरू","Default":"पूर्वनिर्धारित","ValueSpecialEpisodeName":"विशेष - {0}","Sync":"समकालीन","AsManyAsPossible":"सकेसम्म धेरै","Ascending":"आरोही","Artist":"कलाकार","AllLanguages":"सबै भाषाहरु","AllEpisodes":"सबै प्रकरणहरु","AllChannels":"सबै ‌च्यानलहरु","All":"सबै","Alerts":"सुचनाहरु","AlbumArtist":"एल्बम कलाकार","Album":"एल्बम","AgeValue":"उमेर","AddToPlaylist":"प्लेलिस्टमा थप्नुहोस्","AddToFavorites":"मनपर्ने मा थप्नुहोस्","Add":"थप्नुहोस्","Actor":"अभिनेता","Absolute":"निरपेक्ष","AddToCollection":"संग्रहमा थप्नुहोस्","AirDate":"प्रसारण मिति","Aired":"प्रसारित","ButtonAddImage":"चित्र थप्नुहोस्","ButtonResume":"सुचारु गर्नुहोस्","ButtonScanAllLibraries":"भन्डरमा खोज्नुहोस्","LatestFromLibrary":"हालसालै थपिएको","LabelTitle":"शीर्षक","LogLevel.Warning":"चेतावनी","ButtonOk":"हुन्छ","ButtonOpen":"खोल्नुहोस","ButtonPause":"रोक्नुहोस्","ButtonRename":"पुन: नामकरण","ButtonRemove":"हटाउनुहोस्","ButtonSend":"पठाउनुहोस्","ButtonShutdown":"बन्द गर्नुहोस्","ButtonSignIn":"","Lyricist":"गीतकार","LabelVideoInfo":"श्रव्यदृश्यको जानकारी","LabelTime":"समय","LiveTV":"प्रत्यक्ष टेलिभिजन","LiveBroadcasts":"प्रत्यक्ष प्रसारण","Localization":"स्थानीयकरण","LogLevel.Information":"जानकारी","LabelWeb":"संजल","LabelYear":"वर्ष","LabelSystem":"प्रणाली","LogLevel.Error":"त्रुटि","LogLevel.None":"","ButtonCancel":"रद्द गर्नुहोस्","Edit":"सम्पादन गर्नुहोस्","Controls":"नियन्त्रणहरू","LabelTimeLimitHours":"समय सीमा (घण्टा)","LabelYoureDone":"तपाईंले पूरा गर्नुभयो !","Live":"प्रत्यक्ष","List":"सूची","CommunityRating":"सामुदायिक मूल्याङ्कन","LabelTextColor":"अक्षरको रङ","LabelTextSize":"अक्षरको मोटाइ","LabelTextWeight":"अक्षरको बजन","BirthLocation":"जन्मस्थान","BirthPlaceValue":"जन्मथलो:{०}","Blacklist":"कालोसूची","ButtonAddUser":"प्रयोगकर्ता थप्नुहोस्","ButtonArrowLeft":"बायाँ","ButtonInfo":"जानकारी","ButtonStart":"सुरु गर्नुहोस्","ButtonStop":"रोक्नुहोस्","ButtonSubmit":"पेश गर्नुहोस्","AiTranslated":"कृत्रिम बौद्धिक अनुवाद","Categories":"श्रेणीहरू","ButtonArrowRight":"दायाँ"}')}}]);