.logoScreenSaver{background:#101010;bottom:0;left:0;position:fixed;right:0;text-align:center;top:0;z-index:1000}.logoScreenSaverImage{height:120px;margin-left:-197px;margin-top:-60px;position:absolute;top:50%}
