@media (min-height:720px){html{font-size:20px}}@media (min-height:1000px){html{font-size:27px}}h1{font-size:1.8em;font-weight:400}.layout-desktop h1{font-size:2em}h2{font-size:1.8em}h2,h3{font-weight:400}h3{font-size:1.17em}
