(self.webpackChunk=self.webpackChunk||[]).push([[10807,27114,33188],{10564:function(e){function t(o){return e.exports=t="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},e.exports.__esModule=!0,e.exports.default=e.exports,t(o)}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports},33188:function(e,t,o){"use strict";o(36947),o(78557),o(73687);var n=o(96784).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e){(0,s.default)(1,arguments);var t=Object.prototype.toString.call(e);return e instanceof Date||"object"===(0,r.default)(e)&&"[object Date]"===t?new Date(e.getTime()):"number"==typeof e||"[object Number]"===t?new Date(e):("string"!=typeof e&&"[object String]"!==t||"undefined"==typeof console||(console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#string-arguments"),console.warn((new Error).stack)),new Date(NaN))};var r=n(o(10564)),s=n(o(23058));e.exports=t.default},84567:function(e,t,o){"use strict";o(36947);var n=o(96784).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r=n(o(56974)),s=["svētdienā","pirmdienā","otrdienā","trešdienā","ceturtdienā","piektdienā","sestdienā"],u={lastWeek:function(e,t,o){return(0,r.default)(e,t,o)?"eeee 'plkst.' p":"'Pagājušā "+s[e.getUTCDay()]+" plkst.' p"},yesterday:"'Vakar plkst.' p",today:"'Šodien plkst.' p",tomorrow:"'Rīt plkst.' p",nextWeek:function(e,t,o){return(0,r.default)(e,t,o)?"eeee 'plkst.' p":"'Nākamajā "+s[e.getUTCDay()]+" plkst.' p"},other:"P"};t.default=function(e,t,o,n){var r=u[e];return"function"==typeof r?r(t,o,n):r},e.exports=t.default},96784:function(e){e.exports=function(e){return e&&e.__esModule?e:{default:e}},e.exports.__esModule=!0,e.exports.default=e.exports}}]);