"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[83518],{83518:function(e,a,l){l(89336),l(36947),l(95021),l(53819),Object.defineProperty(a,"__esModule",{value:!0}),a.default=function(e){return function(a){var l=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},t=a.match(e.matchPattern);if(!t)return null;var u=t[0],n=a.match(e.parsePattern);if(!n)return null;var r=e.valueCallback?e.valueCallback(n[0]):n[0];return{value:r=l.valueCallback?l.valueCallback(r):r,rest:a.slice(u.length)}}},e.exports=a.default}}]);