"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[46902],{46902:function(e,t,u){u(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"eeee 'שעבר בשעה' p",yesterday:"'אתמול בשעה' p",today:"'היום בשעה' p",tomorrow:"'מחר בשעה' p",nextWeek:"eeee 'בשעה' p",other:"P"};t.default=function(e,t,u,r){return o[e]},e.exports=t.default}}]);