"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[33796,49911,66884],{9214:function(e,i,s){s.r(i);var t=s(62540),a=s(11444),n=(s(63696),s(37632)),o=s(65242),c=s(99883),p=s(46850),r=s(65369),l=s(4672),T={viewType:p.D.Episodes,itemType:[a.D.Episode],collectionType:r.X.Tvshows,isAlphabetPickerEnabled:!1,noItemsMessage:"MessageNoEpisodesFound"},b={viewType:p.D.Series,itemType:[a.D.Series],collectionType:r.X.Tvshows,isBtnShuffleEnabled:!0},d={viewType:p.D.Networks,itemType:[a.D.Series],isBtnFilterEnabled:!1,isBtnGridListEnabled:!1,isBtnSortEnabled:!1,isAlphabetPickerEnabled:!1},y={viewType:p.D.Upcoming},w={0:b,1:{viewType:p.D.Suggestions,collectionType:r.X.Tvshows,sectionsView:l.i3},2:y,3:{viewType:p.D.Genres,itemType:[a.D.Series],collectionType:r.X.Tvshows},4:d,5:T};i.default=function(){var e=(0,n.A)(),i=e.libraryId,s=e.activeTab,a=w[s];return(0,t.jsx)(o.A,{id:"tvshowsPage",className:"mainAnimatedPage libraryPage backdropPage collectionEditorPage pageWithAbsoluteTabs withTabs",backDropType:"series",children:(0,t.jsx)(c.A,{currentTab:a,parentId:i},"".concat(a.viewType," - ").concat(i))})}}}]);