"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[75336],{75336:function(e,t,o){o(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n={lastWeek:"'viime' eeee 'klo' p",yesterday:"'eilen klo' p",today:"'tänään klo' p",tomorrow:"'huomenna klo' p",nextWeek:"'ensi' eeee 'klo' p",other:"P"};t.default=function(e,t,o,l){return n[e]},e.exports=t.default}}]);