"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[62373],{62373:function(e,t,o){o(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:function(e){var t=e.getUTCDay();return"'"+(0===t||6===t?"último":"última")+"' eeee 'às' p"},yesterday:"'ontem às' p",today:"'hoje às' p",tomorrow:"'amanhã às' p",nextWeek:"eeee 'às' p",other:"P"};t.default=function(e,t,o,n){var r=a[e];return"function"==typeof r?r(t):r},e.exports=t.default}}]);