"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[94160],{94160:function(t,e,a){a(44962),a(36947),a(78557),a(82367),Object.defineProperty(e,"__esModule",{value:!0}),e.default=function(t){return function(e,a){var n;if("formatting"===(null!=a&&a.context?String(a.context):"standalone")&&t.formattingValues){var l=t.defaultFormattingWidth||t.defaultWidth,u=null!=a&&a.width?String(a.width):l;n=t.formattingValues[u]||t.formattingValues[l]}else{var i=t.defaultWidth,r=null!=a&&a.width?String(a.width):t.defaultWidth;n=t.values[r]||t.values[i]}return n[t.argumentCallback?t.argumentCallback(e):e]}},t.exports=e.default}}]);