"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[87300],{87300:function(e,t,l){l(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"'i' EEEE's kl.' p",yesterday:"'igår kl.' p",today:"'idag kl.' p",tomorrow:"'imorgon kl.' p",nextWeek:"EEEE 'kl.' p",other:"P"};t.default=function(e,t,l,r){return o[e]},e.exports=t.default}}]);