"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[48016],{48016:function(e,l,t){t(36947),Object.defineProperty(l,"__esModule",{value:!0}),l.default=void 0;var a={lastWeek:"eeee 'li għadda' 'fil-'p",yesterday:"'Il-bieraħ fil-'p",today:"'Illum fil-'p",tomorrow:"'Għada fil-'p",nextWeek:"eeee 'fil-'p",other:"P"};l.default=function(e,l,t,f){return a[e]},e.exports=l.default}}]);