"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[8589],{31758:function(a){a.exports=JSON.parse('{"Books":"lo cukta","Box":"tanxe","ButtonActivate":"aktigau","Add":"jmina","AddToFavorites":"jmina fi lo se trajynei","Alerts":"lo sajgau","All":"ro","Artist":"larpra","Artists":"lo larpra","AddToCollection":"jmina fi lo girzu","Authorize":"tolpro","Auto":"zmiku","Banner":"lo lanci","HeaderLatestMusic":"bavrai lo zgike","MusicVideo":"zgike xrapoi","TabMusic":"zgike","TypeOptionPluralMusicArtist":"lo zgike larpra","ButtonArrowLeft":"zunle","ButtonArrowRight":"pritu","ButtonCancel":"sisti","ButtonInfo":"datni","ButtonPause":"zasysti","ButtonSend":"benji","ButtonStart":"tolsti","ButtonStop":"sisti","Art":"lardai","Audio":"sance","AddedOnValue":"se jmina {0}","AddToPlaylist":"jmina fi lo zgipor","ButtonGotIt":"je\'e","ButtonNextTrack":"sepcau zgike","BirthPlaceValue":"lo ve jbena {0}","ButtonQuickStartGuide":"sutra tolsti gidva","ButtonTogglePlaylist":"zgipor","LabelPlaylist":"zgipor","HeaderAddToPlaylist":"jmina fi lo zgipor","RemoveFromPlaylist":"vimcu fi le zgipor","LabelArtists":"lo larpra","OtherArtist":"fliba lo larpra","ViewAlbumArtist":"catlu fe lo albuma larpra","LabelAlbumArtists":"lo albuma larpra","Playlists":"lo zgipor","Actor":"tigni","Album":"albuma","AlbumArtist":"albuma larpra","Albums":"lo albuma","HeaderAlbumArtists":"lo albuma larpra","HeaderPhotoAlbums":"lo pixra albuma","LabelAlbum":"albuma","MusicArtist":"larpra zgike","MusicAlbum":"zgike albuma","TypeOptionPluralMusicAlbum":"lo zgike albuma","ViewAlbum":"cutla fe lo albuma","Large":"barda","Normal":"fadni","ButtonOk":"ie","Small":"cmalu","BirthLocation":"lo ve jbena","Browse":"catlu","Absolute":"fatci","AllLanguages":"ro bangu","AllLibraries":"lo gavni sorcu","AllowMediaConversion":"curmi fe lo se galfi be lo ganvi","LabelBirthDate":"lo te jbena","LabelPlaceOfBirth":"lo ve jbena","Backdrops":"lo vinti\'e","ButtonClose":"ga\'orgau","ButtonShutdown":"na\'aktigau","ButtonSelectView":"samcu\'a lo jvinu","ButtonExitApp":"se barkalri lo proga","AddToPlayQueue":"jmina fe lo mencti depypoi","HeaderStartNow":"ca tolsti","LabelDeathDate":"se detri lo nu nunmro","LabelDeviceDescription":"se velski lo skami"}')}}]);