"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[31297],{76059:function(e,t,d){d(36947),Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"'síðasta' dddd 'kl.' p",yesterday:"'í gær kl.' p",today:"'í dag kl.' p",tomorrow:"'á morgun kl.' p",nextWeek:"dddd 'kl.' p",other:"P"};t.default=function(e,t,d,l){return a[e]},e.exports=t.default}}]);