"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[89150],{44625:function(e,a,t){t.r(a),a.default='<div id="selectServerPage" data-role="page" class="page noSecondaryNavPage standalonePage pageContainer"> <div class="margin-auto-y padded-bottom-page"> <div class="verticalSection flex-shrink-zero w-100 flex flex-direction-column"> <div class="padded-left padded-right flex align-items-center justify-content-center"> <h1 class="sectionTitle sectionTitle-cards">${SelectServer}</h1> </div> <div class="padded-top padded-bottom-focusscale flex-grow flex" data-horizontal="true" data-centerfocus="card"> <div is="emby-itemscontainer" class="scrollSlider focuscontainer-x servers flex-grow" style="display:block;text-align:center" data-hovermenu="false" data-multiselect="false"></div> </div> </div> <div class="padded-top padded-left padded-right flex flex-shrink-zero justify-content-center verticalSection flex-wrap-wrap margin-auto-x"> <a is="emby-linkbutton" href="#/addserver" class="raised cancel btnAddServer flex-shrink-zero" style="margin:.25em"> <span>${ButtonAddServer}</span> </a> </div> </div> </div> '}}]);