"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[29593],{16209:function(e,t,n){function u(e){return u="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},u(e)}function r(e,t){for(var n=0;n<t.length;n++){var u=t[n];u.enumerable=u.enumerable||!1,u.configurable=!0,"value"in u&&(u.writable=!0),Object.defineProperty(e,l(u.key),u)}}function l(e){var t=function(e){if("object"!=u(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=u(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==u(t)?t:t+""}n.r(t),n(29305),n(32733),n(84701),n(81678),n(44962),n(4754),n(94),n(36947),n(78557),n(83994),n(82367);var i=function(){return e=function e(t){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e),this.queueCore=t.getQueueCore()},(t=[{key:"getPlaylist",value:function(){return this.queueCore.getPlaylist()}},{key:"setPlaylist",value:function(){}},{key:"queue",value:function(){}},{key:"shufflePlaylist",value:function(){}},{key:"sortShuffledPlaylist",value:function(){}},{key:"clearPlaylist",value:function(){}},{key:"queueNext",value:function(){}},{key:"getCurrentPlaylistIndex",value:function(){return this.queueCore.getCurrentPlaylistIndex()}},{key:"getCurrentItem",value:function(){var e=this.getCurrentPlaylistIndex();return e>=0?this.getPlaylist()[e]:null}},{key:"getCurrentPlaylistItemId",value:function(){return this.queueCore.getCurrentPlaylistItemId()}},{key:"setPlaylistState",value:function(){}},{key:"setPlaylistIndex",value:function(){}},{key:"removeFromPlaylist",value:function(){}},{key:"movePlaylistItem",value:function(){return{result:"noop"}}},{key:"reset",value:function(){}},{key:"setRepeatMode",value:function(){}},{key:"getRepeatMode",value:function(){return this.queueCore.getRepeatMode()}},{key:"setShuffleMode",value:function(){}},{key:"toggleShuffleMode",value:function(){}},{key:"getShuffleMode",value:function(){return this.queueCore.getShuffleMode()}},{key:"getNextItemInfo",value:function(){var e,t=this.getPlaylist();switch(this.getRepeatMode()){case"RepeatOne":e=this.getCurrentPlaylistIndex();break;case"RepeatAll":(e=this.getCurrentPlaylistIndex()+1)>=t.length&&(e=0);break;default:e=this.getCurrentPlaylistIndex()+1}if(e<0||e>=t.length)return null;var n=t[e];return n?{item:n,index:e}:null}}])&&r(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e;var e,t}();t.default=i}}]);