.editPageSidebar{display:block}.editPageSidebar-withcontent{display:none}[dir=ltr] .libraryTree{margin-left:.25em}[dir=rtl] .libraryTree{margin-right:.25em}.offlineEditorNode{color:#c33}.editorNode img{height:18px;margin:0 .35em;position:relative;top:-2px;vertical-align:middle}.jstree-anchor{font-weight:400!important}.jstree-wholerow-hovered{background:#38c!important;border-radius:0!important;box-shadow:none!important}.jstree-default .jstree-hovered{background:0 0!important;border-radius:0!important;box-shadow:none!important;color:#fff!important}.jstree-default .jstree-wholerow-clicked{background:#00a4dc!important}.metadataSidebarIcon{margin-right:.4em}@media (min-width:50em){.editPageSidebar{bottom:0;display:block;position:fixed;top:3.25rem;width:30%}[dir=ltr] .editPageSidebar{border-right:1px solid #555;left:0}[dir=rtl] .editPageSidebar{border-left:1px solid #555;right:0}.editPageInnerContent{width:68.5%}[dir=ltr] .editPageInnerContent{float:right}[dir=rtl] .editPageInnerContent{float:left}}@media (min-width:112.5em){.editPageSidebar{width:25%}.editPageInnerContent{width:73.5%}}
