"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[40810],{76066:function(e,t,r){r.r(t),r(29305),r(32733),r(84701),r(81678),r(44962),r(4754),r(94),r(36947),r(78557),r(90076),r(83994),r(82367);var n=r(5898),a=r(82885),o=r(22622),i=r(41177),l=r(38783);function u(e){return u="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},u(e)}function p(e,t){for(var r=0;r<t.length;r++){var n=t[r];n.enumerable=n.enumerable||!1,n.configurable=!0,"value"in n&&(n.writable=!0),Object.defineProperty(e,y(n.key),n)}}function y(e){var t=function(e){if("object"!=u(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var r=t.call(e,"string");if("object"!=u(r))return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==u(t)?t:t+""}function s(e,t,r){if(o.g.supports(r))return Promise.resolve();var n=new Date;return t+=n.getFullYear()+"-w"+function(e){var t=new Date(Date.UTC(e.getFullYear(),e.getMonth(),e.getDate())),r=t.getUTCDay()||7;t.setUTCDate(t.getUTCDate()+4-r);var n=new Date(Date.UTC(t.getUTCFullYear(),0,1));return Math.ceil(((t-n)/864e5+1)/7)}(n),"1"===a.get(t,!1)?Promise.resolve():(a.set(t,"1",!1),(0,i.A)(e))}var c=function(){return e=function e(){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e),this.name="Experimental playback warnings",this.type=l.Q.PreplayIntercept,this.id="expirementalplaybackwarnings"},(t=[{key:"intercept",value:function(e){var t=e.item;return t?"Iso"===t.VideoType?s(n.Ay.translate("UnsupportedPlayback"),"isoexpirementalinfo","nativeisoplayback"):"BluRay"===t.VideoType?s(n.Ay.translate("UnsupportedPlayback"),"blurayexpirementalinfo","nativeblurayplayback"):"Dvd"===t.VideoType?s(n.Ay.translate("UnsupportedPlayback"),"dvdexpirementalinfo","nativedvdplayback"):Promise.resolve():Promise.resolve()}}])&&p(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e;var e,t}();t.default=c}}]);