#reactRoot{height:100%}#myPreferencesMenuPage .adminSection,#myPreferencesMenuPage .lnkQuickConnectPreferences,#myPreferencesMenuPage .userSection{display:none!important}.homePage.libraryPage.withTabs,.libraryPage:not(.itemDetailPage){padding-top:3.25rem!important}.layout-mobile .itemBackdrop{margin-top:0!important}.layout-mobile .itemBackdrop:before{background:linear-gradient(180deg,rgba(32,32,32,.6),rgba(32,32,32,.2) 4rem,transparent 50%);content:"";display:block;height:100%;width:100%}
