"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[53961],{26346:function(e){e.exports=JSON.parse('{"Absolute":"բացարձակ","Songs":"Երգեր","Vertical":"Վերտիկալ","Writer":"Գրող","Movies":"Ֆիլմեր","Photos":"Լուսանկարներ","Actor":"Դերասան","Add":"Ավելացնել","AgeValue":"({0} տարեկան)","Album":"Ալբոմ","Albums":"Ալբոմներ","All":"Բոլորը","AllChannels":"Բոլորը ալիքները","AllLanguages":"Բոլորը լեզուները","AllLibraries":"Բոլոր գրադարանները","AllowedRemoteAddressesHelp":"Ստորակետով անջատված IP հասցեներ կամ IP/netmask-եր որոնք կարող են միանալ հեռակա։ Դարակ թողնելու դեպքում կամայական հասցե կարող է միանալ հեռակա։","Channels":"Ալիքներ","Folders":"Պանակներ","AllowSegmentDeletion":"Հեռացնել սեգմենտները","Books":"Գրքեր","HeaderContinueWatching":"Շարունակել դիտումը","Yes":"Այո","Writers":"Գրողներ","Yesterday":"Երեկ","Collections":"Հավաքածուներ","AddedOnValue":"Ավելացվեց {0}","AddToCollection":"Ավելացնել հավաքածույին","ButtonArrowLeft":"Ձախ","ButtonArrowRight":"Աջ","ButtonBack":"Հետ","ButtonOpen":"Բացել","ButtonParentalControl":"Ծնողական հսկողություն","Continuing":"Շարունակում","AddToFavorites":"Ավելացնել սիրվածներին","AnyLanguage":"Ցանկացած լեզու","ButtonRename":"Վերանվանել","ButtonResume":"Շարունակել","ButtonSend":"Ուղարկել","ButtonShutdown":"Անջատել","ButtonSpace":"Բացատ","ButtonStart":"Սկսել","Anytime":"Ցանկացած ժամանակ","BirthPlaceValue":"Ծննդատեղ։ {0}","BirthLocation":"Ծննդավայր","ButtonActivate":"Ակտիվացնել","ButtonAddImage":"Նկար ավելացնել","ButtonClose":"Փակել","ConfirmDeleteImage":"","ContinueWatching":"Շարունակել դիտել","AllComplexFormats":"Բոլոր բարդ ֆորմատները (ASS, SSA, VobSub, PGS, SUB, IDX, ...)","AllEpisodes":"Բոլոր դրվագները","AccessRestrictedTryAgainLater":"Այս պահին մուտքը արգելված է։ Խնդրում ենք կրկին փորձել ավելի ուշ։","AirDate":"Հեռարձակման օրը","Aired":"Հեռարձակվել է","LabelIsHearingImpaired":"Լսողության խնդիր ունեցողների համար (SDH)","Clip":"Հոլովակ","LabelServerHostHelp":"192.168.1.100:8096 կամ https://myserver.com","ValueSeconds":"{0} վարկյան","ValueSongCount":"{0} երգեր","Interview":"Հարցազրույց","Select":"Ընտրել","MessageSyncPlayUserLeft":"{0}ն լքել է խումբը","Option3D":"3D","DownloadsValue":"{0} ներմերնում","ListPaging":"{0}-{1} {2}ից","MessageSyncPlayUserJoined":"{0}ն միացել է խմբին","SyncPlayGroupDefaultTitle":"{0}ի խումբը","ValueEpisodeCount":"{0} դրվագ","ValueMovieCount":"{0} ֆիլմեր","ValueOneEpisode":"1 դրվագ","ValueOneMovie":"1 ֆիլմ","ValueOneSeries":"1 հեռուստասերիալ","ValueOneSong":"1 երգ","ContainerNotSupported":"Տվյալ վիդեոյի կրիչը չի սպասարկվում","SelectAll":"Ընտրել բոլորը","HeaderSecondsValue":"{0} Վարկյան","Label3DFormat":"3D ձևաչափ"}')}}]);