"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[4867],{39040:function(e){e.exports=JSON.parse('{"LabelOpenclDeviceHelp":"ಇದು ಟೋನ್ ಮ್ಯಾಪಿಂಗ್‌ಗಾಗಿ ಬಳಸಲಾಗುವ OpenCL ಸಾಧನವಾಗಿದೆ. ಡಾಟ್‌ನ ಎಡಭಾಗವು ಪ್ಲಾಟ್‌ಫಾರ್ಮ್ ಸಂಖ್ಯೆಯಾಗಿದೆ ಮತ್ತು ಬಲಭಾಗವು ಪ್ಲಾಟ್‌ಫಾರ್ಮ್‌ನಲ್ಲಿರುವ ಸಾಧನ ಸಂಖ್ಯೆಯಾಗಿದೆ. ಡೀಫಾಲ್ಟ್ ಮೌಲ್ಯವು 0.0 ಆಗಿದೆ. OpenCL ಹಾರ್ಡ್‌ವೇರ್ ವೇಗವರ್ಧಕ ವಿಧಾನವನ್ನು ಹೊಂದಿರುವ FFmpeg ಅಪ್ಲಿಕೇಶನ್ ಫೈಲ್ ಅಗತ್ಯವಿದೆ.","LabelRemoteClientBitrateLimitHelp":"ಎಲ್ಲಾ ನೆಟ್‌ವರ್ಕ್ ಸಾಧನಗಳಿಗೆ ಐಚ್ಛಿಕ ಪ್ರತಿ-ಸ್ಟ್ರೀಮ್ ಬಿಟ್‌ರೇಟ್ ಮಿತಿ. ನಿಮ್ಮ ಇಂಟರ್ನೆಟ್ ಸಂಪರ್ಕವನ್ನು ನಿಭಾಯಿಸುವುದಕ್ಕಿಂತ ಹೆಚ್ಚಿನ ಬಿಟ್ರೇಟ್ ಅನ್ನು ವಿನಂತಿಸುವುದರಿಂದ ಸಾಧನಗಳನ್ನು ತಡೆಯಲು ಇದು ಉಪಯುಕ್ತವಾಗಿದೆ. ಕಡಿಮೆ ಬಿಟ್ರೇಟ್‌ಗೆ ಹಾರುತ್ತಿರುವಾಗ ವೀಡಿಯೊಗಳನ್ನು ಟ್ರಾನ್ಸ್‌ಕೋಡ್ ಮಾಡಲು ಇದು ನಿಮ್ಮ ಸರ್ವರ್‌ನಲ್ಲಿ ಹೆಚ್ಚಿದ CPU ಲೋಡ್‌ಗೆ ಕಾರಣವಾಗಬಹುದು.","LabelTonemappingThresholdHelp":"ಟೋನ್ ಮ್ಯಾಪಿಂಗ್ ಅಲ್ಗಾರಿದಮ್ ಪ್ಯಾರಾಮೀಟರ್‌ಗಳನ್ನು ಪ್ರತಿ ದೃಶ್ಯಕ್ಕೆ ಉತ್ತಮವಾಗಿ ಟ್ಯೂನ್ ಮಾಡಲಾಗಿದೆ. ಮತ್ತು ದೃಶ್ಯವು ಬದಲಾಗಿದೆಯೇ ಅಥವಾ ಇಲ್ಲವೇ ಎಂಬುದನ್ನು ಪತ್ತೆಹಚ್ಚಲು ಮಿತಿಯನ್ನು ಬಳಸಲಾಗುತ್ತದೆ. ಪ್ರಸ್ತುತ ಫ್ರೇಮ್ ಸರಾಸರಿ ಹೊಳಪು ಮತ್ತು ಪ್ರಸ್ತುತ ಚಾಲನೆಯಲ್ಲಿರುವ ಸರಾಸರಿ ನಡುವಿನ ಅಂತರವು ಮಿತಿ ಮೌಲ್ಯವನ್ನು ಮೀರಿದರೆ, ನಾವು ದೃಶ್ಯ ಸರಾಸರಿ ಮತ್ತು ಗರಿಷ್ಠ ಹೊಳಪನ್ನು ಮರು ಲೆಕ್ಕಾಚಾರ ಮಾಡುತ್ತೇವೆ. ಶಿಫಾರಸು ಮಾಡಲಾದ ಮತ್ತು ಡೀಫಾಲ್ಟ್ ಮೌಲ್ಯಗಳು 0.8 ಮತ್ತು 0.2.","LabelTonemappingDesatHelp":"ಈ ಮಟ್ಟದ ಪ್ರಕಾಶಮಾನತೆಯನ್ನು ಮೀರಿದ ಮುಖ್ಯಾಂಶಗಳಿಗೆ ಡಿಸ್ಯಾಚುರೇಶನ್ ಅನ್ನು ಅನ್ವಯಿಸಿ. ಹೆಚ್ಚಿನ ಪ್ಯಾರಾಮೀಟರ್, ಹೆಚ್ಚು ಬಣ್ಣದ ಮಾಹಿತಿಯನ್ನು ಸಂರಕ್ಷಿಸಲಾಗುತ್ತದೆ. ಈ ಸೆಟ್ಟಿಂಗ್ ಸೂಪರ್-ಹೈಲೈಟ್‌ಗಳಿಗೆ ಅಸ್ವಾಭಾವಿಕವಾಗಿ ಹಾರಿಹೋಗುವ ಬಣ್ಣಗಳನ್ನು ತಡೆಯಲು ಸಹಾಯ ಮಾಡುತ್ತದೆ, ಬದಲಿಗೆ ಬಿಳಿ ಬಣ್ಣಕ್ಕೆ ತಿರುಗುತ್ತದೆ. ಇದು ವ್ಯಾಪ್ತಿಯಿಂದ ಹೊರಗಿರುವ ಬಣ್ಣಗಳ ಬಗ್ಗೆ ಮಾಹಿತಿಯನ್ನು ಕಡಿಮೆ ಮಾಡುವ ವೆಚ್ಚದಲ್ಲಿ ಚಿತ್ರಗಳನ್ನು ಹೆಚ್ಚು ನೈಸರ್ಗಿಕವಾಗಿಸುತ್ತದೆ. ಶಿಫಾರಸು ಮಾಡಲಾದ ಮತ್ತು ಡೀಫಾಲ್ಟ್ ಮೌಲ್ಯಗಳು 0 ಮತ್ತು 0.5.","ExtractChapterImagesHelp":"ಅಧ್ಯಾಯ ಚಿತ್ರಗಳನ್ನು ಹೊರತೆಗೆಯಲಾಗುತ್ತಿದೆ ಗ್ರಾಹಕರು ಚಿತ್ರಾತ್ಮಕ ದೃಶ್ಯ ಆಯ್ಕೆ ಮೆನುಗಳನ್ನು ಪ್ರದರ್ಶಿಸಲು ಅನುಮತಿಸುತ್ತದೆ. ಈ ಪ್ರಕ್ರಿಯೆಯು ನಿಧಾನವಾಗಬಹುದು, ಸಂಪನ್ಮೂಲ ತೀವ್ರತೆ, ಮತ್ತು ಹಲವಾರು ಗಿಗಾಬೈಟ್ಗಳ ಸ್ಥಳಾವಕಾಶ ಬೇಕಾಗಬಹುದು. ವೀಡಿಯೊಗಳನ್ನು ಪತ್ತೆಹಚ್ಚಿದಾಗ ಮತ್ತು ರಾತ್ರಿಯ ನಿಗದಿತ ಕಾರ್ಯವಾಗಿ ಇದು ನಡೆಯುತ್ತದೆ. ವೇಳಾಪಟ್ಟಿಯನ್ನು ನಿಗದಿತ ಕಾರ್ಯಗಳ ಪ್ರದೇಶದಲ್ಲಿ ಕಾನ್ಫಿಗರ್ ಮಾಡಬಹುದಾಗಿದೆ. ಗರಿಷ್ಠ ಬಳಕೆಯ ಸಮಯದಲ್ಲಿ ಈ ಕೆಲಸವನ್ನು ಚಲಾಯಿಸಲು ಸೂಕ್ತವಲ್ಲ.","LanNetworksHelp":"ಬ್ಯಾಂಡ್‌ವಿಡ್ತ್ ನಿರ್ಬಂಧಗಳನ್ನು ಜಾರಿಗೊಳಿಸುವಾಗ ಸ್ಥಳೀಯ ನೆಟ್‌ವರ್ಕ್‌ನಲ್ಲಿ ಪರಿಗಣಿಸಲಾಗುವ ನೆಟ್‌ವರ್ಕ್‌ಗಳಿಗಾಗಿ IP ವಿಳಾಸಗಳ ಅಲ್ಪವಿರಾಮದಿಂದ ಬೇರ್ಪಡಿಸಿದ ಪಟ್ಟಿ ಅಥವಾ IP/ನೆಟ್‌ಮಾಸ್ಕ್ ನಮೂದುಗಳು. ಹೊಂದಿಸಿದರೆ, ಎಲ್ಲಾ ಇತರ IP ವಿಳಾಸಗಳನ್ನು ಬಾಹ್ಯ ನೆಟ್‌ವರ್ಕ್‌ನಲ್ಲಿ ಎಂದು ಪರಿಗಣಿಸಲಾಗುತ್ತದೆ ಮತ್ತು ಬಾಹ್ಯ ಬ್ಯಾಂಡ್‌ವಿಡ್ತ್ ನಿರ್ಬಂಧಗಳಿಗೆ ಒಳಪಟ್ಟಿರುತ್ತದೆ. ಖಾಲಿ ಬಿಟ್ಟರೆ, ಸರ್ವರ್‌ನ ಸಬ್‌ನೆಟ್ ಮಾತ್ರ ಸ್ಥಳೀಯ ನೆಟ್‌ವರ್ಕ್‌ನಲ್ಲಿದೆ ಎಂದು ಪರಿಗಣಿಸಲಾಗುತ್ತದೆ.","Actor":"ನಟ","AccessRestrictedTryAgainLater":"ಪ್ರಸ್ತುತ ಪ್ರವೇಶವನ್ನು ನಿರ್ಬಂಧಿಸಲಾಗಿದೆ. ದಯವಿಟ್ಟು ನಂತರ ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ.","Absolute":"ಸಂಪೂರ್ಣ","Default":"ಪೂರ್ವನಿಯೋಜಿತ","Channels":"ಮೂಲಗಳು","Folders":"ಫೋಲ್ಡರ್‌ಗಳು","HeaderContinueWatching":"ನೋಡುವುದನ್ನು ಮುಂದುವರಿಸಿ","Playlists":"ಪ್ಲೇಪಟ್ಟಿಗಳು","Songs":"ಹಾಡುಗಳು","Movies":"ಚಲನಚಿತ್ರಗಳು","MusicVideos":"ಸಂಗೀತ ವೀಡಿಯೊಗಳು","Sync":"ಹೊಂದಿಕೆ","ValueSpecialEpisodeName":"ವಿಶೇಷ - {0}","Albums":"ಸಂಪುಟ","Genres":"ಪ್ರಕಾರಗಳು","Favorites":"ಮೆಚ್ಚಿನವುಗಳು","HeaderAlbumArtists":"ಸಂಪುಟ ಕಲಾವಿದರು","Collections":"ಸಂಗ್ರಹಣೆಗಳು","Shows":"ಧಾರವಾಹಿಗಳು","Photos":"ಚಿತ್ರಗಳು","Artists":"ಕಲಾವಿದರು","Books":"ಪುಸ್ತಕಗಳು","AddedOnValue":"{0} ಸೇರಿಸಲಾಗಿದೆ","AddToPlaylist":"ಪ್ಲೇಲಿಸ್ಟ್‌ಗೆ ಸೇರಿಸಿ","Aired":"ಪ್ರಸಾರಗೊಂಡಿದೆ","AllComplexFormats":"ಎಲ್ಲಾ ಸಂಕೀರ್ಣ ಫಾರ್ಮ್ಯಾಟ್‌ಗಳು (ASS, SSA, VobSub, PGS, SUB, IDX, …)","All":"ಎಲ್ಲಾ","AirPlay":"ಎರ್‌ಪ್ಲೇ","Add":"ಸೇರಿಸಿ","AddToCollection":"ಸಂಗ್ರಹಕ್ಕೆ ಸೇರಿಸಿ","AllEpisodes":"ಎಲ್ಲಾ ಎಪಿಸೋಡ್‌ಗಳು","AllChannels":"ಎಲ್ಲಾ ಚಾನೆಲ್‌ಗಳು","Album":"ಆಲ್ಬಮ್","AddToFavorites":"ಮೆಚ್ಚಿನವುಗಳಿಗೆ ಸೇರಿಸಿ","AlbumArtist":"ಆಲ್ಬಮ್ ಕಲಾವಿದ","Alerts":"ಅಲರ್ಟ್‌ಗಳು","AllLanguages":"ಎಲ್ಲಾ ಭಾಷೆಗಳು","AllLibraries":"ಎಲ್ಲಾ ಲೈಬ್ರರಿ ಗಳು","AddToPlayQueue":"ಪ್ಲೇ ಕ್ಯೂಗೆ ಸೇರಿಸಿ","AgeValue":"({0} ವರ್ಷಗಳಷ್ಟು ಹಳೆಯದು)","AirDate":"ಪ್ರಸಾರ ದಿನಾಂಕ"}')}}]);