"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[91751],{69513:function(e,a,t){t.r(a),a.default='<div id="wizardSettingsPage" data-role="page" class="page standalonePage wizardPage"> <div class="padded-left padded-right padded-top"> <div class="ui-corner-all ui-shadow wizardContent"> <form class="wizardSettingsForm"> <h1>${HeaderPreferredMetadataLanguage}</h1> <p style="margin:1.5em 0">${DefaultMetadataLangaugeDescription}</p> <div class="selectContainer"> <select is="emby-select" id="selectLanguage" required="required" label="${LabelLanguage}"></select> </div> <div class="selectContainer"> <select is="emby-select" id="selectCountry" required="required" label="${LabelCountry}"></select> </div> <br/> <div class="wizardNavigation"> <button is="emby-button" type="button" class="raised button-cancel" onclick="history.back()"> <span class="material-icons arrow_back" aria-hidden="true"></span> <span>${Previous}</span> </button> <button is="emby-button" type="submit" class="raised button-submit"> <span>${Next}</span> <span class="material-icons arrow_forward" aria-hidden="true"></span> </button> </div> </form> </div> </div> </div> '}}]);