"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[2],{16590:function(e,t,n){n.r(t),n(29305),n(32733),n(84701),n(81678),n(44962),n(4754),n(94),n(36947),n(78557),n(83994),n(82367);var a=n(44797);function o(e){return o="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},o(e)}function u(e,t){for(var n=0;n<t.length;n++){var a=t[n];a.enumerable=a.enumerable||!1,a.configurable=!0,"value"in a&&(a.writable=!0),Object.defineProperty(e,l(a.key),a)}}function l(e){var t=function(e){if("object"!=o(e)||!e)return e;var t=e[Symbol.toPrimitive];if(void 0!==t){var n=t.call(e,"string");if("object"!=o(n))return n;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==o(t)?t:t+""}var r,i,c,y=function(){return e=function e(t,n){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e),this.player=t,this.manager=n,this.playbackCore=n.getPlaybackCore(),this.queueCore=n.getQueueCore(),this.bound=!1},(t=[{key:"bindToPlayer",value:function(){this.bound||(this.localBindToPlayer(),this.bound=!0)}},{key:"localBindToPlayer",value:function(){throw new Error("Override this method!")}},{key:"unbindFromPlayer",value:function(){this.bound&&(this.localUnbindFromPlayer(),this.bound=!1)}},{key:"localUnbindFromPlayer",value:function(){throw new Error("Override this method!")}},{key:"onPlaybackStart",value:function(e,t){this.playbackCore.onPlaybackStart(e,t),a.A.trigger(this,"playbackstart",[e,t])}},{key:"onPlaybackStop",value:function(e){this.playbackCore.onPlaybackStop(e),a.A.trigger(this,"playbackstop",[e])}},{key:"onUnpause",value:function(){this.playbackCore.onUnpause(),a.A.trigger(this,"unpause",[this.currentPlayer])}},{key:"onPause",value:function(){this.playbackCore.onPause(),a.A.trigger(this,"pause",[this.currentPlayer])}},{key:"onTimeUpdate",value:function(e,t){this.playbackCore.onTimeUpdate(e,t),a.A.trigger(this,"timeupdate",[e,t])}},{key:"onReady",value:function(){this.playbackCore.onReady(),a.A.trigger(this,"ready")}},{key:"onBuffering",value:function(){this.playbackCore.onBuffering(),a.A.trigger(this,"buffering")}},{key:"onQueueUpdate",value:function(){}},{key:"isPlaybackActive",value:function(){return!1}},{key:"isPlaying",value:function(){return!1}},{key:"currentTime",value:function(){return 0}},{key:"hasPlaybackRate",value:function(){return!1}},{key:"setPlaybackRate",value:function(e){}},{key:"getPlaybackRate",value:function(){return 1}},{key:"isRemote",value:function(){return!1}},{key:"localUnpause",value:function(){}},{key:"localPause",value:function(){}},{key:"localSeek",value:function(e){}},{key:"localStop",value:function(){}},{key:"localSendCommand",value:function(e){}},{key:"localPlay",value:function(e){}},{key:"localSetCurrentPlaylistItem",value:function(e){}},{key:"localRemoveFromPlaylist",value:function(e){}},{key:"localMovePlaylistItem",value:function(e,t){}},{key:"localQueue",value:function(e){}},{key:"localQueueNext",value:function(e){}},{key:"localNextItem",value:function(){}},{key:"localPreviousItem",value:function(){}},{key:"localSetRepeatMode",value:function(e){}},{key:"localSetQueueShuffleMode",value:function(e){}},{key:"localToggleQueueShuffleMode",value:function(){}}])&&u(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e;var e,t}();r=y,c="generic",(i=l(i="type"))in r?Object.defineProperty(r,i,{value:c,enumerable:!0,configurable:!0,writable:!0}):r[i]=c,t.default=y}}]);