"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[30168],{40475:function(a){a.exports=JSON.parse('{"Albums":"Albamyo","All":"Dhamaan","Actor":"Jile","Add":"Kudar","AddedOnValue":"Lagu Daray {0}","AddToCollection":"Ururka kudar","AgeValue":"({0} sanuu jiraa)","AirDate":"Taariikhda baafinta","Aired":"Labaafiyay","Album":"Albam","AlbumArtist":"Fannaanka Albamka","Alerts":"Wargelin","AllChannels":"Giddi kannaalada"}')}}]);