"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[33796,66884,75692],{21665:function(e,i,t){t.r(i);var s=t(62540),l=t(11444),a=(t(63696),t(37632)),n=t(65242),c=t(99883),r=t(46850),b=t(65369),o=t(4672),p={viewType:r.D.AlbumArtists,collectionType:b.X.Music,isBtnSortEnabled:!1},u={viewType:r.D.Albums,collectionType:b.X.Music,isBtnPlayAllEnabled:!0,isBtnShuffleEnabled:!0,itemType:[l.D.MusicAlbum]},y={viewType:r.D.Artists,collectionType:b.X.Music,isBtnSortEnabled:!1},d={viewType:r.D.Playlists,isBtnFilterEnabled:!1,isBtnGridListEnabled:!1,isBtnSortEnabled:!1,isAlphabetPickerEnabled:!1,itemType:[l.D.Playlist]},T={viewType:r.D.Songs,isBtnShuffleEnabled:!0,isBtnGridListEnabled:!1,isAlphabetPickerEnabled:!1,itemType:[l.D.Audio]},A={0:u,1:{viewType:r.D.Suggestions,collectionType:b.X.Music,sectionsView:o.C0},2:p,3:y,4:d,5:T,6:{viewType:r.D.Genres,collectionType:b.X.Music,itemType:[l.D.MusicAlbum]}};i.default=function(){var e=(0,a.A)(),i=e.libraryId,t=e.activeTab,l=A[t];return(0,s.jsx)(n.A,{id:"musicPage",className:"mainAnimatedPage libraryPage backdropPage collectionEditorPage pageWithAbsoluteTabs withTabs",backDropType:"musicartist",children:(0,s.jsx)(c.A,{currentTab:l,parentId:l.viewType===r.D.Playlists?void 0:i},"".concat(l.viewType," - ").concat(i))})}}}]);