"use strict";(self.webpackChunk=self.webpackChunk||[]).push([[28567],{28567:function(e,a,t){t.r(a),t(84734),t(86584),t(78557);var n=t(39738);t(44797).A.on(n.f,"playerchange",(function(e,a,t,o){o&&a&&(o.isLocalPlayer?a.isLocalPlayer?console.debug("Skipping remote control autoplay because newPlayer is a local player"):function(e,a){var t=n.f.getPlayerState(e),o=t.NowPlayingItem;o&&n.f.getPlaylist(e).then((function(l){var i=l.map((function(e){return e.Id})),r=(t.PlayState||{}).PositionTicks||0,s=i.indexOf(o.Id)||0;n.f.stop(e).then((function(){n.f.play({ids:i,serverId:o.ServerId,startPositionTicks:r,startIndex:s},a)}))}))}(o,a):console.debug("Skipping remote control autoplay because oldPlayer is not a local player"))}))}}]);