.itemProgressBar{background:#333;background:rgba(51,51,51,.8);height:.28em;position:relative}.itemLinearProgress{border-radius:100px;bottom:0;left:0;position:absolute!important;width:100%}.itemProgressBarForeground{bottom:0;position:absolute;top:0}[dir=ltr] .itemProgressBarForeground{left:0}[dir=rtl] .itemProgressBarForeground{right:0}.indicator{-webkit-align-items:center;align-items:center;border-radius:100em;display:-webkit-flex;display:flex;font-weight:500;height:2em;-webkit-justify-content:center;justify-content:center;width:2em}.timerIndicator{color:#cb272a}.timerIndicator-inactive{color:#888}[dir=ltr] .indicator+.indicator{margin-left:.25em}[dir=rtl] .indicator+.indicator{margin-right:.25em}.indicatorIcon{font-size:1.6em;height:auto;width:auto}.countIndicator{font-size:88%;font-weight:500}.countIndicator,.playedIndicator{-webkit-align-items:center;align-items:center;border-radius:100em;box-shadow:0 2px 2px 0 rgba(0,0,0,.14),0 1px 5px 0 rgba(0,0,0,.12),0 3px 1px -2px rgba(0,0,0,.2);color:#fff;display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center}.playedIndicator{font-size:80%}.videoIndicator{-webkit-align-items:center;align-items:center;background:#444;box-shadow:0 2px 2px 0 rgba(0,0,0,.14),0 1px 5px 0 rgba(0,0,0,.12),0 3px 1px -2px rgba(0,0,0,.2);color:#fff;display:-webkit-flex;display:flex;font-size:88%;-webkit-justify-content:center;justify-content:center}.syncIndicator,.videoIndicator{border-radius:100em}.emptySyncIndicator{background:#ccc;color:#333}.missingIndicator,.unairedIndicator{background:#c33;border-radius:100em;color:#fff;font-size:84%;font-weight:500;margin:0 .25em;padding:.25em .5em}
.mediaInfoItem{padding:0}[dir=ltr] .mediaInfoItem{margin:0 1em 0 0}[dir=rtl] .mediaInfoItem{margin:0 0 0 1em}.mediaInfoText{-webkit-align-items:center;align-items:center;border-radius:.25em;display:-webkit-flex;display:flex;font-size:92%;margin:0 .5em 0 0;padding:.22em .5em;white-space:nowrap}.mediaInfoText-upper{text-transform:uppercase}.mediaInfoIconItem{font-size:1.6em;height:auto;margin-right:.6em;width:auto}[dir=ltr] .mediaInfoItem:last-child{margin-right:0}[dir=rtl] .mediaInfoItem:last-child{margin-left:0}.starRatingContainer{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;-webkit-justify-content:center;justify-content:center;vertical-align:middle}.starIcon{color:#f2b01e;font-size:1.4em;height:auto!important;margin-right:.125em;width:auto!important}.mediaInfoCriticRating{-webkit-align-items:center;align-items:center;background-repeat:no-repeat;background-size:auto 1.2em;display:-webkit-flex;display:flex;min-height:1.2em}[dir=ltr] .mediaInfoCriticRating{background-position:0;padding-left:1.5em}[dir=rtl] .mediaInfoCriticRating{background-position:100%;padding-right:1.5em}.mediaInfoCriticRatingFresh{background-image:url(assets/img/fresh.svg)}.mediaInfoCriticRatingRotten{background-image:url(assets/img/rotten.svg)}.mediaInfoProgramAttribute{border-radius:.15em;font-size:80%;padding:.16em .6em;text-transform:uppercase}.closedCaptionMediaInfoText{font-weight:700}
.newTvProgram{background:#38c;color:#fff}.liveTvProgram{background:#c33;color:#fff}.premiereTvProgram{background:#ef6c00;color:#fff}.repeatTvProgram{background:#009688;color:#fff}
@-webkit-keyframes fadein{0%{opacity:0}to{opacity:1}}@keyframes fadein{0%{opacity:0}to{opacity:1}}.lazy-image-fadein{-webkit-animation:fadein .5s;animation:fadein .5s;opacity:1}.lazy-image-fadein-fast{-webkit-animation:fadein .1s;animation:fadein .1s;opacity:1}.lazy-hidden,.lazy-hidden-children *{opacity:0}.blurhash-canvas{bottom:0;height:100%;left:0;pointer-events:none;position:absolute;right:0;top:0;width:100%}
.recordingButton{min-width:10em}[dir=ltr] .recordingButton{margin-left:0}[dir=rtl] .recordingButton{margin-right:0}.recordingIcon-active{color:#c33}.recordSeriesContainer{margin-bottom:.8em}
.emby-collapse{margin:.5em 0}.collapseContent{border-width:0;height:0;overflow:hidden;padding:1.25em 1.25em;transition-duration:.3s;transition-property:height}.emby-collapsible-button{-webkit-align-items:center;align-items:center;background:transparent;border-style:solid;border-width:0 0 .1em 0;box-shadow:none;display:-webkit-flex;display:flex;margin:0;padding-left:.1em;text-transform:none;width:100%}[dir=ltr] .emby-collapsible-button{padding-left:.1em;text-align:left}[dir=rtl] .emby-collapsible-button{padding-right:.1em;text-align:right}.emby-collapse-expandIcon{font-size:1.5em;position:absolute;-webkit-transform-origin:50% 50%;transform-origin:50% 50%;transition:-webkit-transform .18s ease-out;transition:transform .18s ease-out;transition:transform .18s ease-out,-webkit-transform .18s ease-out}[dir=ltr] .emby-collapse-expandIcon{right:.5em}[dir=rtl] .emby-collapse-expandIcon{left:.5em}.emby-collapse-expandIconExpanded{-webkit-transform:rotate(180deg);transform:rotate(180deg)}.emby-collapsible-title{margin:0;padding:0}
.recordingDialog-imageContainer{-webkit-flex-shrink:0;flex-shrink:0;padding:1em 1em 1em 0;width:25%}.recordingDialog-img{width:100%}.recordingDialog-itemName{margin-top:.7em}.recordingDetailsContainer{display:-webkit-flex;display:flex}.recordingDetails{-webkit-flex-grow:1;flex-grow:1}.recordingDetailText{-webkit-align-items:center;align-items:center;display:-webkit-flex;display:flex;-webkit-flex-wrap:wrap;flex-wrap:wrap}
